@@ -370,7 +370,7 @@ void btn_button_set_label(Button *btn, BtnFace face, const gchar *label)
 	if(btn != NULL)
 	{
 		if(label != NULL)
-			stu_strncpy(btn->label[face], label, sizeof btn->label[face]);
+			g_strlcpy(btn->label[face], label, sizeof btn->label[face]);
 		else
 			btn->label[face][0] = '\0';
 	}
@@ -420,7 +420,7 @@ void btn_button_set_key(Button *btn, BtnFace face, const gchar *key)
 	if(btn != NULL)
 	{
 		if(key != NULL)
-			stu_strncpy(btn->key[face], key, sizeof btn->key[face]);
+			g_strlcpy(btn->key[face], key, sizeof btn->key[face]);
 		else
 			btn->key[face][0] = '\0';
 	}
@@ -499,7 +499,7 @@ void btn_button_set_color_fg_widget(GtkWidget *widget, BtnFace face, const GdkCo
 Button * btn_button_get(GtkWidget *wid)
 {
 	if(wid != NULL)
-		return gtk_object_get_data(GTK_OBJECT(wid), "button");
+		return g_object_get_data(G_OBJECT(wid), "button");
 	return NULL;
 }
 
@@ -566,7 +566,7 @@ void btn_button_set_tooltip(Button *btn, const gchar *tip)
 	if(btn != NULL)
 	{
 		if(tip != NULL)
-			stu_strncpy(btn->tooltip, tip, sizeof btn->tooltip);
+			g_strlcpy(btn->tooltip, tip, sizeof btn->tooltip);
 		else
 			btn->tooltip[0] = '\0';
 	}
@@ -658,7 +658,7 @@ void btn_button_swap(Button *a, Button *b)
 	*b = temp;
 }
 
-/* 1998-0915 -	Write a copy of <src> into <dst>. */
+/* 1998-09-15 -	Write a copy of <src> into <dst>. */
 void btn_button_copy(Button *dst, Button *src)
 {
 	if((dst != NULL) && (src != NULL))
@@ -667,14 +667,14 @@ void btn_button_copy(Button *dst, Button *src)
 
 		for(i = 0; i < BTN_FACES; i++)
 		{
-			stu_strncpy(dst->label[i], src->label[i], sizeof dst->label[i]);
+			g_strlcpy(dst->label[i], src->label[i], sizeof dst->label[i]);
 			btn_button_set_cmdseq(dst, i, btn_button_get_cmdseq(src, i));
-			stu_strncpy(dst->key[i], src->key[i], sizeof dst->key[i]);
+			g_strlcpy(dst->key[i], src->key[i], sizeof dst->key[i]);
 			dst->color[i][0] = src->color[i][0];
 			dst->color[i][1] = src->color[i][1];
 		}
-		stu_strncpy(dst->menu, src->menu, sizeof dst->menu);
-		stu_strncpy(dst->tooltip, src->tooltip, sizeof dst->tooltip);
+		g_strlcpy(dst->menu, src->menu, sizeof dst->menu);
+		g_strlcpy(dst->tooltip, src->tooltip, sizeof dst->tooltip);
 		dst->flags = src->flags;
 	}
 }
@@ -714,7 +714,7 @@ static void evt_button_clicked(GtkWidget *wid, gpointer user)
 	MainInfo	*min = user;
 	guint		face = od_multibutton_get_index(OD_MULTIBUTTON(wid));
 
-	btn = gtk_object_get_data(GTK_OBJECT(wid), "button");
+	btn = g_object_get_data(G_OBJECT(wid), "button");
 	if((min != NULL) && (btn != NULL) && (btn->cmdseq[face] != NULL))
 		csq_execute(min, btn->cmdseq[face]->str);
 }
@@ -725,7 +725,7 @@ static gboolean button_set_face(GtkWidget *widget, BtnFace face)
 	Button		*btn;
 	gboolean	ret = FALSE;
 
-	if((widget != NULL) && ((btn = gtk_object_get_data(GTK_OBJECT(widget), "button")) != NULL))
+	if((widget != NULL) && ((btn = g_object_get_data(G_OBJECT(widget), "button")) != NULL))
 	{
 		const gchar	*lab;
 
@@ -749,7 +749,7 @@ static gboolean button_set_face(GtkWidget *widget, BtnFace face)
 **		signal to <func>, passing it <user> on invocation.
 ** 1999-05-01 -	Rewritten; now builds an ODEmilButton instead, with multi-face support. Way cool.
 */
-static GtkWidget * button_build(MainInfo *min, Button *btn, gboolean partial, GtkSignalFunc func, gpointer user)
+static GtkWidget * button_build(MainInfo *min, Button *btn, gboolean partial, GCallback func, gpointer user)
 {
 	GtkWidget	*but;
 
@@ -758,10 +758,13 @@ static GtkWidget * button_build(MainInfo *min, Button *btn, gboolean partial, Gt
 		gboolean	set = FALSE;
 		BtnFace		i;
 
+#if GTK_CHECK_VERSION(2, 2, 0)
+		gtk_widget_set_can_focus(but, FALSE);
+#else
 		GTK_WIDGET_UNSET_FLAGS(but, GTK_CAN_FOCUS);
-
-		gtk_object_set_data(GTK_OBJECT(but), "min", min);
-		gtk_object_set_data(GTK_OBJECT(but), "button", btn);
+#endif
+		g_object_set_data(G_OBJECT(but), "min", min);
+		g_object_set_data(G_OBJECT(but), "button", btn);
 
 		for(i = 0; i < BTN_FACES; i++)
 			set |= button_set_face(but, i);
@@ -776,34 +779,23 @@ static GtkWidget * button_build(MainInfo *min, Button *btn, gboolean partial, Gt
 **		If the specified button doesn't use tooltips, don't do anything but
 **		return FALSE.
 */
-static gboolean button_tooltip(MainInfo *min, GtkTooltips *tt, Button *def, GtkWidget *btn)
+static gboolean button_tooltip(MainInfo *min, Button *def, GtkWidget *btn)
 {
 	if(btn_button_get_flags_boolean(def, BTF_SHOW_TOOLTIP) && (def->tooltip[0] != '\0'))
 	{
-		gtk_tooltips_set_tip(tt, btn, def->tooltip, NULL);
+		gtk_widget_set_tooltip_text(btn, def->tooltip);
 		return TRUE;
 	}
 	return FALSE;
 }
 
-/* 1999-01-13 -	Destroy the ToolTips for this row, since the row is about to be destroyed. */
-static gint evt_brow_destroy(GtkWidget *wid, gpointer user)
-{
-	gtk_object_destroy(GTK_OBJECT(user));
-
-	return TRUE;
-}
-
 /* 1998-09-15 -	Build GUI representation of given row. */
-static GtkWidget * buttonrow_build(MainInfo *min, ButtonRow *brw, gboolean partial, GtkSignalFunc func, gpointer user)
+static GtkWidget * buttonrow_build(MainInfo *min, ButtonRow *brw, gboolean partial, GCallback func, gpointer user)
 {
 	GtkWidget	*hbox, *hbox2 = NULL, *btn;
-	GtkTooltips	*tt = NULL;
-	guint		i, keep_tt = 0U;
+	guint		i;
 
 	hbox = gtk_hbox_new(FALSE, 0);
-	if(!partial)
-		tt = gtk_tooltips_new();
 
 	for(i = 0; i < brw->width;)
 	{
@@ -815,8 +807,8 @@ static GtkWidget * buttonrow_build(MainInfo *min, ButtonRow *brw, gboolean parti
 				if((btn = button_build(min, brw->button + i, partial, func, user)) != NULL)
 				{
 					if(!partial)
-						keep_tt |= button_tooltip(min, tt, brw->button + i, btn);
-					gtk_object_set_data(GTK_OBJECT(btn), "row", brw);
+						button_tooltip(min, brw->button + i, btn);
+					g_object_set_data(G_OBJECT(btn), "row", brw);
 					gtk_box_pack_start(GTK_BOX(hbox2), btn, FALSE, FALSE, 0);
 				}
 			}
@@ -830,19 +822,14 @@ static GtkWidget * buttonrow_build(MainInfo *min, ButtonRow *brw, gboolean parti
 				if((btn = button_build(min, brw->button + i, partial, func, user)) != NULL)
 				{
 					if(!partial)
-						keep_tt |= button_tooltip(min, tt, brw->button + i, btn);
-					gtk_object_set_data(GTK_OBJECT(btn), "row", brw);
+						button_tooltip(min, brw->button + i, btn);
+					g_object_set_data(G_OBJECT(btn), "row", brw);
 					gtk_box_pack_start(GTK_BOX(hbox2), btn, TRUE, TRUE, 0);
 				}
 			}
 			gtk_box_pack_start(GTK_BOX(hbox), hbox2, TRUE, TRUE, 0);
 		}
 	}
-	if(keep_tt)
-		g_signal_connect(G_OBJECT(hbox), "destroy", G_CALLBACK(evt_brow_destroy), tt);
-	else if(tt != NULL)
-		gtk_object_destroy(GTK_OBJECT(tt));
-
 	return hbox;
 }
 
@@ -979,7 +966,7 @@ ButtonSheet * btn_buttonsheet_new(const gchar *label)
 
 	bsh = g_malloc(sizeof *bsh);
 	if(label != NULL)
-		stu_strncpy(bsh->label, label, sizeof bsh->label);
+		g_strlcpy(bsh->label, label, sizeof bsh->label);
 	bsh->height = 0;
 	bsh->visible = 0;
 	bsh->top_row = 0;
@@ -997,7 +984,7 @@ static ButtonSheet * btn_buttonsheet_new_default_commands(MainInfo *min)
 	ButtonRow	*brw;
 
 	bsh = g_malloc(sizeof *bsh);
-	stu_strncpy(bsh->label, BTN_DEFAULT_SHEET, sizeof bsh->label);
+	g_strlcpy(bsh->label, BTN_DEFAULT_SHEET, sizeof bsh->label);
 	bsh->rows = NULL;
 	if((brw = btn_buttonrow_new_default(min)) != NULL)
 		btn_buttonsheet_append_row(bsh, brw);
@@ -1019,7 +1006,7 @@ static ButtonSheet * btn_buttonsheet_new_default_shortcuts(MainInfo *min)
 	guint		i;
 
 	bsh = g_malloc(sizeof *bsh);
-	stu_strncpy(bsh->label, "Shortcuts", sizeof bsh->label);
+	g_strlcpy(bsh->label, "Shortcuts", sizeof bsh->label);
 	bsh->rows = NULL;
 	for(i = 0; i < sizeof lab / sizeof *lab; i++)
 	{
@@ -1141,7 +1128,7 @@ ButtonSheet * btn_buttonsheet_get(ButtonInfo *bti, const gchar *label)
 **		ben gtk_widget_show()n.
 ** 1999-05-12 -	Now wraps the vbox holding the sheet's rows in a ODScrolledBox widget. Nice.
 */
-static GtkWidget * buttonsheet_build(MainInfo *min, ButtonSheet *bsh, gboolean partial, GtkSignalFunc func, gpointer user)
+static GtkWidget * buttonsheet_build(MainInfo *min, ButtonSheet *bsh, gboolean partial, GCallback func, gpointer user)
 {
 	GtkWidget	*scbox, *vbox, *row;
 	GList		*iter;
@@ -1171,7 +1158,7 @@ static GtkWidget * buttonsheet_build(MainInfo *min, ButtonSheet *bsh, gboolean p
 ** 1998-12-23 -	Added the <partial> argument so it's there when GTK+ 1.2.0 is released
 **		(if I live to see it). It's going to rule.
 */
-GtkWidget * btn_buttonsheet_build(MainInfo *min, ButtonInfo *bti, const gchar *label, gboolean partial, GtkSignalFunc func, gpointer user)
+GtkWidget * btn_buttonsheet_build(MainInfo *min, ButtonInfo *bti, const gchar *label, gboolean partial, GCallback func, gpointer user)
 {
 	GtkWidget	*sheet = NULL;
 	GList		*iter;
@@ -1179,7 +1166,7 @@ GtkWidget * btn_buttonsheet_build(MainInfo *min, ButtonInfo *bti, const gchar *l
 	if(label == NULL)
 		label = BTN_DEFAULT_SHEET;
 	if(func == NULL)
-		func = GTK_SIGNAL_FUNC(evt_button_clicked);
+		func = G_CALLBACK(evt_button_clicked);
 	if(user == NULL)
 		user = min;
 	for(iter = bti->sheets; iter != NULL; iter = g_list_next(iter))
@@ -1197,7 +1184,7 @@ GtkWidget * btn_buttonsheet_build(MainInfo *min, ButtonInfo *bti, const gchar *l
 **		button, everything is cool and we actually add the keyboard shortcut. If the
 **		widget is a hbox, we need to recurse.
 ** 1999-05-04 -	Adapted for new multi-face buttons. Now lets the keyboard module directly
-**		envoke the relevant command sequence, rather than going through an activation
+**		invoke the relevant command sequence, rather than going through an activation
 **		event. Saves the trouble of extending the kbd module to support multi-argument
 **		signals (which would be required for the activation event of ODEmilButton).
 */
@@ -1206,7 +1193,7 @@ static void btn_callback(GtkWidget *wid, gpointer user)
 	Button		*btn;
 	MainInfo	*min = user;
 
-	if(OD_IS_MULTIBUTTON(wid) && ((btn = gtk_object_get_data(GTK_OBJECT(wid), "button")) != NULL))
+	if(OD_IS_MULTIBUTTON(wid) && ((btn = g_object_get_data(G_OBJECT(wid), "button")) != NULL))
 	{
 		const gchar	*key, *cmd;
 		guint		i;
