@@ -85,6 +85,6 @@ extern void		btn_buttonsheet_delete_row(ButtonSheet *bsh, ButtonRow *brw);
 extern void		btn_buttonsheet_move_row(ButtonSheet *bsh, ButtonRow *brw, gint delta);
 extern guint		btn_buttonsheet_get_height(ButtonSheet *bsh);
 extern ButtonSheet *	btn_buttonsheet_get(ButtonInfo *bti, const gchar *label);
-extern GtkWidget *	btn_buttonsheet_build(MainInfo *min, ButtonInfo *bti, const gchar *label, gint partial, GtkSignalFunc func, gpointer user);
+extern GtkWidget *	btn_buttonsheet_build(MainInfo *min, ButtonInfo *bti, const gchar *label, gint partial, GCallback func, gpointer user);
 extern void		btn_buttonsheet_built_add_keys(MainInfo *min, GtkContainer *sheet, gpointer user);
 extern void		btn_buttonsheet_destroy(ButtonSheet *bsh);
