@@ -98,7 +98,7 @@ static void set_button_state(GtkWidget *btn, gboolean state)
 static void set_blocked_entry(GtkWidget *entry, const gchar *str, guint sig)
 {
 	if(sig > 0)
-		gtk_signal_handler_block(GTK_OBJECT(entry), sig);
+		g_signal_handler_block(G_OBJECT(entry), sig);
 
 	if(str != NULL)
 		gtk_entry_set_text(GTK_ENTRY(entry), str);
@@ -106,7 +106,7 @@ static void set_blocked_entry(GtkWidget *entry, const gchar *str, guint sig)
 		gtk_entry_set_text(GTK_ENTRY(entry), "");
 
 	if(sig > 0)
-		gtk_signal_handler_unblock(GTK_OBJECT(entry), sig);
+		g_signal_handler_unblock(G_OBJECT(entry), sig);
 }
 
 /* 1998-09-15 -	Reset all widgets to their most idle states. */
@@ -122,9 +122,9 @@ static void reset_widgets(P_Buttons *page)
 		gtk_entry_set_text(GTK_ENTRY(page->def[i].key), "");
 	}
 	gtk_entry_set_text(GTK_ENTRY(page->dtooltip), "");
-	gtk_signal_handler_block(GTK_OBJECT(page->dnarrow), page->dnarsig);
+	g_signal_handler_block(G_OBJECT(page->dnarrow), page->dnarsig);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->dnarrow), FALSE);
-	gtk_signal_handler_unblock(GTK_OBJECT(page->dnarrow), page->dnarsig);
+	g_signal_handler_unblock(G_OBJECT(page->dnarrow), page->dnarsig);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->dshowtip), FALSE);
 	gtk_widget_set_sensitive(page->dvbox, FALSE);
 	for(i = 0; i < sizeof page->bcmd / sizeof page->bcmd[0]; i++)
@@ -154,9 +154,9 @@ static void set_widgets(P_Buttons *page)
 			gtk_entry_set_text(GTK_ENTRY(page->dtooltip), str);
 		else
 			gtk_entry_set_text(GTK_ENTRY(page->dtooltip), "");
-		gtk_signal_handler_block(GTK_OBJECT(page->dnarrow), page->dnarsig);
+		g_signal_handler_block(G_OBJECT(page->dnarrow), page->dnarsig);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->dnarrow), btn_button_get_flags_boolean(but, BTF_NARROW));
-		gtk_signal_handler_unblock(GTK_OBJECT(page->dnarrow), page->dnarsig);
+		g_signal_handler_unblock(G_OBJECT(page->dnarrow), page->dnarsig);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->dshowtip), btn_button_get_flags_boolean(but, BTF_SHOW_TOOLTIP));
 	}
 	gtk_widget_set_sensitive(page->dvbox, TRUE);
@@ -175,7 +175,7 @@ static void populate_scwin(P_Buttons *page)
 		gtk_widget_destroy(page->shvbox);
 	page->shvbox = NULL;
 
-	if((page->shvbox = btn_buttonsheet_build(page->min, &page->buttons, page->cur_sheet, TRUE, GTK_SIGNAL_FUNC(evt_button_clicked), page)) != NULL)
+	if((page->shvbox = btn_buttonsheet_build(page->min, &page->buttons, page->cur_sheet, TRUE, G_CALLBACK(evt_button_clicked), page)) != NULL)
 	{
 		gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(page->scwin), page->shvbox);
 		gtk_widget_show_all(page->shvbox);
@@ -258,7 +258,7 @@ static gint evt_bcmd_clicked(GtkWidget *wid, gpointer user)
 {
 	P_Buttons	*page = user;
 
-	switch(GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid))))
+	switch(GPOINTER_TO_INT(g_object_get_data(G_OBJECT(wid), "index")))
 	{
 		case 0:
 			page->mode = BM_COPY;
@@ -329,7 +329,7 @@ static void add_row(gpointer user, guint width)
 	if(page->sheet != NULL)
 	{
 		if(page->button != NULL)
-			row = gtk_object_get_data(GTK_OBJECT(page->button), "row");
+			row = g_object_get_data(G_OBJECT(page->button), "row");
 		btn_buttonsheet_insert_row(page->sheet, row, width);
 		set_mode_normal(page);
 		populate_scwin(page);
@@ -344,7 +344,7 @@ static void resize_row(gpointer user, guint width)
 	P_Buttons	*page = user;
 	ButtonRow	*row;
 
-	if((row = gtk_object_get_data(GTK_OBJECT(page->button), "row")) != NULL)
+	if((row = g_object_get_data(G_OBJECT(page->button), "row")) != NULL)
 	{
 		if(width != btn_buttonrow_get_width(row))	/* Don't call set_width() in vain. */
 		{
@@ -368,7 +368,7 @@ static void move_row(P_Buttons *page, gint delta)
 	if(delta != -1 && delta != 1)
 		return;
 
-	if((row = gtk_object_get_data(GTK_OBJECT(page->button), "row")) != NULL)
+	if((row = g_object_get_data(G_OBJECT(page->button), "row")) != NULL)
 	{
 		page->modified = TRUE;
 		btn_buttonsheet_move_row(page->sheet, row, delta);
@@ -438,7 +438,7 @@ static void delete_row(P_Buttons *page)
 {
 	if(dlg_dialog_sync_new_simple_wait(_("Really delete current button row?"), _("Please Confirm"), _("_Delete|_Cancel")) == DLG_POSITIVE)
 	{
-		btn_buttonsheet_delete_row(page->sheet, (ButtonRow *) gtk_object_get_data(GTK_OBJECT(page->button), "row"));
+		btn_buttonsheet_delete_row(page->sheet, (ButtonRow *) g_object_get_data(G_OBJECT(page->button), "row"));
 		set_mode_normal(page);
 		populate_scwin(page);
 		page->modified = TRUE;
@@ -454,10 +454,10 @@ static gint evt_rcmd_clicked(GtkWidget *wid, gpointer user)
 
 	if(page->button != NULL)
 	{
-		brw = gtk_object_get_data(GTK_OBJECT(page->button), "row");
+		brw = g_object_get_data(G_OBJECT(page->button), "row");
 		width = btn_buttonrow_get_width(brw);
 	}
-	switch(GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid))))
+	switch(GPOINTER_TO_INT(g_object_get_data(G_OBJECT(wid), "index")))
 	{
 		case 0:			/* Add? */
 			width_dialog(_("Select Width for New Row"), width, add_row, page);
@@ -489,7 +489,7 @@ static void evt_label_changed(GtkWidget *wid, gpointer user)
 
 	if((page != NULL) && (page->button != NULL))
 	{
-		face = GPOINTER_TO_UINT(gtk_object_get_data(GTK_OBJECT(wid), "face"));
+		face = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(wid), "face"));
 		if((text = gtk_entry_get_text(GTK_ENTRY(wid))) != NULL)
 		{
 			btn_button_set_label_widget(page->button, face, text);
@@ -509,7 +509,7 @@ static void evt_cmdseq_changed(GtkWidget *wid, gpointer user)
 		const gchar	*text;
 		BtnFace		face;
 
-		face = (BtnFace) GPOINTER_TO_UINT(gtk_object_get_data(GTK_OBJECT(wid), "face"));
+		face = (BtnFace) GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(wid), "face"));
 		if((text = gtk_entry_get_text(GTK_ENTRY(wid))) != NULL)
 		{
 			btn_button_set_cmdseq(btn, face, text);
@@ -531,7 +531,7 @@ static void evt_cmdseq_pick_clicked(GtkWidget *wid, gpointer user)
 		BtnFace		face;
 		const gchar	*csq;
 
-		face = (BtnFace) GPOINTER_TO_UINT(gtk_object_get_data(GTK_OBJECT(wid), "face"));
+		face = (BtnFace) GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(wid), "face"));
 		if((csq = csq_dialog_sync_new_wait(page->min, ccs_get_current())) != NULL)
 			gtk_entry_set_text(GTK_ENTRY(page->def[face].cmdseq), csq);	/* Rely on "changed" signal. */
 	}
@@ -550,7 +550,7 @@ static void evt_key_press(GtkWidget *wid, GdkEventKey *evt, gpointer user)
 		{
 			BtnFace	face;
 
-			face = (BtnFace) GPOINTER_TO_UINT(gtk_object_get_data(GTK_OBJECT(wid), "face"));
+			face = (BtnFace) GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(wid), "face"));
 			gtk_entry_set_text(GTK_ENTRY(wid), key);
 			btn_button_set_key(btn, face, gtk_entry_get_text(GTK_ENTRY(wid)));
 			page->modified = TRUE;
@@ -569,7 +569,7 @@ static void evt_key_clear_clicked(GtkWidget *wid, gpointer user)
 	{
 		BtnFace	face;
 
-		face = (BtnFace) GPOINTER_TO_UINT(gtk_object_get_data(GTK_OBJECT(wid), "face"));
+		face = (BtnFace) GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(wid), "face"));
 		gtk_entry_set_text(GTK_ENTRY(page->def[face].key), "");
 		btn_button_set_key(btn, face, NULL);
 		page->modified = TRUE;
@@ -677,34 +677,35 @@ static void init_bdef(MainInfo *min, P_Buttons *page, BDef *def, const gchar *la
 
 	label = gtk_label_new(_("Label"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
-	def->label = gtk_entry_new_with_max_length(BTN_LABEL_SIZE - 1);
-	gtk_object_set_data(GTK_OBJECT(def->label), "face", GUINT_TO_POINTER(face));
+	def->label = gtk_entry_new();
+	gtk_entry_set_max_length(GTK_ENTRY(def->label), BTN_LABEL_SIZE - 1);
+	g_object_set_data(G_OBJECT(def->label), "face", GUINT_TO_POINTER(face));
 	def->label_sig = g_signal_connect(G_OBJECT(def->label), "changed", G_CALLBACK(evt_label_changed), page);
 	gtk_table_attach(GTK_TABLE(table), def->label, 1, 3, 0, 1,  GTK_EXPAND|GTK_FILL,0,0,0);
 
 	label = gtk_label_new(_("Command"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,  0,0,0,0);
 	def->cmdseq = gtk_entry_new();
-	gtk_object_set_data(GTK_OBJECT(def->cmdseq), "face", GUINT_TO_POINTER(face));
+	g_object_set_data(G_OBJECT(def->cmdseq), "face", GUINT_TO_POINTER(face));
 	def->cmdseq_sig = g_signal_connect(G_OBJECT(def->cmdseq), "changed", G_CALLBACK(evt_cmdseq_changed), page);
 	gtk_table_attach(GTK_TABLE(table), def->cmdseq, 1, 2, 1, 2,  GTK_EXPAND|GTK_FILL,0,0,0);
-	btn = gui_details_button_new(min->gui->window->window);
-	gtk_object_set_data(GTK_OBJECT(btn), "face", GUINT_TO_POINTER(face));
+	btn = gui_details_button_new();
+	g_object_set_data(G_OBJECT(btn), "face", GUINT_TO_POINTER(face));
 	g_signal_connect(G_OBJECT(btn), "clicked", G_CALLBACK(evt_cmdseq_pick_clicked), page);
 	gtk_table_attach(GTK_TABLE(table), btn, 2, 3, 1, 2,  GTK_FILL,0,0,0);
 
 	label = gtk_label_new(_("Key"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3,  0,0,0,0);
 	def->key = gtk_entry_new();
-	gtk_entry_set_editable(GTK_ENTRY(def->key), FALSE);
-	gtk_object_set_data(GTK_OBJECT(def->key), "face", GUINT_TO_POINTER(face));
+	gtk_editable_set_editable(GTK_EDITABLE(def->key), FALSE);
+	g_object_set_data(G_OBJECT(def->key), "face", GUINT_TO_POINTER(face));
 	g_signal_connect(G_OBJECT(def->key), "key_press_event", G_CALLBACK(evt_key_press), page);
 	gtk_table_attach(GTK_TABLE(table), def->key, 1, 2, 2, 3,  GTK_EXPAND|GTK_FILL,0,0,0);
 
 	btn = gtk_button_new();
 	img = gtk_image_new_from_stock(GTK_STOCK_CLEAR, GTK_ICON_SIZE_MENU);
 	gtk_button_set_image(GTK_BUTTON(btn), img);
-	gtk_object_set_data(GTK_OBJECT(btn), "face", GUINT_TO_POINTER(face));
+	g_object_set_data(G_OBJECT(btn), "face", GUINT_TO_POINTER(face));
 	g_signal_connect(G_OBJECT(btn), "clicked", G_CALLBACK(evt_key_clear_clicked), page);
 	gtk_table_attach(GTK_TABLE(table), btn, 2, 3, 2, 3,  GTK_FILL,0,0,0);
 
@@ -729,12 +730,10 @@ static void init_bdef(MainInfo *min, P_Buttons *page, BDef *def, const gchar *la
 	gtk_container_add(GTK_CONTAINER(def->frame), table);
 }
 
-static void evt_sheet_activate(GtkWidget *wid, gpointer user)
+static void evt_sheet_activate(GtkWidget *wid, guint index, gpointer user)
 {
 	P_Buttons	*page = user;
-	guint		index;
 
-	index = GPOINTER_TO_UINT(gtk_object_get_user_data(GTK_OBJECT(wid)));
 	if(index == 0U)
 		page->cur_sheet = NULL;
 	else
@@ -749,7 +748,7 @@ static GtkWidget * cbt_init(MainInfo *min, gchar **name)
 	const gchar	*mlab[] = { N_("Default"), N_("Shortcuts"), NULL },
 			*blab[] = { N_("Copy To"), N_("Copy Colors To"), N_("Swap With"), N_("Clear") },
 			*rlab[] = { N_("Add Row..."), N_("Row Width..."), N_("Up"), N_("Down"), N_("Delete Row") };
-	GtkWidget	*hbox, *menu, *optm, *sep, *label, *frame;
+	GtkWidget	*hbox, *optm, *sep, *label, *frame;
 	guint		i;
 	gint		expand;
 
@@ -761,9 +760,7 @@ static GtkWidget * cbt_init(MainInfo *min, gchar **name)
 	hbox = gtk_hbox_new(FALSE, 0);
 	label = gtk_label_new(_("Sheet"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	optm = gtk_option_menu_new();
-	menu = gui_build_menu(mlab, GTK_SIGNAL_FUNC(evt_sheet_activate), page);
-	gtk_option_menu_set_menu(GTK_OPTION_MENU(optm), menu);
+	optm = gui_build_combo_box(mlab, G_CALLBACK(evt_sheet_activate), page);
 	gtk_box_pack_start(GTK_BOX(hbox), optm, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(page->vbox), hbox, FALSE, FALSE, 0);
 
@@ -784,7 +781,8 @@ static GtkWidget * cbt_init(MainInfo *min, gchar **name)
 	hbox = gtk_hbox_new(FALSE, 0);
 	label = gtk_label_new(_("Tooltip"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	page->dtooltip = gtk_entry_new_with_max_length(BTN_TOOLTIP_SIZE - 1);
+	page->dtooltip = gtk_entry_new();
+	gtk_entry_set_max_length(GTK_ENTRY(page->dtooltip), BTN_TOOLTIP_SIZE - 1);
 	g_signal_connect(G_OBJECT(page->dtooltip), "changed", G_CALLBACK(evt_dtooltip_changed), page);
 	gtk_box_pack_start(GTK_BOX(hbox), page->dtooltip, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(page->dvbox), hbox, FALSE, FALSE, 0);
@@ -807,7 +805,7 @@ static GtkWidget * cbt_init(MainInfo *min, gchar **name)
 	for(i = 0; i < sizeof page->bcmd / sizeof page->bcmd[0]; i++)
 	{
 		page->bcmd[i] = gtk_button_new_with_label(_(blab[i]));
-		gtk_object_set_user_data(GTK_OBJECT(page->bcmd[i]), GINT_TO_POINTER(i));
+		g_object_set_data(G_OBJECT(page->bcmd[i]), "index", GINT_TO_POINTER(i));
 		g_signal_connect(G_OBJECT(page->bcmd[i]), "clicked", G_CALLBACK(evt_bcmd_clicked), page);
 		gtk_box_pack_start(GTK_BOX(hbox), page->bcmd[i], TRUE, TRUE, 0);
 	}
@@ -823,7 +821,7 @@ static GtkWidget * cbt_init(MainInfo *min, gchar **name)
 			page->rcmd[i] = gui_arrow_button_new(i == 2 ? GTK_ARROW_UP : GTK_ARROW_DOWN);
 		else
 			page->rcmd[i] = gtk_button_new_with_label(_(rlab[i]));
-		gtk_object_set_user_data(GTK_OBJECT(page->rcmd[i]), GINT_TO_POINTER(i));
+		g_object_set_data(G_OBJECT(page->rcmd[i]), "index", GINT_TO_POINTER(i));
 		g_signal_connect(G_OBJECT(page->rcmd[i]), "clicked", G_CALLBACK(evt_rcmd_clicked), page);
 		expand = (i == 0) || (i == sizeof page->rcmd / sizeof page->rcmd[0] - 1);
 		gtk_box_pack_start(GTK_BOX(hbox), page->rcmd[i], expand, TRUE, expand ? 5 : 1);
@@ -832,6 +830,9 @@ static GtkWidget * cbt_init(MainInfo *min, gchar **name)
 
 	cfg_tree_level_begin(_("Buttons"));
 	cfg_tree_level_append(_("Definitions"), page->vbox);
+
+	gtk_combo_box_set_active(GTK_COMBO_BOX(optm), 0);	/* Do this last, so all handlers can run. */
+
 	return NULL;
 }
 
