@@ -66,7 +66,6 @@ typedef struct {
 	GtkWidget	*dview;		/* Tree view for the definition. */
 	GtkWidget	*dhbox;		/* Hbox for type, definition, and pick button. */
 	GtkWidget	*dtype;		/* Type option menu, select built-in/external. */
-	GtkWidget	*dtmenu;	/* The actual menu for type selection. */
 	GtkWidget	*ddef;		/* Row definition. */
 	GtkWidget	*dpick;		/* Pick button, for definition help. */
 
@@ -106,6 +105,7 @@ enum {
 
 static void	set_row_widgets(P_CmdSeq *page);
 static void	reset_row_widgets(P_CmdSeq *page);
+static void	evt_type_selected(GtkWidget *wid, guint index, gpointer user);
 
 /* ----------------------------------------------------------------------------------------- */
 
@@ -226,9 +226,9 @@ static void reset_widgets(P_CmdSeq *page)
 	gtk_list_store_clear(page->dstore);
 	g_signal_handler_unblock(G_OBJECT(page->dstore), page->sig_delete);
 
-	gtk_option_menu_set_history(GTK_OPTION_MENU(page->dtype), 0);
+	gtk_combo_box_set_active(GTK_COMBO_BOX(page->dtype), 0);
 	gtk_entry_set_text(GTK_ENTRY(page->ddef), "");
-	gtk_notebook_set_page(GTK_NOTEBOOK(page->dextra), 0);
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(page->dextra), 0);
 	reset_row_widgets(page);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->drepeat), FALSE);
 	gtk_widget_set_sensitive(page->dframe, FALSE);
@@ -323,12 +323,12 @@ static gint evt_name_changed(GtkWidget *wid, gpointer user)
 /* 1998-09-27 -	Set general flag widgets in <pxeg> to match <flags>. */
 static void set_cx_g_flags(PXE_General *pxeg, guint32 flags)
 {
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxeg->runbg), flags & CGF_RUNINBG);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxeg->killprev), flags & CGF_KILLPREV);
-	gtk_widget_set_sensitive(pxeg->killprev, flags & CGF_RUNINBG);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxeg->graboutput), flags & CGF_GRABOUTPUT);
-	gtk_widget_set_sensitive(pxeg->survive, flags & CGF_RUNINBG);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxeg->survive), flags & CGF_SURVIVE);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxeg->runbg), (flags & CGF_RUNINBG) != 0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxeg->killprev), (flags & CGF_KILLPREV) != 0);
+	gtk_widget_set_sensitive(pxeg->killprev, (flags & CGF_RUNINBG) != 0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxeg->graboutput), (flags & CGF_GRABOUTPUT) != 0);
+	gtk_widget_set_sensitive(pxeg->survive, (flags & CGF_RUNINBG) != 0);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxeg->survive), (flags & CGF_SURVIVE) != 0);
 }
 
 /* 1999-03-09 -	Set visual state of before/after checkbuttons, according to <flags>. Sets for
@@ -340,8 +340,8 @@ static void set_cx_ba_flags(PXE_BAF *pxbaf, guint after, guint32 flags)
 	{
 		guint	st_src = FALSE, st_dst = FALSE;		/* Guess a few states. */
 
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxbaf->reqsel_src), flags & CBAF_REQSEL_SOURCE);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxbaf->reqsel_dst), flags & CBAF_REQSEL_DEST);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxbaf->reqsel_src), (flags & CBAF_REQSEL_SOURCE) != 0);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxbaf->reqsel_dst), (flags & CBAF_REQSEL_DEST) != 0);
 		if(flags & CBAF_CD_SOURCE)
 			st_src = TRUE;
 		else if(flags & CBAF_CD_DEST)
@@ -351,8 +351,8 @@ static void set_cx_ba_flags(PXE_BAF *pxbaf, guint after, guint32 flags)
 	}
 	else			/* Set "after" flags, i.e. rescan source IOR dest. */
 	{
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxbaf->rssrc), flags & CBAF_RESCAN_SOURCE);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxbaf->rsdst), flags & CBAF_RESCAN_DEST);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxbaf->rssrc), (flags & CBAF_RESCAN_SOURCE) != 0);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pxbaf->rsdst), (flags & CBAF_RESCAN_DEST) != 0);
 	}
 }
 
@@ -360,11 +360,12 @@ static void set_cx_ba_flags(PXE_BAF *pxbaf, guint after, guint32 flags)
 static void set_cx_external_widgets(P_CmdSeq *page)
 {
 	CmdRow	*row;
+	CX_Ext	*ext;
 
 	if((row = cmdrow_get_selected(page, NULL)) == NULL)
 		return;
 
-	CX_Ext	*ext = &row->extra.external;
+	ext = &row->extra.external;
 
 	set_cx_g_flags(&page->px_external.gflags, ext->gflags);
 
@@ -375,17 +376,19 @@ static void set_cx_external_widgets(P_CmdSeq *page)
 /* 1998-09-27 -	Set up widgets for row, assuming there is a row selected. */
 static void set_row_widgets(P_CmdSeq *page)
 {
-	guint	i;
-
 	CmdRow	*row;
+	guint	i;
 
 	if((row = cmdrow_get_selected(page, NULL)) == NULL)
 		return;
 	for(i = 1; i < sizeof page->dbtn / sizeof page->dbtn[0]; i++)
 		gtk_widget_set_sensitive(page->dbtn[i], TRUE);
-	gtk_option_menu_set_history(GTK_OPTION_MENU(page->dtype), row->type);
+	gui_combo_box_set_blocked(page->dtype, TRUE);
+	gtk_combo_box_set_active(GTK_COMBO_BOX(page->dtype), row->type);
+	gui_combo_box_set_blocked(page->dtype, FALSE);
+
 	gtk_entry_set_text(GTK_ENTRY(page->ddef), row->def->str);
-	gtk_notebook_set_page(GTK_NOTEBOOK(page->dextra), row->type);
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(page->dextra), row->type);
 	gtk_widget_set_sensitive(page->dhbox,  TRUE);
 	gtk_widget_set_sensitive(page->dextra, TRUE);
 	gtk_widget_set_sensitive(page->dframe, TRUE);
@@ -561,20 +564,18 @@ static void evt_row_deleted(GtkTreeModel *model, GtkTreePath *path, gpointer use
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1998-09-26 -	User choose a new type for the current row. */
-static void evt_type_selected(GtkWidget *wid, gpointer user)
+static void evt_type_selected(GtkWidget *wid, guint index, gpointer user)
 {
 	P_CmdSeq	*page = user;
 	CmdRow		*row;
 	GtkTreeIter	iter;
-	CRType		type;
 
 	if((row = cmdrow_get_selected(page, &iter)) == NULL)
 		return;
 
-	type = (CRType) gtk_object_get_user_data(GTK_OBJECT(wid));
-	csq_cmdrow_set_type(row, type);
+	csq_cmdrow_set_type(row, (CRType) index);
 	gtk_list_store_set(page->dstore, &iter, DEF_COLUMN_TYPE, csq_cmdrow_type_to_string(row->type), -1);
-	gtk_notebook_set_page(GTK_NOTEBOOK(page->dextra), type);
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(page->dextra), (CRType) index);
 	page->modified = TRUE;
 }
 
@@ -642,6 +643,14 @@ static void pick_external(P_CmdSeq *page)
 					"Ph",	N_("Path to home directory"),
 					"Pl",	N_("Path of left pane"),
 					"Pr",	N_("Path of right pane"),
+					"u",	N_("URI of first selected"),
+					"uu",	N_("URI of first selected, unselect"),
+					"uQ",	N_("URI of first selected, no quotes"),
+					"U",	N_("URIs of all selected"),
+					"Uu",	N_("URIs of all selected, unselect"),
+					"UQ",	N_("URIs of all selected, no quotes"),
+					"UuQ",	N_("URIs of all selected, unselect, no quotes"),
+					"ud",	N_("URI of first selected (destination pane)"),
 					"Ic:\"label\"=\"choice1\",...",	N_("Input combo box"),
 					"Im:\"label\"=\"text1:choice1\",...",	N_("Input using menu"),
 					"Is:\"label\"=\"default\"",	N_("Input string"),
@@ -684,11 +693,15 @@ static void pick_external(P_CmdSeq *page)
 			gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &code, -1);
 			if(code != NULL)
 			{
+				gint	pos;
+				gsize	len;
+
 				if(*code == '\\')
-					g_snprintf(buf, sizeof buf, code);
+					len = g_snprintf(buf, sizeof buf, "%s", code);
 				else
-					g_snprintf(buf, sizeof buf, " {%s}", code);
-				gtk_entry_append_text(GTK_ENTRY(page->ddef), buf);
+					len = g_snprintf(buf, sizeof buf, " {%s}", code);
+				pos = gtk_entry_get_text_length(GTK_ENTRY(page->ddef));
+				gtk_editable_insert_text(GTK_EDITABLE(page->ddef), buf, len, &pos);
 				g_free(code);
 			}
 		}
@@ -736,7 +749,7 @@ static void evt_add_clicked(GtkWidget *wid, gpointer user)
 	gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(page->view), path, NULL, TRUE, 0.5f, 0.0f);
 	gtk_tree_path_free(path);
 
-	gtk_entry_select_region(GTK_ENTRY(page->name), 0, -1);
+	gtk_editable_select_region(GTK_EDITABLE(page->name), 0, -1);
 	gtk_widget_grab_focus(page->name);
 }
 
@@ -770,7 +783,7 @@ static void build_px_builtin(P_CmdSeq *page, PX_Builtin *pxb)
 static void evt_gf_clicked(GtkWidget *wid, gpointer user)
 {
 	P_CmdSeq	*page = user;
-	guint32		flags = GPOINTER_TO_UINT(gtk_object_get_user_data(GTK_OBJECT(wid)));
+	guint32		flags = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(wid), "user"));
 	CmdSeq		*cs;
 	CmdRow		*row;
 
@@ -799,21 +812,21 @@ static void build_pxe_general(P_CmdSeq *page, PXE_General *pxg)
 
 	hbox = gtk_hbox_new(FALSE, 0);
 	pxg->runbg = gtk_check_button_new_with_label(_("Run in Background?"));
-	gtk_object_set_user_data(GTK_OBJECT(pxg->runbg), GINT_TO_POINTER(CGF_RUNINBG));
+	g_object_set_data(G_OBJECT(pxg->runbg), "user", GINT_TO_POINTER(CGF_RUNINBG));
 	g_signal_connect(G_OBJECT(pxg->runbg), "clicked", G_CALLBACK(evt_gf_clicked), page);
 	gtk_box_pack_start(GTK_BOX(hbox), pxg->runbg, FALSE, FALSE, 0);
 	pxg->killprev = gtk_check_button_new_with_label(_("Kill Previous Instance?"));
-	gtk_object_set_user_data(GTK_OBJECT(pxg->killprev), GINT_TO_POINTER(CGF_KILLPREV));
+	g_object_set_data(G_OBJECT(pxg->killprev), "user", GINT_TO_POINTER(CGF_KILLPREV));
 	g_signal_connect(G_OBJECT(pxg->killprev), "clicked", G_CALLBACK(evt_gf_clicked), page);
 	gtk_box_pack_start(GTK_BOX(hbox), pxg->killprev, FALSE, FALSE, 0);
 	pxg->survive = gtk_check_button_new_with_label(_("Survive Quit?"));
-	gtk_object_set_user_data(GTK_OBJECT(pxg->survive), GINT_TO_POINTER(CGF_SURVIVE));
+	g_object_set_data(G_OBJECT(pxg->survive), "user", GINT_TO_POINTER(CGF_SURVIVE));
 	g_signal_connect(G_OBJECT(pxg->survive), "clicked", G_CALLBACK(evt_gf_clicked), page);
 	gtk_box_pack_start(GTK_BOX(hbox), pxg->survive, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(pxg->vbox), hbox, FALSE, FALSE, 0);
 
 	pxg->graboutput = gtk_check_button_new_with_label(_("Capture Output?"));
-	gtk_object_set_user_data(GTK_OBJECT(pxg->graboutput), GINT_TO_POINTER(CGF_GRABOUTPUT));
+	g_object_set_data(G_OBJECT(pxg->graboutput), "user", GINT_TO_POINTER(CGF_GRABOUTPUT));
 	g_signal_connect(G_OBJECT(pxg->graboutput), "clicked", G_CALLBACK(evt_gf_clicked), page);
 	gtk_box_pack_start(GTK_BOX(pxg->vbox), pxg->graboutput, FALSE, FALSE, 0);
 }
@@ -828,7 +841,7 @@ static void evt_baf_reqsel_clicked(GtkWidget *wid, gpointer user)
 	if(!get_selections(page, NULL, &row))
 		return;
 
-	mask = GPOINTER_TO_UINT(gtk_object_get_user_data(GTK_OBJECT(wid)));
+	mask = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(wid), "user"));
 	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid)))
 		row->extra.external.baflags[0] |= mask;
 	else
@@ -852,7 +865,7 @@ static void evt_baf_cd_clicked(GtkWidget *wid, gpointer user)
 		return;
 
 	/* Figure out if we're in source or dest (same handler). */
-	if(gtk_object_get_data(GTK_OBJECT(wid), "destination"))
+	if(g_object_get_data(G_OBJECT(wid), "destination"))
 	{
 		other = page->px_external.baf.cdsrc;
 		mask  = CBAF_CD_DEST;
@@ -876,7 +889,7 @@ static void evt_baf_rescan_clicked(GtkWidget *wid, gpointer user)
 {
 	P_CmdSeq	*page = user;
 	CmdRow		*row;
-	guint32		mask = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid)));
+	guint32		mask = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(wid), "user"));
 
 	if(!get_selections(page, NULL, &row))
 		return;
@@ -893,7 +906,7 @@ static void evt_baf_rescan_clicked(GtkWidget *wid, gpointer user)
 */
 static void build_px_baf(P_CmdSeq *page, PXE_BAF *pxbaf)
 {
-	GtkWidget	*vbox;
+	GtkWidget	*vbox, *hbox;
 
 	pxbaf->hbox = gtk_hbox_new(FALSE, 0);
 
@@ -901,32 +914,34 @@ static void build_px_baf(P_CmdSeq *page, PXE_BAF *pxbaf)
 	vbox = gtk_vbox_new(FALSE, 0);
 
 	pxbaf->reqsel_src = gtk_check_button_new_with_label(_("Require Source Selection?"));
-	gtk_object_set_user_data(GTK_OBJECT(pxbaf->reqsel_src), GINT_TO_POINTER(CBAF_REQSEL_SOURCE));
+	g_object_set_data(G_OBJECT(pxbaf->reqsel_src), "user", GINT_TO_POINTER(CBAF_REQSEL_SOURCE));
 	g_signal_connect(G_OBJECT(pxbaf->reqsel_src), "clicked", G_CALLBACK(evt_baf_reqsel_clicked), page);
 	gtk_box_pack_start(GTK_BOX(vbox), pxbaf->reqsel_src, TRUE, TRUE, 0);
 	pxbaf->reqsel_dst = gtk_check_button_new_with_label(_("Require Destination Selection?"));
-	gtk_object_set_user_data(GTK_OBJECT(pxbaf->reqsel_dst), GINT_TO_POINTER(CBAF_REQSEL_DEST));
+	g_object_set_data(G_OBJECT(pxbaf->reqsel_dst), "user", GINT_TO_POINTER(CBAF_REQSEL_DEST));
 	g_signal_connect(G_OBJECT(pxbaf->reqsel_dst), "clicked", G_CALLBACK(evt_baf_reqsel_clicked), page);
 	gtk_box_pack_start(GTK_BOX(vbox), pxbaf->reqsel_dst, TRUE, TRUE, 0);
 
+	hbox = gtk_hbox_new(TRUE, 0);
 	pxbaf->cdsrc = gtk_check_button_new_with_label(_("CD Source?"));
 	g_signal_connect(G_OBJECT(pxbaf->cdsrc), "clicked", G_CALLBACK(evt_baf_cd_clicked), page);
-	gtk_box_pack_start(GTK_BOX(vbox), pxbaf->cdsrc, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), pxbaf->cdsrc, TRUE, TRUE, 0);
 	pxbaf->cddst = gtk_check_button_new_with_label(_("CD Destination?"));
-	gtk_object_set_data(GTK_OBJECT(pxbaf->cddst), "destination", GINT_TO_POINTER(1));	/* Just a silly flag. */
+	g_object_set_data(G_OBJECT(pxbaf->cddst), "destination", GINT_TO_POINTER(1));	/* Just a silly flag. */
 	g_signal_connect(G_OBJECT(pxbaf->cddst), "clicked", G_CALLBACK(evt_baf_cd_clicked), page);
-	gtk_box_pack_start(GTK_BOX(vbox), pxbaf->cddst, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), pxbaf->cddst, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 0);
 	gtk_container_add(GTK_CONTAINER(pxbaf->bframe), vbox);
 	gtk_box_pack_start(GTK_BOX(pxbaf->hbox), pxbaf->bframe, TRUE, TRUE, 0);
 
 	pxbaf->aframe = gtk_frame_new(_("After Execution"));
 	vbox = gtk_vbox_new(FALSE, 0);
 	pxbaf->rssrc = gtk_check_button_new_with_label(_("Rescan Source?"));
-	gtk_object_set_user_data(GTK_OBJECT(pxbaf->rssrc), GINT_TO_POINTER(CBAF_RESCAN_SOURCE));
+	g_object_set_data(G_OBJECT(pxbaf->rssrc), "user", GINT_TO_POINTER(CBAF_RESCAN_SOURCE));
 	g_signal_connect(G_OBJECT(pxbaf->rssrc), "clicked", G_CALLBACK(evt_baf_rescan_clicked), page);
 	gtk_box_pack_start(GTK_BOX(vbox), pxbaf->rssrc, TRUE, TRUE, 0);
 	pxbaf->rsdst = gtk_check_button_new_with_label(_("Rescan Destination?"));
-	gtk_object_set_user_data(GTK_OBJECT(pxbaf->rsdst), GINT_TO_POINTER(CBAF_RESCAN_DEST));
+	g_object_set_data(G_OBJECT(pxbaf->rsdst), "user", GINT_TO_POINTER(CBAF_RESCAN_DEST));
 	g_signal_connect(G_OBJECT(pxbaf->rsdst), "clicked", G_CALLBACK(evt_baf_rescan_clicked), page);
 	gtk_box_pack_start(GTK_BOX(vbox), pxbaf->rsdst, TRUE, TRUE, 0);
 	gtk_container_add(GTK_CONTAINER(pxbaf->aframe), vbox);
@@ -977,7 +992,8 @@ static GtkWidget * ccs_init(MainInfo *min, gchar **name)
 	page->nhbox = gtk_hbox_new(FALSE, 0);
 	label = gtk_label_new(_("Name"));
 	gtk_box_pack_start(GTK_BOX(page->nhbox), label, FALSE, FALSE, 0);
-	page->name = gtk_entry_new_with_max_length(CSQ_NAME_SIZE - 1);
+	page->name = gtk_entry_new();
+	gtk_entry_set_max_length(GTK_ENTRY(page->name), CSQ_NAME_SIZE - 1);
 	g_signal_connect(G_OBJECT(page->name), "changed", G_CALLBACK(evt_name_changed), page);
 	gtk_box_pack_start(GTK_BOX(page->nhbox), page->name, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), page->nhbox, FALSE, FALSE, 0);
@@ -1016,14 +1032,12 @@ static GtkWidget * ccs_init(MainInfo *min, gchar **name)
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 5);
 
 	page->dhbox = gtk_hbox_new(FALSE, 0);
-	page->dtmenu = gui_build_menu(tlab, GTK_SIGNAL_FUNC(evt_type_selected), page);
-	page->dtype = gtk_option_menu_new();
-	gtk_option_menu_set_menu(GTK_OPTION_MENU(page->dtype), page->dtmenu);
+	page->dtype = gui_build_combo_box(tlab, G_CALLBACK(evt_type_selected), page);
 	gtk_box_pack_start(GTK_BOX(page->dhbox), page->dtype, FALSE, FALSE, 0);
 	page->ddef = gtk_entry_new();
 	g_signal_connect(G_OBJECT(page->ddef), "changed", G_CALLBACK(evt_def_changed), page);
 	gtk_box_pack_start(GTK_BOX(page->dhbox), page->ddef, TRUE, TRUE, 0);
-	page->dpick = gui_details_button_new(min->gui->window->window);
+	page->dpick = gui_details_button_new();
 	g_signal_connect(G_OBJECT(page->dpick), "clicked", G_CALLBACK(evt_pick_clicked), page);
 	gtk_box_pack_start(GTK_BOX(page->dhbox), page->dpick, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), page->dhbox, FALSE, FALSE, 0);
@@ -1160,7 +1174,8 @@ static void save_cmdseq(gpointer key, gpointer data, gpointer user)
 static gint ccs_save(MainInfo *min, FILE *out)
 {
 	xml_put_node_open(out, NODE);
-	g_hash_table_foreach(min->cfg.commands.cmdseq, save_cmdseq, out);
+	if(min->cfg.commands.cmdseq != NULL)
+		g_hash_table_foreach(min->cfg.commands.cmdseq, save_cmdseq, out);
 	xml_put_node_close(out, NODE);
 	return TRUE;
 }
