@@ -2,5 +2,5 @@
 ** 1999-03-16 -	Header for the configuration module dealing with controls. Real short.
 */
 
-CfgPage *	cct_describe(MainInfo *min);
+extern const CfgModule *	cct_describe(MainInfo *min);
 
