@@ -62,6 +62,34 @@ static gint evt_path_changed(GtkWidget *wid, gpointer user)
 	return TRUE;
 }
 
+/* 2011-09-27 -	Path editor for the list dialog, makes it easy to edit each single path by providing a standard file chooser dialog. */
+static gboolean path_editor(GString *value, gpointer user)
+{
+	P_Paths		*page = user;
+	GtkWidget	*fc;
+	gint		ret;
+	gboolean	success;
+
+	fc = gtk_file_chooser_dialog_new(_("Edit path"), GTK_WINDOW(page->main->gui->window), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, GTK_STOCK_OPEN, GTK_RESPONSE_OK, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL);
+	/* For this usage, I really think it makes sense to call this, despite the recommendation not to. */
+	gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(fc), value->str);
+	ret = gtk_dialog_run(GTK_DIALOG(fc));
+	if(ret == GTK_RESPONSE_OK)
+	{
+		gchar	*filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fc));
+
+		if(filename != NULL && *filename != '\0')
+		{
+			g_string_assign(value, filename);
+			success = TRUE;
+		}
+		g_free(filename);
+	}
+	gtk_widget_destroy(fc);
+
+	return success;
+}
+
 /* 2010-07-28 -	The "pick" button next to a path was clicked; pop up a list dialog. */
 static void evt_path_pick_clicked(GtkWidget *wid, gpointer user)
 {
@@ -75,7 +103,7 @@ static void evt_path_pick_clicked(GtkWidget *wid, gpointer user)
 		gchar	tmp[1024];
 
 		g_snprintf(tmp, sizeof tmp, "%s", text);
-		ldl_dialog_sync_new_wait(tmp, sizeof tmp, ':', _("Edit path"));
+		ldl_dialog_sync_new_full_wait(tmp, sizeof tmp, ':', _("Edit path"), path_editor, page);
 		if(strcmp(tmp, text) != 0)
 			gtk_entry_set_text(GTK_ENTRY(entry), tmp);
 	}
