@@ -23,6 +23,7 @@
 #include "types.h"
 #include "dirpane.h"
 #include "dialog.h"
+#include "dpformat.h"
 #include "iconutil.h"
 #include "strutil.h"
 #include "fileutil.h"
@@ -46,11 +47,21 @@
 
 /* ----------------------------------------------------------------------------------------- */
 
+/* For GtkTreeModel access. */
+enum {
+	COLUMN_ICON,
+	COLUMN_NAME
+};
+
 typedef struct {			/* Visual properties notebook page. */
-	GtkWidget	*vbox;
-	GtkWidget	*preview;	/* CList showing preview of style (old-school!). */
-	GtkWidget	*override[3];	/* Override check buttons for back- & foreground colors, plus icon. */
-	GtkWidget	*edit[3];	/* The "edit" (or "pick") command buttons. */
+	GtkWidget		*vbox;
+	GtkWidget		*preview;	/* CList showing preview of style (old-school!). */
+	GtkTreeViewColumn	*pre_icon;	/* Icon preview. */
+	GtkCellRenderer		*pre_icon_r;
+	GtkTreeViewColumn	*pre_name;	/* Name (text) preview. */
+	GtkCellRenderer		*pre_name_r;
+	GtkWidget		*override[3];	/* Override check buttons for back- & foreground colors, plus icon. */
+	GtkWidget		*edit[3];	/* The "edit" (or "pick") command buttons. */
 } PVisual;
 
 typedef struct {			/* Action properties notebook page. */
@@ -103,26 +114,23 @@ static P_Styles	the_page;
 /* 1999-05-24 -	Set the preview widget(s). */
 static void set_widgets_preview(P_Styles *page, Style *stl)
 {
-	const gchar	*iname;
-	const GdkColor	*col;
+	GtkListStore	*store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(page->dpvisual.preview)));
+	GtkTreeIter	iter;
 
-	if((iname = stl_style_property_get_icon(stl, SPN_ICON_UNSEL)) != NULL)
+	if(gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter))
 	{
-		GdkPixmap	*ipix;
-		GdkBitmap	*imsk;
+		const gchar	*iname;
 
-		if((ipix = ico_icon_get(page->min, iname, &imsk)) != NULL)
-			gtk_clist_set_pixmap(GTK_CLIST(page->dpvisual.preview), 0, 0, ipix, imsk);
+		if((iname = stl_style_property_get_icon(stl, SPN_ICON_UNSEL)) != NULL)
+		{
+			GdkPixbuf	*pbuf;
+
+			if((pbuf = ico_icon_get_pixbuf(page->min, iname)) != NULL)
+				gtk_list_store_set(store, &iter, COLUMN_ICON, pbuf, -1);
+		}
 	}
-	if((col = stl_style_property_get_color(stl, SPN_COL_UNSEL_BG)) != NULL)
-		gtk_clist_set_background(GTK_CLIST(page->dpvisual.preview), 0, (GdkColor *) col);
-	else
-	{
-		col = &gtk_widget_get_style(GTK_WIDGET(page->min->gui->pane[0].list))->base[GTK_STATE_NORMAL];
-		gtk_clist_set_background(GTK_CLIST(page->dpvisual.preview), 0, (GdkColor *) col);
-	}
-	if((col = stl_style_property_get_color(stl, SPN_COL_UNSEL_FG)) != NULL)
-		gtk_clist_set_foreground(GTK_CLIST(page->dpvisual.preview), 0, (GdkColor *) col);
+	dpf_cell_set_style_colors(page->dpvisual.pre_icon_r, stl, FALSE);
+	dpf_cell_set_style_colors(page->dpvisual.pre_name_r, stl, TRUE);
 }
 
 /* 1999-05-24 -	Set action list. */
@@ -277,7 +285,7 @@ static void populate_tree(P_Styles *page)
 {
 	if(page->si != NULL)
 	{
-		page->store = stl_styleinfo_build_partial2(page->si, NULL);
+		page->store = stl_styleinfo_build_partial(page->si, NULL);
 		/* Block expand/collapse signals. */
 		g_signal_handler_block(page->tree, page->sig_collapse);
 		g_signal_handler_block(page->tree, page->sig_expand);
@@ -342,7 +350,7 @@ static void evt_vprop_override_toggled(GtkWidget *wid, gpointer user)
 	if((style = style_get_selected(page, NULL)) == NULL)
 		return;
 
-	pname = gtk_object_get_user_data(GTK_OBJECT(wid));
+	pname = g_object_get_data(G_OBJECT(wid), "user");
 	or = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid));
 	if(or)
 	{
@@ -354,7 +362,7 @@ static void evt_vprop_override_toggled(GtkWidget *wid, gpointer user)
 
 			/* FIXME: This assumes only background can be non-overridden in root. */
 			if((def = stl_style_property_get_color(style, pname)) == NULL)
-				def = &(gtk_widget_get_style(GTK_WIDGET(page->min->gui->pane[0].list))->base[GTK_STATE_NORMAL]);
+				def = &(gtk_widget_get_style(GTK_WIDGET(page->min->gui->pane[0].view))->base[GTK_STATE_NORMAL]);
 			stl_style_property_set_color(style, pname, def);
 		}
 	}
@@ -386,7 +394,7 @@ static void evt_vprop_edit_clicked(GtkWidget *wid, gpointer user)
 	if((style = style_get_selected(page, NULL)) == NULL)
 		return;
 
-	page->curr_prop = gtk_object_get_user_data(GTK_OBJECT(wid));
+	page->curr_prop = g_object_get_data(G_OBJECT(wid), "user");
 
 	if(strcmp(page->curr_prop, SPN_ICON_UNSEL) == 0)
 	{
@@ -452,7 +460,7 @@ static void evt_aprop_selection_changed(GtkTreeSelection *sel, gpointer user)
 		ovr = set_aprop_delete_button(page, style);
 		/* Set the name column's editable mode, depending on override. */
 		col = gtk_tree_view_get_column(GTK_TREE_VIEW(page->dpaction.view), 0);
-		cellrenderers = gtk_tree_view_column_get_cell_renderers(col);
+		cellrenderers = gtk_cell_layout_get_cells(GTK_CELL_LAYOUT(col));
 		if(cellrenderers != NULL)
 		{
 			g_object_set(G_OBJECT(cellrenderers->data), "editable", ovr, NULL);
@@ -587,7 +595,8 @@ static void evt_aprop_add_clicked(GtkWidget *wid, gpointer user)
 	hbox = gtk_hbox_new(FALSE, 0);
 	label = gtk_label_new(_("Name"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	entry = gtk_entry_new_with_max_length(STL_PROPERTY_NAME_SIZE - 1);
+	entry = gtk_entry_new();
+	gtk_entry_set_max_length(GTK_ENTRY(entry), STL_PROPERTY_NAME_SIZE - 1);
 	gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
 	dlg = dlg_dialog_sync_new(hbox, _("New Action Property"), NULL);
 	gtk_widget_grab_focus(entry);
@@ -648,7 +657,7 @@ static void evt_style_add_clicked(GtkWidget *wid, gpointer user)
 		if(stl_styleinfo_tree_find_style(page->si, page->store, stl, &iter))
 		{
 			gtk_tree_selection_select_iter(gtk_tree_view_get_selection(GTK_TREE_VIEW(page->tree)), &iter);
-			gtk_entry_select_region(GTK_ENTRY(page->dname), 0, -1);
+			gtk_editable_select_region(GTK_EDITABLE(page->dname), 0, -1);
 			gtk_widget_grab_focus(page->dname);
 		}
 	}
@@ -690,23 +699,32 @@ static void evt_style_del_clicked(GtkWidget *wid, gpointer user)
 /* 1999-05-22 -	Build the visual property editing widgets. */
 static void build_pvisual(P_Styles *page)
 {
-	PVisual		*pv = &page->dpvisual;
-	const gchar	*vplab[] = { N_("Background Color"), N_("Foreground Color"), N_("Icon") },
-			*vpname[] = { SPN_COL_UNSEL_BG, SPN_COL_UNSEL_FG, SPN_ICON_UNSEL };
-	gchar		*ctxt[] = { "", N_("(Row Style Preview Text)") };
-	GtkWidget	*hbox, *frame, *vbox, *label;
-	guint		i;
+	PVisual			*pv = &page->dpvisual;
+	const gchar		*vplab[] = { N_("Background Color"), N_("Foreground Color"), N_("Icon") },
+				*vpname[] = { SPN_COL_UNSEL_BG, SPN_COL_UNSEL_FG, SPN_ICON_UNSEL };
+	gchar			ptxt[] = N_("(Row Style Preview Text)");
+	GtkListStore		*store;
+	GtkTreeIter		iter;
+	GtkWidget		*hbox, *frame, *vbox, *label;
+	guint			i;
 
 	pv->vbox = gtk_vbox_new(FALSE, 0);
 	hbox = gtk_hbox_new(FALSE, 0);
 	label = gtk_label_new(_("Preview"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	pv->preview = gtk_clist_new(2);
+	store = gtk_list_store_new(2, GDK_TYPE_PIXBUF, G_TYPE_STRING);
+	gtk_list_store_append(store, &iter);
+	gtk_list_store_set(store, &iter, COLUMN_NAME, _(ptxt), -1);
+	pv->preview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
+	pv->pre_icon_r = gtk_cell_renderer_pixbuf_new();
+	pv->pre_icon = gtk_tree_view_column_new_with_attributes("(title)", pv->pre_icon_r, "pixbuf", COLUMN_ICON, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(pv->preview), pv->pre_icon);
+	pv->pre_name_r = gtk_cell_renderer_text_new();
+	pv->pre_name = gtk_tree_view_column_new_with_attributes("(title)", pv->pre_name_r, "text", COLUMN_NAME, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(pv->preview), pv->pre_name);
+	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(pv->preview), FALSE);
 	gtk_widget_set_name(pv->preview, "cstPreview");
-	gtk_clist_set_column_width(GTK_CLIST(pv->preview), 0, 16);
-	ctxt[1] = _(ctxt[1]);
-	gtk_clist_append(GTK_CLIST(pv->preview), ctxt);
-	gtk_clist_set_selectable(GTK_CLIST(pv->preview), 0, FALSE);
+	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(pv->preview)), GTK_SELECTION_SINGLE);	/* Or none, like before? */
 	gtk_box_pack_start(GTK_BOX(hbox), pv->preview, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(pv->vbox), hbox, FALSE, FALSE, 2);
 
@@ -717,11 +735,11 @@ static void build_pvisual(P_Styles *page)
 		vbox = gtk_vbox_new(FALSE, 0);
 		gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 		pv->override[i] = gtk_check_button_new_with_label(_("Override Parent's?"));
-		gtk_object_set_user_data(GTK_OBJECT(pv->override[i]), (gpointer) vpname[i]);
+		g_object_set_data(G_OBJECT(pv->override[i]), "user", (gpointer) vpname[i]);
 		g_signal_connect(G_OBJECT(pv->override[i]), "toggled", G_CALLBACK(evt_vprop_override_toggled), page);
 		gtk_box_pack_start(GTK_BOX(vbox), pv->override[i], FALSE, FALSE, 0);
 		pv->edit[i] = gtk_button_new_with_label(i < 2 ? _("Edit...") : _("Pick..."));
-		gtk_object_set_user_data(GTK_OBJECT(pv->edit[i]), (gpointer) vpname[i]);
+		g_object_set_data(G_OBJECT(pv->edit[i]), "user", (gpointer) vpname[i]);
 		g_signal_connect(G_OBJECT(pv->edit[i]), "clicked", G_CALLBACK(evt_vprop_edit_clicked), page);
 		gtk_box_pack_start(GTK_BOX(vbox), pv->edit[i], FALSE, FALSE, 0);
 		gtk_container_add(GTK_CONTAINER(frame), vbox);
@@ -804,15 +822,17 @@ static GtkWidget * cst_init(MainInfo *min, gchar **name)
 	table = gtk_table_new(2, 3, FALSE);
 	label = gtk_label_new(_("Name"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
-	page->dname = gtk_entry_new_with_max_length(STL_STYLE_NAME_SIZE - 1);
+	page->dname = gtk_entry_new();
+	gtk_entry_set_max_length(GTK_ENTRY(page->dname), STL_STYLE_NAME_SIZE - 1);
 	gui_handler_group_connect(page->handlers, G_OBJECT(page->dname), "changed", G_CALLBACK(evt_style_name_changed), page);
 	gtk_table_attach(GTK_TABLE(table), page->dname, 1, 3, 0, 1,  GTK_EXPAND|GTK_FILL,0,0,0);
 	label = gtk_label_new(_("Parent"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,  0,0,0,0);
-	page->dparent = gtk_entry_new_with_max_length(STL_STYLE_NAME_SIZE - 1);
-	gtk_entry_set_editable(GTK_ENTRY(page->dparent), FALSE);
+	page->dparent = gtk_entry_new();
+	gtk_entry_set_max_length(GTK_ENTRY(page->dparent), STL_STYLE_NAME_SIZE - 1);
+	gtk_editable_set_editable(GTK_EDITABLE(page->dparent), FALSE);
 	gtk_table_attach(GTK_TABLE(table), page->dparent, 1, 2, 1, 2,  GTK_EXPAND|GTK_FILL,0,0,0);
-	page->dreparent = gui_details_button_new(min->gui->window->window);
+	page->dreparent = gui_details_button_new();
 	g_signal_connect(G_OBJECT(page->dreparent), "clicked", G_CALLBACK(evt_style_parent_clicked), page);
 	gtk_table_attach(GTK_TABLE(table), page->dreparent, 2, 3, 1, 2,  0,0,0,0);
 	gtk_box_pack_start(GTK_BOX(page->dvbox), table, FALSE, FALSE, 0);
