@@ -141,7 +141,7 @@ static void set_widgets(P_Types *page, FType *tpe, GtkTreeIter *iter)
 
 	for(i = 0; i < 7; i++)
 	{
-		if(page->itmode[GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(page->itype[i])))] == tpe->mode)
+		if(page->itmode[GPOINTER_TO_INT(g_object_get_data(G_OBJECT(page->itype[i]), "user"))] == tpe->mode)
 		{
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->itype[i]), TRUE);
 			break;
@@ -170,24 +170,23 @@ static void set_widgets(P_Types *page, FType *tpe, GtkTreeIter *iter)
 
 	if(tpe->style != NULL)
 	{
-		GdkPixmap	*ipix;
-		GdkBitmap	*imsk = NULL;
+		GdkPixbuf	*pbuf;
 		gchar		buf[128];
 		const gchar	*iname;
 
 		if((iname = stl_style_property_get_icon(tpe->style, SPN_ICON_UNSEL)) != NULL)
 		{
-			if((ipix = ico_icon_get(page->min, iname, &imsk)) != NULL)
+			if((pbuf = ico_icon_get_pixbuf(page->min, iname)) != NULL)
 			{
 				if(page->sicon == NULL)
 				{
-					page->sicon = gtk_pixmap_new(ipix, imsk);
+					page->sicon = gtk_image_new_from_pixbuf(pbuf);
 					gtk_box_pack_start(GTK_BOX(page->sbhbox), page->sicon, FALSE, FALSE, 10);
 					gtk_box_reorder_child(GTK_BOX(page->sbhbox), page->sicon, 0);
 					gtk_widget_show(page->sicon);
 				}
 				else
-					gtk_pixmap_set(GTK_PIXMAP(page->sicon), ipix, imsk);
+					gtk_image_set_from_pixbuf(GTK_IMAGE(page->sicon), pbuf);
 			}
 		}
 		g_snprintf(buf, sizeof buf, _("%s - Click to Change..."), stl_style_get_name(tpe->style));
@@ -205,6 +204,7 @@ static void reset_widgets(P_Types *page)
 	gint	i;
 
 	page->curr_type = NULL;
+	gtk_tree_selection_unselect_all(gtk_tree_view_get_selection(GTK_TREE_VIEW(page->view)));
 	gtk_entry_set_text(GTK_ENTRY(page->name), "");
 	gtk_widget_set_sensitive(page->ntable, FALSE);
 
@@ -320,7 +320,7 @@ static gint evt_name_changed(GtkWidget *wid, gpointer user)
 static gint evt_mode_clicked(GtkWidget *wid, gpointer user)
 {
 	P_Types	*page = user;
-	gint	index = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid)));
+	gint	index = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(wid), "user"));
 
 	if(page->curr_type == NULL)
 		return TRUE;
@@ -363,7 +363,7 @@ static gint evt_id_perm_clicked(GtkWidget *wid, gpointer user)
 		return TRUE;
 
 	page->modified = TRUE;
-	flag = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid)));
+	flag = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(wid), "user"));
 	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid)))
 		page->curr_type->perm |= flag;
 	else
@@ -376,7 +376,7 @@ static gint evt_id_perm_clicked(GtkWidget *wid, gpointer user)
 static gint evt_id_check_clicked(GtkWidget *wid, gpointer user)
 {
 	P_Types	*page = user;
-	gint	index = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid)));
+	gint	index = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(wid), "user"));
 	gint	iflags[] = { FTFL_REQSUFFIX, FTFL_NAMEMATCH, FTFL_FILEMATCH };
 	gint	state;
 
@@ -407,7 +407,7 @@ static gint evt_id_entry_changed(GtkWidget *wid, gpointer user)
 {
 	P_Types		*page = user;
 	const gchar	*text;
-	gint		index = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid)));
+	gint		index = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(wid), "user"));
 
 	if(page->curr_type == NULL)
 		return TRUE;
@@ -420,13 +420,13 @@ static gint evt_id_entry_changed(GtkWidget *wid, gpointer user)
 	switch(index)
 	{
 		case 0:
-			stu_strncpy(page->curr_type->suffix, text, sizeof page->curr_type->suffix);
+			g_strlcpy(page->curr_type->suffix, text, sizeof page->curr_type->suffix);
 			break;
 		case 1:
-			stu_strncpy(page->curr_type->name_re_src, text, sizeof page->curr_type->name_re_src);
+			g_strlcpy(page->curr_type->name_re_src, text, sizeof page->curr_type->name_re_src);
 			break;
 		case 2:
-			stu_strncpy(page->curr_type->file_re_src, text, sizeof page->curr_type->file_re_src);
+			g_strlcpy(page->curr_type->file_re_src, text, sizeof page->curr_type->file_re_src);
 			break;
 	}
 	return TRUE;
@@ -436,7 +436,7 @@ static gint evt_id_entry_changed(GtkWidget *wid, gpointer user)
 static gint evt_id_glob_changed(GtkWidget *wid, gpointer user)
 {
 	P_Types	*page = user;
-	gint	index = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid)));
+	gint	index = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(wid), "user"));
 	gint	flag[] = { 0, FTFL_NAMEGLOB, FTFL_FILEGLOB };
 
 	if(page->curr_type == NULL)
@@ -455,7 +455,7 @@ static gint evt_id_glob_changed(GtkWidget *wid, gpointer user)
 static gint evt_id_nocase_changed(GtkWidget *wid, gpointer user)
 {
 	P_Types	*page = user;
-	gint	index = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid)));
+	gint	index = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(wid), "user"));
 	gint	flag[] = { 0, FTFL_NAMENOCASE, FTFL_FILENOCASE };
 
 	if(page->curr_type == NULL)
@@ -501,7 +501,7 @@ static gint evt_style_clicked(GtkWidget *wid, gpointer user)
 static gint evt_add_clicked(GtkWidget *wid, gpointer user)
 {
 	P_Types	*page = user;
-	CfgInfo	*cfg  = gtk_object_get_user_data(GTK_OBJECT(wid));
+	CfgInfo	*cfg  = g_object_get_data(G_OBJECT(wid), "user");
 	FType	*tpe, *otpe;
 
 	if((tpe = typ_type_new(cfg, _("(New Type)"), S_IFREG, 0, NULL, NULL, NULL)) != NULL)
@@ -517,7 +517,7 @@ static gint evt_add_clicked(GtkWidget *wid, gpointer user)
 		{
 			/* Current selection exists; add after it. */
 			page->type = typ_type_insert(page->type, otpe, tpe);
-			gtk_list_store_insert_after(page->store, &oiter, &iter);
+			gtk_list_store_insert_after(page->store, &iter, &oiter);
 		}
 		else
 		{
@@ -677,7 +677,8 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 	page->ntable = gtk_table_new(2, 2, FALSE);
 	label = gtk_label_new(_("Name"));
 	gtk_table_attach(GTK_TABLE(page->ntable), label, 0, 1, 0, 1,  GTK_FILL,0,5,0);
-	page->name = gtk_entry_new_with_max_length(STL_STYLE_NAME_SIZE - 1);
+	page->name = gtk_entry_new();
+	gtk_entry_set_max_length(GTK_ENTRY(page->name), STL_STYLE_NAME_SIZE - 1);
 	gui_handler_group_connect(page->handlers, G_OBJECT(page->name), "changed", G_CALLBACK(evt_name_changed), page);
 	gtk_table_attach_defaults(GTK_TABLE(page->ntable), page->name, 1, 2, 0, 1);
 
@@ -694,7 +695,7 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 	for(i = 0; i < 7; i++)
 	{
 		gui_handler_group_connect(page->handlers, G_OBJECT(page->itype[i]), "clicked", G_CALLBACK(evt_mode_clicked), page);
-		gtk_object_set_user_data(GTK_OBJECT(page->itype[i]), GINT_TO_POINTER(i));
+		g_object_set_data(G_OBJECT(page->itype[i]), "user", GINT_TO_POINTER(i));
 		gtk_box_pack_start(GTK_BOX(page->ithbox), page->itype[i], TRUE, TRUE, 0);
 	}
 	gtk_table_attach(GTK_TABLE(page->itable), page->ithbox, 1, 3, 0, 1, GTK_EXPAND|GTK_FILL,0,0,0);
@@ -706,7 +707,7 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 	for(i = 0; i < 6; i++)
 	{
 		page->iperm[i] = gtk_toggle_button_new_with_label(_(iplab[i]));
-		gtk_object_set_user_data(GTK_OBJECT(page->iperm[i]), GINT_TO_POINTER(ifperm[i]));
+		g_object_set_data(G_OBJECT(page->iperm[i]), "user", GINT_TO_POINTER(ifperm[i]));
 		gui_handler_group_connect(page->handlers, G_OBJECT(page->iperm[i]), "clicked", G_CALLBACK(evt_id_perm_clicked), page);
 		gtk_box_pack_start(GTK_BOX(page->iphbox), page->iperm[i], TRUE, TRUE, 0);
 	}
@@ -720,12 +721,13 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 		y = (i == 2) ? i + 3 : i + 2;
 
 		page->ident[i].check = gtk_check_button_new_with_label(_(idlab[i]));
-		gtk_object_set_user_data(GTK_OBJECT(page->ident[i].check), GINT_TO_POINTER(i));
+		g_object_set_data(G_OBJECT(page->ident[i].check), "user", GINT_TO_POINTER(i));
 		gui_handler_group_connect(page->handlers, G_OBJECT(page->ident[i].check), "clicked", G_CALLBACK(evt_id_check_clicked), page);
 		gtk_table_attach(GTK_TABLE(page->itable), page->ident[i].check, 0, 1, y, y+1,  GTK_FILL,0,0,0);
 
-		page->ident[i].entry = gtk_entry_new_with_max_length(idmax[i] - 1);
-		gtk_object_set_user_data(GTK_OBJECT(page->ident[i].entry), GINT_TO_POINTER(i));
+		page->ident[i].entry = gtk_entry_new();
+		gtk_entry_set_max_length(GTK_ENTRY(page->ident[i].entry), idmax[i] - 1);
+		g_object_set_data(G_OBJECT(page->ident[i].entry), "user", GINT_TO_POINTER(i));
 		gui_handler_group_connect(page->handlers, G_OBJECT(page->ident[i].entry), "changed", G_CALLBACK(evt_id_entry_changed), page);
 		gtk_table_attach(GTK_TABLE(page->itable), page->ident[i].entry, 1, (i == 0) ? 3 : 2, y, y+1,  GTK_EXPAND | GTK_FILL,0,0,0);
 
@@ -735,12 +737,12 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 
 			hbox = gtk_hbox_new(FALSE, 0);
 			page->ident[i].glob = gtk_check_button_new_with_label(_("Glob?"));
-			gtk_object_set_user_data(GTK_OBJECT(page->ident[i].glob), GINT_TO_POINTER(i));
+			g_object_set_data(G_OBJECT(page->ident[i].glob), "user", GINT_TO_POINTER(i));
 			gui_handler_group_connect(page->handlers, G_OBJECT(page->ident[i].glob), "clicked", G_CALLBACK(evt_id_glob_changed), page);
 			gtk_box_pack_start(GTK_BOX(hbox), page->ident[i].glob, FALSE, FALSE, 0);
 
 			page->ident[i].nocase = gtk_check_button_new_with_label(_("Ignore Case?"));
-			gtk_object_set_user_data(GTK_OBJECT(page->ident[i].nocase), GINT_TO_POINTER(i));
+			g_object_set_data(G_OBJECT(page->ident[i].nocase), "user", GINT_TO_POINTER(i));
 			gui_handler_group_connect(page->handlers, G_OBJECT(page->ident[i].nocase), "clicked", G_CALLBACK(evt_id_nocase_changed), page);
 			gtk_box_pack_start(GTK_BOX(hbox), page->ident[i].nocase, FALSE, FALSE, 0);
 
@@ -772,7 +774,7 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 
 	page->bhbox = gtk_hbox_new(FALSE, 0);
 	page->add = gtk_button_new_with_label(_("Add"));
-	gtk_object_set_user_data(GTK_OBJECT(page->add), &min->cfg);
+	g_object_set_data(G_OBJECT(page->add), "user", &min->cfg);
 	g_signal_connect(G_OBJECT(page->add), "clicked", G_CALLBACK(evt_add_clicked), page);
 	gtk_box_pack_start(GTK_BOX(page->bhbox), page->add, TRUE, TRUE, 5);
 
