@@ -69,7 +69,7 @@ static void evt_dialog_position_toggled(GtkWidget *wid, gpointer user)
 		P_Windows	*page = user;
 		gint		pos;
 
-		pos = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(wid), "pos"));
+		pos = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(wid), "pos"));
 		if(pos != page->dialog_pos)
 		{
 			page->dialog_pos = pos;
@@ -120,11 +120,11 @@ static GtkWidget * cwn_init(MainInfo *min, gchar **name)
 	for(i = 0; i < sizeof dlab / sizeof *dlab; i++)
 	{
 		page->dpos[i] = gtk_radio_button_new_with_label(group, _(dlab[i]));
-		gtk_object_set_data(GTK_OBJECT(page->dpos[i]), "pos", GINT_TO_POINTER(dpos[i]));
+		g_object_set_data(G_OBJECT(page->dpos[i]), "pos", GINT_TO_POINTER(dpos[i]));
 		g_signal_connect(G_OBJECT(page->dpos[i]), "toggled", G_CALLBACK(evt_dialog_position_toggled), page);
 		if(dpos[i] == min->cfg.dialogs.pos)
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->dpos[i]), TRUE);
-		group = gtk_radio_button_group(GTK_RADIO_BUTTON(page->dpos[i]));
+		group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(page->dpos[i]));
 		gtk_box_pack_start(GTK_BOX(vbox), page->dpos[i], FALSE, FALSE, 0);
 	}
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
