@@ -2,4 +2,4 @@
 ** 1998-10-15 -	Header for the size & position config module.
 */
 
-extern CfgPage*	cwn_describe(MainInfo *min);
+extern const CfgModule *	cwn_describe(MainInfo *min);
