@@ -13,7 +13,7 @@
 
 extern gboolean	chd_initialize(MainInfo *min);
 
-extern void	chd_register(const gchar *prog, pid_t pid, guint32 gflags, guint32 aflags);
+extern void	chd_register(const gchar *prog, GPid pid, guint32 gflags, guint32 aflags);
 
 extern void	chd_set_running(CmdSeq *cs, guint index);
 extern CmdSeq *	chd_get_running(guint *index);
