@@ -108,6 +108,9 @@ static gboolean copy_gfile_special(MainInfo *min, DirPane *src, DirPane *dst, GF
 		}
 		g_free(path);
 	}
+	else
+		g_set_error(err, g_io_error_quark(), G_IO_ERROR_FAILED, _("Error copying special file: no local path"));
+
 	g_object_unref(fi);
 
 	return ok;
