@@ -11,6 +11,7 @@
 #include "gentoo.h"
 #include "dirpane.h"
 #include "errors.h"
+#include "guiutil.h"
 #include "overwrite.h"
 #include "progress.h"
 #include "strutil.h"
@@ -198,7 +199,7 @@ static gint copyas_or_clone(MainInfo *min, DirPane *src, DirPane *dst, CpaAction
 
 	cpa.vbox = gtk_vbox_new(FALSE, 0);
 	cpa.label = gtk_label_new(_("Copy As"));
-	cpa.entry = gtk_entry_new();
+	cpa.entry = gui_dialog_entry_new();
 	gtk_entry_set_max_length(GTK_ENTRY(cpa.entry), FILENAME_MAX - 1);
 	gtk_box_pack_start(GTK_BOX(cpa.vbox), cpa.label, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(cpa.vbox), cpa.entry, FALSE, FALSE, 0);
