@@ -19,8 +19,8 @@
 #include "fileutil.h"
 #include "gfam.h"
 #include "guiutil.h"
-#include "mount.h"
 #include "strutil.h"
+#include "userinfo.h"
 
 #include "cmd_parent.h"
 #include "cmd_direnter.h"
@@ -31,25 +31,37 @@
 
 /* 1999-05-07 -	Get the name of the first selected row of <dp>. If that is not a directory,
 **		report error to user and return NULL.
+** 2010-03-04 -	Now returns the URI of the first selected directory, which is a bit more GIO.
 */
-static const gchar * get_selected_dir(DirPane *dp)
+static gboolean get_selected_dir(DirPane *dp, gchar *buf, gsize buf_max)
 {
-	const gchar	*dir = NULL;
 	GSList		*slist;
+	gboolean	ok = FALSE;
 
+	/* FIXME: This is kind of wasteful. Maybe invent some dp_get_selection_first() function? */
 	if((slist = dp_get_selection(dp)) != NULL)
 	{
-		if(S_ISDIR(DP_SEL_STAT(slist).st_mode))
+		if(dp_row_get_file_type(dp_get_tree_model(dp), slist->data, TRUE) == G_FILE_TYPE_DIRECTORY)
 		{
-			errno = 0;
-			dir = dp_full_name(dp, DP_SEL_INDEX(dp, slist));
-			dp_unselect(dp, DP_SEL_INDEX(dp, slist));
+			GFile	*file;
+
+			if((file = dp_get_file_from_row(dp, slist->data)) != NULL)
+			{
+				gchar	*uri = g_file_get_uri(file);
+
+				if(uri != NULL)
+				{
+					ok = (g_strlcpy(buf, uri, buf_max) < buf_max);
+					if(ok)
+						dp_unselect(dp, slist->data);
+					g_free(uri);
+				}
+				g_object_unref(file);
+			}
 		}
-		else
-			errno = ENOTDIR;
 		dp_free_selection(slist);
 	}
-	return dir;
+	return ok;
 }
 
 /* 1999-05-07 -	Rewrote this, now supports a "dir" command argument.
@@ -58,58 +70,47 @@ static const gchar * get_selected_dir(DirPane *dp)
 gint cmd_direnter(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
 	const gchar	*dir;
+	gchar		uri[URI_MAX] = "";
+	guint		index;
+	gboolean	ok = FALSE;
 
 	if((dir = car_bareword_get(ca, 0)) == NULL)
 		dir = car_keyword_get_value(ca, "dir", NULL);
-	if(dir == NULL)
-		dir = get_selected_dir(src);
-
 	if(dir != NULL)
 	{
-		gchar	buf[PATH_MAX] = "";
-		guint	index;
-
 		if(sscanf(dir, "@history[%u]", &index) == 1)	/* Access history buffer? */
 		{
 			dir = dph_dirhistory_get_entry(src->hist, index);
 			if(dir == NULL)
-				dir = "";
-		}
-
-		if((dir[0] == G_DIR_SEPARATOR) || (dir[0] == '~'))	/* Absolute? */
-			stu_strncpy(buf, dir, sizeof buf);
-		else
-		{
-			if(src->dir.path[0] == '\0')
-				stu_strncpy(buf, dir, sizeof buf);
-			else if((src->dir.path[0] == G_DIR_SEPARATOR) && (src->dir.path[1] == '\0'))
-				g_snprintf(buf, sizeof buf, "%c%s", G_DIR_SEPARATOR, dir);
-			else
-				g_snprintf(buf, sizeof buf, "%s%c%s", src->dir.path, G_DIR_SEPARATOR, dir);
-		}
-		err_clear(min);
-		fut_interpolate(buf);
-		dph_state_save(src);
-		dp_freeze(src);
-		if(dp_enter_dir(src, buf))
-		{
-			dp_redisplay(src);
-			/* Annoying hacky code to get GTK+ to resize the pane before we restore
-			** the history state; if not resized, vpos setting will likely fail.
-			*/
-			gtk_widget_queue_resize(GTK_WIDGET(src->list));
-			gui_events_flush();
-			dph_state_restore(src);
-			dp_focus_enter_dir(src);
-			dp_show_stats(src);
-			fam_monitor(src);
-		}
-		dp_thaw(src);
-		if(errno != 0)
-		{
-			err_set(min, errno, CMD_ID, buf);
-			err_show(min);
+				dir = usr_get_home();
 		}
+		if(dir != NULL)
+			ok = g_strlcpy(uri, dir, sizeof uri) < sizeof uri;
 	}
-	return (dir != NULL) && (errno == 0);
+	if(!ok)
+		ok = get_selected_dir(src, uri, sizeof uri);
+	if(!ok)
+	{
+		g_warning("** cmd_direnter() exhausted known ways to get a directory--aborting");
+		return 0;
+	}
+
+	fut_interpolate(uri);
+	dph_state_save(src);
+	if(dp_enter_dir(src, uri))
+	{
+		/* Annoying hacky code to get GTK+ to resize the pane before we restore
+		** the history state; if not resized, vpos setting will likely fail.
+		*/
+		gtk_widget_queue_resize(GTK_WIDGET(src->view));
+		gui_events_flush();
+		dph_state_restore(src);
+		dp_focus_enter_dir(src);
+		dp_show_stats(src);
+		fam_monitor(src);
+		return 1;
+	}
+	g_warning("** Pane #%d failed to enter '%s'", src->index, uri);
+
+	return 0;
 }
