@@ -16,16 +16,12 @@
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* 2002-07-19 -	Rescan source directory. */
+/* 2002-07-19 -	Rescan source directory.
+** 2010-03-04 -	Removed all pretense that this does error detection or reporting.
+*/
 gint cmd_dirrescan(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
-	err_clear(min);
-	dp_rescan(src);
+	dp_rescan(src);		/* FIXME: There ought to be a way for this to report failure. */
 	dp_show_stats(src);
-	if(errno)
-	{
-		err_set(min, errno, CMD_ID, src->dir.path);
-		err_show(min);
-	}
-	return errno == 0;
+	return 1;
 }
