@@ -39,47 +39,43 @@ static CmdCfg		*getsize_cmc = NULL;
 */
 gint cmd_getsize(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
-	GSList	*slist, *iter;
-	guint	num = 0;
-	FUCount	fuc;
+	GtkTreeModel	*m = dp_get_tree_model(src);
+	GSList		*slist, *iter;
+	guint		num = 0;
+	FUCount		fuc;
+	gboolean	ok = TRUE;
+	GError		*err = NULL;
 
-	err_clear(min);
 	if((slist = dp_get_selection(src)) == NULL)
 		return 1;
 	pgs_progress_begin(min, _("Getting sizes..."), PFLG_BUSY_MODE);
-	for(iter = slist; iter != NULL; iter = g_slist_next(iter))
+	for(iter = slist; ok && (iter != NULL); iter = g_slist_next(iter))
 	{
-		if(S_ISDIR(DP_SEL_LSTAT(iter).st_mode))
+		if(dp_row_get_file_type(m, iter->data, TRUE) == G_FILE_TYPE_DIRECTORY)
 		{
-			if(fut_dir_size_progress(min, dp_full_name(src, DP_SEL_INDEX(src, iter)), NULL, &fuc))
+			GFile	*here = dp_get_file_from_row(src, iter->data);
+
+			if((ok = fut_size_gfile(min, here, NULL, &fuc, &err)))
 			{
-				DP_SEL_LSTAT(iter).st_size   = fuc.num_bytes;
-				DP_SEL_LSTAT(iter).st_blocks = fuc.num_blocks;
-				DP_SEL_FLAGS_SET(iter, DPRF_HAS_SIZE);
+				dp_row_set_size(m, iter->data, fuc.num_bytes);
+				dp_row_set_flag(m, iter->data, DPRF_HAS_SIZE);
 				num++;
+				if(getsize_options.unselect)
+					dp_unselect(src, iter->data);
 			}
 			else
-				break;
+				err_set_gerror(min, &err, CMD_ID, here);
 		}
-		if(getsize_options.unselect)
-			dp_unselect(src, DP_SEL_INDEX(src, iter));
 	}
 	pgs_progress_end(min);
+	dp_free_selection(slist);
 
 	if(num)
 	{
 		dp_update_stats(src);
-		dp_redisplay_preserve(src);
+		dp_show_stats(src);
 	}
-	if(errno)
-		err_set(min, errno, CMD_ID, iter ? DP_SEL_NAME(iter) : NULL);
-	else
-		err_clear(min);
-	err_show(min);
-
-	dp_free_selection(slist);
-
-	return 1;
+	return ok;
 }
 
 /* ----------------------------------------------------------------------------------------- */
@@ -89,41 +85,38 @@ gint cmd_getsize(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 */
 gint cmd_clearsize(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
-	GSList	*slist, *iter;
-	guint	num = 0U;
+	GtkTreeModel	*m = dp_get_tree_model(src);
+	GSList		*slist, *iter;
+	guint		num = 0;
+	GError		*err = NULL;
+	gboolean	ok = TRUE;
 
 	if((slist = dp_get_selection(src)) == NULL)
 		return 1;
 
-	for(iter = slist; iter != NULL; iter = g_slist_next(iter))
+	for(iter = slist; ok && (iter != NULL); iter = g_slist_next(iter))
 	{
-		if(S_ISDIR(DP_SEL_LSTAT(iter).st_mode) && DP_SEL_FLAGS_CHK(iter, DPRF_HAS_SIZE))
+		if(dp_row_get_file_type(m, iter->data, TRUE) == G_FILE_TYPE_DIRECTORY && dp_row_get_flags(m, iter->data, DPRF_HAS_SIZE))
 		{
-			const gchar	*name = dp_full_name(src, DP_SEL_INDEX(src, iter));
-
-			if(lstat(name, &DP_SEL_LSTAT(iter)))
-				break;
-			DP_SEL_FLAGS_CLR(iter, DPRF_HAS_SIZE);
+			/* Now, we need to re-scan the file's info, and replace it in the model. Interesting, but
+			** clearly a nitty job that needs to be done inside the dirpane module, not inline here.
+			*/
+			ok = dp_rescan_row(src, iter->data, &err);
+			if(!ok)
+				err_set_gerror(min, &err, CMD_ID2, dp_get_file_from_row(src, iter->data));
 			num++;
 		}
 		if(getsize_options.unselect)
-			dp_unselect(src, DP_SEL_INDEX(src, iter));
+			dp_unselect(src, iter->data);
 	}
+	dp_free_selection(slist);
 
 	if(num)
 	{
 		dp_update_stats(src);
-		dp_redisplay_preserve(src);
+		dp_show_stats(src);
 	}
-	if(errno)
-		err_set(min, errno, CMD_ID2, iter ? DP_SEL_NAME(iter) : NULL);
-	else
-		err_clear(min);
-	err_show(min);
-
-	dp_free_selection(slist);
-
-	return 1;
+	return ok;
 }
 
 /* ----------------------------------------------------------------------------------------- */
