@@ -23,8 +23,9 @@
 */
 static void func_position(GtkMenu *menu, gint *x, gint *y, gboolean *push, gpointer data)
 {
+#if 0
 	MainInfo	*min = data;
-	GtkCList	*cp = min->gui->cur_pane->list;
+	GtkCList	*cp = min->gui->cur_pane->view;
 	gint		wx, wy, px, py, pw, ph, fr;
 
 	gdk_window_get_position(min->gui->window->window, &wx, &wy);
@@ -40,6 +41,8 @@ static void func_position(GtkMenu *menu, gint *x, gint *y, gboolean *push, gpoin
 		*x = (wx + px) + pw / 2;
 		*y = (wy + py) + ph / 2;
 	}
+#endif
+	g_warning("Menu popup pane positioning not implemented");
 }
 
 /* 2000-04-09 -	Pop up the dirpane menu for the current pane. Now also works if bound to a
@@ -64,3 +67,4 @@ gint cmd_menupopup(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		pos = func_position;
 	return mnu_menu_popup(min->cfg.menus, name, pos, min, button, ac_time);
 }
+
