@@ -18,6 +18,7 @@
 #include "dirpane.h"
 #include "errors.h"
 #include "gfam.h"
+#include "guiutil.h"
 #include "overwrite.h"
 #include "strutil.h"
 
@@ -118,7 +119,7 @@ gint cmd_mkdir(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	mi.vbox = gtk_vbox_new(FALSE, 0);
 	wid = gtk_label_new(_("Enter Name of Directory to Create"));
 	gtk_box_pack_start(GTK_BOX(mi.vbox), wid, FALSE, FALSE, 0);
-	mi.entry = gtk_entry_new();
+	mi.entry = gui_dialog_entry_new();
 	gtk_entry_set_max_length(GTK_ENTRY(mi.entry), MAXNAMLEN - 1);
 	gtk_box_pack_start(GTK_BOX(mi.vbox), mi.entry, FALSE, FALSE, 0);
 	wid = cmc_field_build(mkdir_cmc, "cd_new", &mkdir_options);
