@@ -5,11 +5,12 @@
 */
 
 #include "gentoo.h"
+#include "dirpane.h"
 #include "errors.h"
 #include "fileutil.h"
+#include "guiutil.h"
 #include "overwrite.h"
 #include "progress.h"
-#include "dirpane.h"
 #include "strutil.h"
 
 #include "cmd_move.h"
@@ -103,7 +104,7 @@ gint cmd_moveas(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 
 	mva.vbox = gtk_vbox_new(FALSE, 0);
 	mva.label = gtk_label_new(_("Move As"));
-	mva.entry = gtk_entry_new();
+	mva.entry = gui_dialog_entry_new();
 	gtk_entry_set_max_length(GTK_ENTRY(mva.entry), FILENAME_MAX - 1);
 	gtk_box_pack_start(GTK_BOX(mva.vbox), mva.label, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(mva.vbox), mva.entry, FALSE, FALSE, 0);
