@@ -13,13 +13,16 @@
 #include "gentoo.h"
 #include "cmd_delete.h"
 #include "cmdseq_config.h"
-#include "errors.h"
 #include "dirpane.h"
+#include "errors.h"
+#include "guiutil.h"
 #include "overwrite.h"
 
 #include "cmd_generic.h"
 #include "cmd_rename.h"
 
+#include <gdk/gdkkeysyms.h>
+
 #define	CMD_ID	"rename"
 
 /* ----------------------------------------------------------------------------------------- */
@@ -37,9 +40,17 @@ typedef struct {
 	gboolean	inplace_success;
 } RenInfo;
 
+typedef enum {
+	PRESELECT_NONE = 0,
+	PRESELECT_FULL,
+	PRESELECT_NAME_ONLY,
+	PRESELECT_EXTENSION_ONLY
+} RenamePreselect;
+
 typedef struct {			/* Options used by the "Rename" command. */
 	gboolean	modified;
 	gboolean	single_in_place;
+	RenamePreselect	preselect;
 } OptRename;
 
 static OptRename	rename_options;
@@ -47,6 +58,102 @@ static CmdCfg		*rename_cmc = NULL;
 
 /* ----------------------------------------------------------------------------------------- */
 
+/* Guess (!) which preselection mode is active in the given editable. */
+static RenamePreselect guess_preselect(GtkEditable *editable)
+{
+	gint	start, end;
+
+	if(gtk_editable_get_selection_bounds(editable, &start, &end))
+	{
+		/* We have a selection; grab the characters and inspect. */
+		gchar	*chars = gtk_editable_get_chars(editable, 0, -1);
+
+		if(chars != NULL)
+		{
+			const glong	len = g_utf8_strlen(chars, -1);
+			RenamePreselect	ret = PRESELECT_NONE;
+			
+			/* Entire string selected? */
+			if(start == 0 && end == len)
+				ret = PRESELECT_FULL;
+			/* Anchored to beginning, ends exactly with period? */
+			else if(start == 0 && end < len && *g_utf8_offset_to_pointer(chars, end) == '.')
+				ret = PRESELECT_NAME_ONLY;
+			/* Anchored to end, starts right after period? */
+			else if(end == len && start > 0 && *g_utf8_offset_to_pointer(chars, start - 1) == '.')
+				ret = PRESELECT_EXTENSION_ONLY;
+			g_free(chars);
+
+			return ret;
+		}
+	}
+	return PRESELECT_NONE;
+}
+
+/* Apply the indicated pre-selection. */
+static void apply_preselect(GtkEditable *editable, const gchar *name, RenamePreselect mode)
+{
+	gpointer	dot_ptr;
+	gulong		dot_pos;
+
+	switch(mode)
+	{
+		case PRESELECT_NONE:
+			/* Rather unexpectedly, we must do this or else GTK+ selects all. */
+			gtk_editable_select_region(editable, 0, 0);
+			break;
+		case PRESELECT_FULL:
+			gtk_editable_select_region(editable, 0, -1);
+			break;
+		case PRESELECT_NAME_ONLY:
+		case PRESELECT_EXTENSION_ONLY:
+			if((dot_ptr = g_utf8_strchr(name, -1, '.')) != NULL)
+			{
+				dot_pos = g_utf8_pointer_to_offset(name, dot_ptr);
+				if(mode == PRESELECT_NAME_ONLY)
+					gtk_editable_select_region(editable, 0, dot_pos);
+				else
+					gtk_editable_select_region(editable, dot_pos + 1, -1);
+			}
+			break;
+	}
+}
+
+/* Keypress handler for whatever widget hosts the renaming. */
+static gboolean evt_rename_keypress(GtkWidget *wid, GdkEvent *evt, gpointer user)
+{
+	const GdkEventKey	*ke = &evt->key;
+
+	/* Hard-coded (control-period) shortcut to cycle selection. Pretty cool. */
+	if(ke->type == GDK_KEY_PRESS && ke->state & GDK_CONTROL_MASK && ke->keyval == GDK_KEY_period)
+	{
+		const RenamePreselect	mode = guess_preselect(GTK_EDITABLE(wid));
+		RenamePreselect		new_mode;
+		gchar			*chars;
+
+		if(mode == PRESELECT_EXTENSION_ONLY)
+			new_mode = PRESELECT_NONE;
+		else
+			new_mode = mode + 1;
+
+		/* Slightly iffy to re-allocate for the chars, but think of the frequency, here. */
+		if((chars = gtk_editable_get_chars(GTK_EDITABLE(wid), 0, -1)) != NULL)
+		{
+			apply_preselect(GTK_EDITABLE(wid), chars, new_mode);
+			g_free(chars);
+		}
+		return TRUE;
+	}
+	return FALSE;
+}
+
+/* Apply the configured preselection-mode. */
+static void init_preselect(GtkEditable *editable, const gchar *name, RenamePreselect mode)
+{
+	g_signal_connect(G_OBJECT(editable), "key_press_event", G_CALLBACK(evt_rename_keypress), NULL);
+	apply_preselect(editable, name, mode);
+}
+
 static void ren_body(MainInfo *min, DirPane *src, DirRow2 *row, gpointer gen, gpointer user)
 {
 	gchar		temp[PATH_MAX + 256];
@@ -57,8 +164,8 @@ static void ren_body(MainInfo *min, DirPane *src, DirRow2 *row, gpointer gen, gp
 	g_snprintf(temp, sizeof temp, _("Enter New Name For \"%s\""), name);
 	gtk_label_set_text(GTK_LABEL(ren->label), temp);
 	gtk_entry_set_text(GTK_ENTRY(ren->entry), name);
-	gtk_editable_select_region(GTK_EDITABLE(ren->entry), 0, strlen(name));
 	gtk_widget_grab_focus(ren->entry);
+	init_preselect(GTK_EDITABLE(ren->entry), name, rename_options.preselect);
 
 	cmd_generic_track_entry(gen, ren->entry);
 
@@ -139,6 +246,16 @@ static void ren_free(gpointer user)
 
 /* ----------------------------------------------------------------------------------------- */
 
+/* 2011-06-29 -	Cell editing started. We would like to just call do_preselect() here, but GTK+ seems to
+**		also have ideas about the selection of the newly editing-enabled cell renderer. So we just
+**		sneakily buffer the pointer, and hack it later. This is not pretty, but it seems to work.
+*/
+static void evt_cell_editing_started(GtkCellRenderer *cr, GtkCellEditable *editable, gchar *path, gpointer user)
+{
+	if(GTK_IS_EDITABLE(editable))
+		*(GtkEditable **) user = GTK_EDITABLE(editable);
+}
+
 /* 2011-01-03 -	When editing ends, try to do the rename. */
 static void evt_cell_edited(GtkCellRendererText *renderer, gchar *path, gchar *new_text, gpointer user)
 {
@@ -178,6 +295,7 @@ gint cmd_rename(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		GtkTreePath		*path;
 		GList			*cells;
 		GtkCellRenderer		*cr;
+		GtkEditable		*editable = NULL;
 
 		ri.inplace_pane = src;
 		ri.inplace_error = NULL;
@@ -206,6 +324,8 @@ gint cmd_rename(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		g_object_set(G_OBJECT(cr), "mode", GTK_CELL_RENDERER_MODE_EDITABLE, "editable", TRUE, "editable-set", TRUE, NULL);
 
 		/* Make sure the signal handler is connected, but only once. */
+		g_signal_handlers_disconnect_by_func(G_OBJECT(cr), G_CALLBACK(evt_cell_editing_started), &ri);
+		g_signal_connect(G_OBJECT(cr), "editing-started", G_CALLBACK(evt_cell_editing_started), &editable);
 		g_signal_handlers_disconnect_by_func(G_OBJECT(cr), G_CALLBACK(evt_cell_edited), &ri);
 		g_signal_connect(G_OBJECT(cr), "edited", G_CALLBACK(evt_cell_edited), &ri);
 		g_signal_handlers_disconnect_by_func(G_OBJECT(cr), G_CALLBACK(evt_cell_editing_canceled), &ri);
@@ -220,6 +340,18 @@ gint cmd_rename(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 
 			/* Detach the keyboard acceleration context to prevent clashes. */
 			kbd_context_detach(min->gui->kbd_ctx, GTK_WINDOW(min->gui->window));
+
+			/* This got set by the the evt_cell_editing_started() callback, now apply preselection. */
+			if(editable != NULL)
+			{
+				gchar	*text;
+
+				if((text = gtk_editable_get_chars(GTK_EDITABLE(editable), 0, -1)) != NULL)
+				{
+					init_preselect(GTK_EDITABLE(editable), text, rename_options.preselect);
+					g_free(text);
+				}
+			}
 			/* Recurse, so we keep Rename fully synchronous. */
 			gtk_main();
 
@@ -237,7 +369,7 @@ gint cmd_rename(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		ri.ovw_open = FALSE;
 		ri.vbox	    = gtk_vbox_new(FALSE, 0);
 		ri.label    = gtk_label_new("");
-		ri.entry    = gtk_entry_new();
+		ri.entry    = gui_dialog_entry_new();
 		gtk_entry_set_max_length(GTK_ENTRY(ri.entry), MAXNAMLEN - 1);
 		gtk_box_pack_start(GTK_BOX(ri.vbox), ri.label, FALSE, FALSE, 0);
 		gtk_box_pack_start(GTK_BOX(ri.vbox), ri.entry, FALSE, FALSE, 0);
@@ -255,10 +387,12 @@ void cfg_rename(MainInfo *min)
 		/* Set the default values for module's options. */
 		rename_options.modified = FALSE;
 		rename_options.single_in_place = FALSE;
+		rename_options.preselect = PRESELECT_FULL;
 
 		rename_cmc = cmc_config_new("Rename", &rename_options);
 		cmc_field_add_boolean(rename_cmc, "modified", NULL, offsetof(OptRename, modified));
 		cmc_field_add_boolean(rename_cmc, "inplace", _("Rename Single File In-Place (Without Dialog)?"), offsetof(OptRename, single_in_place));
+		cmc_field_add_enum(rename_cmc, "preselect", _("Automatically Pre-Select"), offsetof(OptRename, preselect), _("None|Entire Name|Filename Only|Extension Only"));
 		cmc_config_register(rename_cmc);
 	}
 }
