@@ -21,6 +21,7 @@
 #include "dialog.h"
 #include "dirpane.h"
 #include "errors.h"
+#include "guiutil.h"
 #include "overwrite.h"
 #include "strutil.h"
 
@@ -421,11 +422,11 @@ gint cmd_renamere(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		table = gtk_table_new(2, 2, FALSE);
 		label = gtk_label_new(_("Replace"));
 		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
-		ri.r_from = gtk_entry_new();
+		ri.r_from = gui_dialog_entry_new();
 		gtk_table_attach(GTK_TABLE(table), ri.r_from, 1, 2, 0, 1, GTK_EXPAND|GTK_FILL,0,0,0);
 		label = gtk_label_new(_("With"));
 		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,  0,0,0,0);
-		ri.r_to = gtk_entry_new();
+		ri.r_to = gui_dialog_entry_new();
 		gtk_table_attach(GTK_TABLE(table), ri.r_to, 1, 2, 1, 2, GTK_EXPAND|GTK_FILL,0,0,0);
 		gtk_box_pack_start(GTK_BOX(ri.r_vbox), table, FALSE, FALSE, 0);
 		table = gtk_table_new(1, 2, FALSE);
@@ -449,11 +450,11 @@ gint cmd_renamere(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		table = gtk_table_new(2, 2, FALSE);
 		label = gtk_label_new(_("From"));
 		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
-		ri.re_from = gtk_entry_new();
+		ri.re_from = gui_dialog_entry_new();
 		gtk_table_attach(GTK_TABLE(table), ri.re_from, 1, 2, 0, 1,  GTK_EXPAND|GTK_FILL,0,0,0);
 		label = gtk_label_new(_("To"));
 		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,  0,0,0,0);
-		ri.re_to = gtk_entry_new();
+		ri.re_to = gui_dialog_entry_new();
 		gtk_table_attach(GTK_TABLE(table), ri.re_to, 1, 2, 1, 2,  GTK_EXPAND|GTK_FILL,0,0,0);
 		gtk_box_pack_start(GTK_BOX(ri.re_vbox), table, FALSE, FALSE, 0);
 		ri.re_cnocase = gtk_check_button_new_with_label(_("Ignore Case?"));
@@ -472,15 +473,15 @@ gint cmd_renamere(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		table = gtk_table_new(3, 2, FALSE);
 		label = gtk_label_new(_("From"));
 		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
-		ri.map_from = gtk_entry_new();
+		ri.map_from = gui_dialog_entry_new();
 		gtk_table_attach(GTK_TABLE(table), ri.map_from, 1, 2, 0, 1,  GTK_EXPAND|GTK_FILL,0,0,0);
 		label = gtk_label_new(_("To"));
 		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,  0,0,0,0);
-		ri.map_to = gtk_entry_new();
+		ri.map_to = gui_dialog_entry_new();
 		gtk_table_attach(GTK_TABLE(table), ri.map_to, 1, 2, 1, 2,  GTK_EXPAND|GTK_FILL,0,0,0);
 		label = gtk_label_new(_("Remove"));
 		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3,  0,0,0,0);
-		ri.map_remove = gtk_entry_new();
+		ri.map_remove = gui_dialog_entry_new();
 		gtk_table_attach(GTK_TABLE(table), ri.map_remove, 1, 2, 2, 3,  GTK_EXPAND|GTK_FILL,0,0,0);
 		gtk_box_pack_start(GTK_BOX(ri.map_vbox), table, FALSE, FALSE, 0);
 		gtk_notebook_append_page(GTK_NOTEBOOK(ri.nbook), ri.map_vbox, gtk_label_new(_("Map")));
