@@ -19,6 +19,7 @@
 #include "dirpane.h"
 #include "errors.h"
 #include "fileutil.h"
+#include "guiutil.h"
 #include "overwrite.h"
 #include "strutil.h"
 
@@ -339,14 +340,14 @@ gint cmd_renameseq(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 
 	label = gtk_label_new(_("Head"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3,  0,0,0,0);
-	dlg.head = gtk_entry_new();
+	dlg.head = gui_dialog_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(dlg.head), rsi.head->str);
 	g_signal_connect(G_OBJECT(dlg.head), "changed", G_CALLBACK(evt_something_changed), &dlg);
 	gtk_table_attach(GTK_TABLE(table), dlg.head, 1, 3, 2, 3,  GTK_EXPAND|GTK_FILL,0,0,0);
 
 	label = gtk_label_new(_("Tail"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 3, 4,  0,0,0,0);
-	dlg.tail = gtk_entry_new();
+	dlg.tail = gui_dialog_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(dlg.tail), rsi.tail->str);
 	g_signal_connect(G_OBJECT(dlg.tail), "changed", G_CALLBACK(evt_something_changed), &dlg);
 	gtk_table_attach(GTK_TABLE(table), dlg.tail, 1, 3, 3, 4,  GTK_EXPAND|GTK_FILL,0,0,0);
@@ -357,7 +358,7 @@ gint cmd_renameseq(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 
 	label = gtk_label_new(_("Preview"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 4, 5,  0,0,0,0);
-	dlg.preview = gtk_entry_new();
+	dlg.preview = gui_dialog_entry_new();
 	gtk_editable_set_editable(GTK_EDITABLE(dlg.preview), FALSE);
 	gtk_table_attach(GTK_TABLE(table), dlg.preview, 1, 4, 4, 5,  GTK_EXPAND|GTK_FILL,0,0,5);
 
