@@ -479,7 +479,7 @@ gint cmd_selectre(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(nocase), sp.nocase);
 		gtk_box_pack_start(GTK_BOX(vbox), nocase, FALSE, FALSE, 0);
 
-		re = gtk_entry_new();
+		re = gui_dialog_entry_new();
 		if(sp.re != NULL)
 		{
 			gtk_entry_set_text(GTK_ENTRY(re), sp.re->str);
@@ -723,7 +723,7 @@ gint cmd_selectshell(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca
 		selparam_init_menus(src, vbox, opt_menu, mptr);
 		label = gtk_label_new(_("Enter shell command to run. The command\nwill have the selected content appended.\nAction is performed on successful exit."));
 		gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
-		entry = gtk_entry_new();
+		entry = gui_dialog_entry_new();
 		gtk_entry_set_max_length(GTK_ENTRY(entry), 1024);
 		if(sp.cmd != NULL)
 			gtk_entry_set_text(GTK_ENTRY(entry), sp.cmd->str);
