@@ -598,7 +598,7 @@ gint cmd_split(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	spi.nhbox = gtk_hbox_new(FALSE, 0);
 	label = gtk_label_new(_("Name Format"));
 	gtk_box_pack_start(GTK_BOX(spi.nhbox), label, FALSE, FALSE, 2);
-	spi.nformat = gtk_entry_new();
+	spi.nformat = gui_dialog_entry_new();
 	gtk_entry_set_max_length(GTK_ENTRY(spi.nformat), NFORMAT_LIMIT);
 	g_signal_connect(G_OBJECT(gtk_entry_get_buffer(GTK_ENTRY(spi.nformat))), "inserted_text", G_CALLBACK(evt_nformat_insert), &spi);
 	g_signal_connect(G_OBJECT(gtk_entry_get_buffer(GTK_ENTRY(spi.nformat))), "deleted_text", G_CALLBACK(evt_nformat_delete), &spi);
