@@ -21,18 +21,15 @@
 **		path is displayed in a combo, and not a plain GtkEntry. Far less efficient
 **		now, though. Too bad.
 ** 2008-09-22 -	Changes for new path entry widget in GTK+ 2.0.
+** 2010-03-27 -	Totally stopped trying to be efficient, since it's hard to swap GtkTreeModels.
 */
 gint cmd_swap(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
-	DirContents	tmp;
+	gchar	tmp[sizeof src->dir.path];
 
-	tmp = src->dir;
-	src->dir = dst->dir;
-	dst->dir = tmp;
-	dp_redisplay_preserve(src);
-	dph_state_restore(src);
-	dp_redisplay_preserve(dst);
-	dph_state_restore(dst);
+	g_strlcpy(tmp, src->dir.path, sizeof tmp);
+	dp_enter_dir(src, dst->dir.path);
+	dp_enter_dir(dst, tmp);
 
 	return 1;
 }
@@ -58,11 +55,9 @@ static void get_selection(DirPane *dst, DirPane *src)
 /* 1998-08-27 -	Go to the same directory as the other (i.e. destination) pane. */
 gint cmd_fromother(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
-	dp_freeze(src);
 	dp_unselect_all(src);
 	csq_execute_format(min, "DirEnter 'dir=%s'", stu_escape(dst->dir.path));
 	get_selection(src, dst);
-	dp_thaw(src);
 
 	return 1;
 }
@@ -70,13 +65,11 @@ gint cmd_fromother(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 /* 1998-09-20 -	Added this to complement the old DirOther command, which was also renamed. */
 gint cmd_toother(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
-	dp_freeze(dst);
 	dp_unselect_all(dst);
 	csq_execute(min, "ActivateOther");
 	csq_execute_format(min, "DirEnter 'dir=%s'", stu_escape(src->dir.path));
 	csq_execute(min, "ActivateOther");
 	get_selection(dst, src);
-	dp_thaw(dst);
 
 	return 1;
 }
