@@ -212,12 +212,12 @@ gint cmd_symlinkedit(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca
 	table = gtk_table_new(2, 3, FALSE);
 	label = gtk_label_new(_("Name"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
-	sle.name = gtk_entry_new();
+	sle.name = gui_dialog_entry_new();
 	gtk_entry_set_max_length(GTK_ENTRY(sle.name), FILENAME_MAX - 1);
 	gtk_table_attach(GTK_TABLE(table), sle.name, 1, 3, 0, 1,  GTK_EXPAND|GTK_FILL,0,0,0);
 	label = gtk_label_new(_("Contents"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,  0,0,0,0);
-	sle.contents = gtk_entry_new();
+	sle.contents = gui_dialog_entry_new();
 	gtk_entry_set_max_length(GTK_ENTRY(sle.contents), PATH_MAX - 1);
 	gtk_table_attach(GTK_TABLE(table), sle.contents, 1, 2, 1, 2,  GTK_EXPAND|GTK_FILL,0,0,0);
 	pick = gui_details_button_new();
