@@ -93,11 +93,10 @@ static void parse_code_file(MainInfo *min, GString *cstr, const gchar *code)
 {
 	DirPane		*dp = min->gui->cur_pane;
 	const gchar	*name;
-	gboolean	unsel = (strchr(code + 1, 'u') != NULL),
+	const gboolean	unsel = (strchr(code + 1, 'u') != NULL),
 			path  = (strchr(code + 1, 'p') != NULL),
 			dest  = (strchr(code + 1, 'd') != NULL),
 			quote = (strchr(code + 1, 'Q') == NULL);	/* Upper case for default-on. */
-	guint		cnt = 0U;
 	GSList		*slist, *iter;
 
 	if(dest)		/* User requested the destination pane? */
@@ -107,17 +106,16 @@ static void parse_code_file(MainInfo *min, GString *cstr, const gchar *code)
 
 	for(iter = slist; iter != NULL; iter = g_slist_next(iter))
 	{
-		name = quote ? dp_name_quoted(dp, DP_SEL_INDEX(dp, iter), path) : DP_SEL_NAME(iter);
+		name = quote ? dp_name_quoted(dp, iter->data, path) : dp_row_get_name(dp_get_tree_model(dp), iter->data);
+
+		if(iter != slist)
+			g_string_append_c(cstr, ' ');
 		g_string_append(cstr, name);
-		g_string_append_c(cstr, ' ');
-		cnt++;
 		if(unsel)
-			dp_unselect(dp, DP_SEL_INDEX(dp, iter));
+			dp_unselect(dp, iter->data);
 		if(code[0] == 'f')		/* Only first? */
 			break;
 	}
-	if(cnt > 0)
-		g_string_truncate(cstr, cstr->len - 1);		/* Lose last space. */
 	dp_free_selection(slist);
 }
 
@@ -147,7 +145,57 @@ static void parse_code_path(MainInfo *min, GString *cstr, const gchar *code)
 			fprintf(stderr, "**CMDPARSE: Illegal path code '%s'\n", code + 1);
 	}
 	if(path != NULL)
+	{
+		if(strncmp(path, "file://", 7) == 0)
+			path += 7;
 		g_string_append(cstr, path);
+	}
+}
+
+/* 2010-03-14 -	Parse a {u} code to look up an URI. */
+static void parse_code_uri(MainInfo *min, GString *cstr, const gchar *code)
+{
+	DirPane		*dp = min->gui->cur_pane;
+	const gboolean	single = code[0] == 'u',
+			unsel = (strchr(code + 1, 'u') != NULL),
+			dest  = (strchr(code + 1, 'd') != NULL),
+			quote = (strchr(code + 1, 'Q') == NULL);	/* Upper case for default-on. */
+	GSList		*slist, *iter;
+
+	if(dest)		/* User requested the destination pane? */
+		dp = dp_mirror(min, dp);
+	if((slist = dp_get_selection(dp)) == NULL)
+		return;
+
+	for(iter = slist; iter != NULL; iter = g_slist_next(iter))
+	{
+		GFile	*child;
+
+		child = dp_get_file_from_row(dp, iter->data);
+		if(child != NULL)
+		{
+			gchar	*uri;
+
+			if((uri = g_file_get_uri(child)) != NULL)
+			{
+				if(iter != slist)
+					g_string_append_c(cstr, ' ');
+				if(quote)
+					g_string_append_c(cstr, '"');
+				g_string_append(cstr, uri);
+				if(quote)
+					g_string_append_c(cstr, '"');
+				if(unsel)
+					dp_unselect(dp, iter->data);
+				if(code[0] == 'f')		/* Only first? */
+					break;
+				g_free(uri);
+			}
+			if(single)
+				break;
+		}
+	}
+	dp_free_selection(slist);
 }
 
 /* 1998-09-25 -	Parse an environment variable lookup-code, {$...}.
@@ -261,7 +309,7 @@ static gint build_input_string(CmdDlg *dlg, const gchar *def, CmdInp *inp)
 			parse_code(dlg->min, dstr, tmp->str, dlg, FALSE);
 			g_string_free(tmp, TRUE);
 			gtk_entry_set_text(GTK_ENTRY(ent), dstr->str);
-			gtk_entry_select_region(GTK_ENTRY(ent), 0, -1);
+			gtk_editable_select_region(GTK_EDITABLE(ent), 0, -1);
 			g_string_free(dstr, TRUE);
 		}
 	}
@@ -275,10 +323,9 @@ static gint build_input_string(CmdDlg *dlg, const gchar *def, CmdInp *inp)
 */
 static gint evt_menu_activated(GtkWidget *wid, gpointer user)
 {
-	CmdInp	*inp;
+	CmdInp	*inp = user;
 
-	if((inp = gtk_object_get_user_data(GTK_OBJECT(wid))) != NULL)
-		inp->inp.menu.current = GPOINTER_TO_INT(user);
+	inp->inp.menu.current = gtk_combo_box_get_active(GTK_COMBO_BOX(wid));
 
 	return TRUE;
 }
@@ -288,14 +335,12 @@ static gint evt_menu_activated(GtkWidget *wid, gpointer user)
 */
 static gint build_input_menu(CmdDlg *dlg, const gchar *def, CmdInp *inp)
 {
-	GtkWidget	*obtn, *menu, *item;
+	GtkWidget	*combo;
 	const gchar	*itext, *colon;
-	gint		index = 0;
 
 	if(*def != '=')
 		return 0;
-	obtn = gtk_option_menu_new();
-	menu = gtk_menu_new();
+	combo = gtk_combo_box_text_new();
 	inp->type = CITP_MENU;
 	inp->inp.menu.items = NULL;
 	inp->inp.menu.current = 0;
@@ -305,20 +350,19 @@ static gint build_input_menu(CmdDlg *dlg, const gchar *def, CmdInp *inp)
 		{
 			gchar	tmp[2048];
 
-			stu_strncpy(tmp, itext, sizeof tmp);
+			g_strlcpy(tmp, itext, sizeof tmp);
 			tmp[colon - itext] = '\0';
-			item = gtk_menu_item_new_with_label(tmp);
+			gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), tmp);
 		}
 		else
-			item = gtk_menu_item_new_with_label(itext);
+			gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), itext);
 
-		gtk_object_set_user_data(GTK_OBJECT(item), inp);
 		inp->inp.menu.items = g_list_append(inp->inp.menu.items, (gpointer) itext);
-		g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(evt_menu_activated), GINT_TO_POINTER(index++));
-		gtk_menu_append(GTK_MENU(menu), item);
 	}
-	gtk_option_menu_set_menu(GTK_OPTION_MENU(obtn), menu);
-	pack_input_widget(dlg, obtn, 1, 0);
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 0);
+	g_signal_connect(G_OBJECT(combo), "changed", G_CALLBACK(evt_menu_activated), inp);
+	pack_input_widget(dlg, combo, 1, 0);
+
 	return 1;
 }
 
@@ -329,29 +373,17 @@ static gint build_input_combo(CmdDlg *dlg, const gchar *def, CmdInp *inp)
 {
 	GtkWidget	*combo;
 	const gchar	*itext;
-	GList		*item = NULL, *iter;
 
 	if(*def != '=')
 		return 0;
 
-	combo = gtk_combo_new();
-	/* Configure the combo to work the way I like it to. */
-	gtk_combo_set_value_in_list(GTK_COMBO(combo), FALSE, TRUE);
-	gtk_combo_set_use_arrows_always(GTK_COMBO(combo), TRUE);
+	combo = gtk_combo_box_text_new();
 	while((def = stu_scan_string(def, &itext)) != NULL)
-		item = g_list_append(item, (gpointer) itext);
-	if(item != NULL)
-	{
-		inp->type = CITP_COMBO;
-		gtk_combo_set_popdown_strings(GTK_COMBO(combo), item);
-		for(iter = item; iter != NULL; iter = g_list_next(iter))
-			g_free(iter->data);
-		g_list_free(item);
-		pack_input_widget(dlg, inp->inp.combo.combo = combo, 1, 0);
-		return 1;
-	}
-	gtk_widget_destroy(combo);
-	return 0;
+		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), itext);
+	inp->type = CITP_COMBO;
+	pack_input_widget(dlg, inp->inp.combo.combo = combo, 1, 0);
+
+	return 1;
 }
 
 /* 1999-02-27 -	Build a label for the input window. This replaces the old single label, which was
@@ -482,41 +514,52 @@ static void parse_code_input(MainInfo *min, GString *cstr, gchar *code, CmdDlg *
 	}
 }
 
-/* 1998-09-25 -	Get a pointer to a string representation of row <row> in dialog <dlg>. */
-static const gchar * eval_input(CmdDlg *dlg, gint row)
+/* 1998-09-25 -	Get a pointer to a string representation of row <row> in dialog <dlg>.
+** 2010-05-16 -	Don't return text pointers; append to the given GString, return FALSE on failure.
+*/
+static gboolean eval_and_append_input(CmdDlg *dlg, gint row, GString *out)
 {
 	GList	*data;
+	gchar	*tmp;
 
 	if(row >= 0 && row < dlg->row)
 	{
 		switch(dlg->input[row].type)
 		{
 			case CITP_STRING:
-				return gtk_entry_get_text(GTK_ENTRY(dlg->input[row].inp.string.entry));
+				g_string_append(out, gtk_entry_get_text(GTK_ENTRY(dlg->input[row].inp.string.entry)));
+				return TRUE;
 			case CITP_MENU:
 				if((data = g_list_nth(dlg->input[row].inp.menu.items, dlg->input[row].inp.menu.current)) != NULL)
 				{
 					gchar	*colon;
 
 					if((colon = strchr(data->data, ':')) != NULL)
-						return colon + 1;
-					return data->data;
+						g_string_append(out, colon + 1);
+					else
+						g_string_append(out, data->data);
+					return TRUE;
 				}
-				return NULL;
+				return FALSE;
 			case CITP_COMBO:
-				return gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(dlg->input[row].inp.combo.combo)->entry));
-			case CITP_LABEL:
-				break;		/* Just to keep the compiler happy. Labels don't generate INPxx's. */
+				tmp = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(dlg->input[row].inp.combo.combo));
+				g_string_append(out, tmp);
+				return TRUE;
 			case CITP_CHECKBOX:
-				return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(dlg->input[row].inp.checkbox.check)) ?
-					dlg->input[row].inp.checkbox.active : dlg->input[row].inp.checkbox.inactive;
+				if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(dlg->input[row].inp.checkbox.check)))
+					g_string_append(out, dlg->input[row].inp.checkbox.active);
+				else
+					g_string_append(out, dlg->input[row].inp.checkbox.inactive);
+				return TRUE;
+			case CITP_LABEL:
+				return TRUE;		/* Just to keep the compiler happy. Labels don't generate INPxx's. */
 		}
 	}
-	return NULL;
+	return FALSE;
 }
 
 /* 1999-02-24 -	Interpolate any INP-fields into <cstr>, by grabbing data from <dlg>.
-**		For simplicity, done in two steps with an intermediate scratch string.
+ **		For simplicity, done in two steps with an intermediate scratch string.
 */
 static void interpolate_input(GString *cstr, CmdDlg *dlg)
 {
@@ -529,7 +572,7 @@ static void interpolate_input(GString *cstr, CmdDlg *dlg)
 	{
 		if(sscanf(ptr, INP_PATTERN, &row) == 1)
 		{
-			g_string_append(scratch, eval_input(dlg, row));
+			eval_and_append_input(dlg, row, scratch);
 			ptr += INP_PAT_LEN;
 		}
 		else
@@ -635,6 +678,8 @@ static void parse_code(MainInfo *min, GString *cstr, gchar *code, CmdDlg *dlg, g
 					parse_code_file(min, cstr, code);
 				else if(code[0] == 'P')
 					parse_code_path(min, cstr, code);
+				else if(code[0] == 'u' || code[0] == 'U')
+					parse_code_uri(min, cstr, code);
 				else if(code[0] == '$')
 					parse_code_env(min, cstr, code);
 				else if(code[0] == '#')
