@@ -431,9 +431,6 @@ static gint fork_and_execute(MainInfo *min, CmdRow *row, gchar **argv)
 	if(ext->gflags & CGF_KILLPREV)
 		chd_kill_child(argv[0]);
 
-	if(!csq_handle_ba_flags(min, ext->baflags[0]))
-		return 0;
-
 	/* Figure out where to CD, if requested and sensible. */
 	if(ext->baflags[0] & CBAF_CD_SOURCE)
 	{
@@ -477,6 +474,8 @@ static gint execute_external(MainInfo *min, CmdRow *row)
 	gchar	**argv;
 	gint	ok = 0;
 
+	if(!csq_handle_ba_flags(min, row->extra.external.baflags[0]))
+		return 0;
 	if((argv = cpr_parse(min, row->def->str)) != NULL)
 	{
 		ok = fork_and_execute(min, row, argv);
