@@ -13,6 +13,7 @@
 #include "color_dialog.h"
 #include "dialog.h"
 #include "guiutil.h"
+#include "list_dialog.h"
 #include "odmultibutton.h"
 #include "sizeutil.h"
 #include "strutil.h"
@@ -30,7 +31,7 @@ struct CmdCfg {
 	GList		*fields;
 };
 
-typedef enum { CFT_INTEGER = 0, CFT_BOOLEAN, CFT_ENUM, CFT_SIZE, CFT_STRING, CFT_COLOR } CFType;
+typedef enum { CFT_INTEGER = 0, CFT_BOOLEAN, CFT_ENUM, CFT_SIZE, CFT_STRING, CFT_COLOR, CFT_PATH } CFType;
 
 typedef struct {
 	gint	min, max;
@@ -44,6 +45,7 @@ typedef struct {
 
 typedef struct {
 	gsize	size;
+	gunichar	separator;		/* Used for CFT_PATH. */
 } CFStr;
 
 typedef struct {
@@ -88,7 +90,7 @@ CmdCfg * cmc_config_new(const gchar *cmdname, gpointer base_instance)
 	CmdCfg	*cmc;
 
 	cmc = g_malloc(sizeof *cmc);
-	stu_strncpy(cmc->name, cmdname, sizeof cmc->name);
+	g_strlcpy(cmc->name, cmdname, sizeof cmc->name);
 	cmc->base   = base_instance;
 	cmc->fields = NULL;
 
@@ -135,6 +137,7 @@ void cmc_config_base_save(CmdCfg *cmc, FILE *out)
 					xml_put_uinteger(out, fld->name, *(guint *) ((gchar *) cmc->base + fld->offset));
 					break;
 				case CFT_STRING:
+				case CFT_PATH:
 					xml_put_text(out, fld->name, (gchar *) cmc->base + fld->offset);
 					break;
 				case CFT_COLOR:
@@ -180,6 +183,7 @@ void cmc_config_base_load(CmdCfg *cmc, const XmlNode *node)
 					}
 					break;
 				case CFT_STRING:
+				case CFT_PATH:
 					xml_get_text_copy(node, fld->name, (gchar *) cmc->base + fld->offset, fld->field.string.size);
 					break;
 				case CFT_COLOR:
@@ -264,7 +268,7 @@ static CField * field_new(CFType type, const gchar *name, const gchar *desc, gsi
 
 	fld->type = type;
 	if(name != NULL)
-		stu_strncpy(fld->name, name, sizeof fld->name);
+		g_strlcpy(fld->name, name, sizeof fld->name);
 	if(desc != NULL)
 		fld->desc = strdup(desc);
 	else
@@ -371,6 +375,20 @@ void cmc_field_add_string(CmdCfg *cmc, const gchar *name, const gchar *desc, gsi
 	}
 }
 
+void cmc_field_add_path(CmdCfg *cmc, const gchar *name, const gchar *desc, gsize offset, gsize size, gunichar separator)
+{
+	if(cmc != NULL)
+	{
+		CField	*fld = field_new(CFT_PATH, name, desc, offset);
+
+		/* Sneaky: use the 'string' member for CFT_PATH, too. */
+		fld->field.string.size = size;
+		fld->field.string.separator = separator;
+
+		field_add(cmc, fld);
+	}
+}
+
 void cmc_field_add_color(CmdCfg *cmc, const gchar *name, const gchar *desc, gsize offset)
 {
 	if(cmc != NULL)
@@ -396,24 +414,24 @@ static CField * field_find(CmdCfg *cmc, const gchar *name)
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1999-04-05 -	Attach some data handy to have in event handlers. */
-static void set_object_data(GtkObject *obj, CField *fld, gpointer instance)
+static void set_object_data(GObject *obj, CField *fld, gpointer instance)
 {
 	if(obj != NULL)
 	{
-		gtk_object_set_data(obj, "field", fld);
-		gtk_object_set_data(obj, "instance", instance);
+		g_object_set_data(obj, "field", fld);
+		g_object_set_data(obj, "instance", instance);
 	}
 }
 
 /* 1999-04-05 -	Retrieve the data set by set_object_data() above. */
-static void get_object_data(GtkObject *obj, CField **fld, gpointer *instance)
+static void get_object_data(GObject *obj, CField **fld, gpointer *instance)
 {
 	if(obj != NULL)
 	{
 		if(fld != NULL)
-			*fld = gtk_object_get_data(obj, "field");
+			*fld = g_object_get_data(obj, "field");
 		if(instance != NULL)
-			*instance = gtk_object_get_data(obj, "instance");
+			*instance = g_object_get_data(obj, "instance");
 	}
 }
 
@@ -449,7 +467,7 @@ static gint evt_boolean_clicked(GtkWidget *wid, gpointer user)
 	CField		*fld = NULL;
 	gpointer	instance = NULL;
 
-	get_object_data(GTK_OBJECT(wid), &fld, &instance);
+	get_object_data(G_OBJECT(wid), &fld, &instance);
 
 	if((cmc != NULL) && (fld != NULL) && (instance != NULL))
 	{
@@ -467,10 +485,10 @@ static gint evt_enum_changed(GtkWidget *wid, gpointer user)
 		CField		*fld = NULL;
 		gpointer	instance = NULL;
 
-		get_object_data(GTK_OBJECT(wid), &fld, &instance);
+		get_object_data(G_OBJECT(wid), &fld, &instance);
 		if(cmc && fld && instance)
 		{
-			*(gint *) ((gchar *) instance + fld->offset) = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(wid), "value"));
+			*(gint *) ((gchar *) instance + fld->offset) = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(wid), "value"));
 			set_modified(cmc, instance, TRUE);
 		}
 	}
@@ -484,20 +502,20 @@ static gint evt_string_changed(GtkWidget *wid, gpointer user)
 	CField		*fld;
 	gpointer	instance;
 
-	get_object_data(GTK_OBJECT(wid), &fld, &instance);
+	get_object_data(G_OBJECT(wid), &fld, &instance);
 
 	if((cmc != NULL) && (fld != NULL) && (instance != NULL))
 	{
 		const gchar	*text;
 
 		if((text = gtk_entry_get_text(GTK_ENTRY(wid))) != NULL)
-			stu_strncpy((gchar *) instance + fld->offset, text, fld->field.string.size);
+			g_strlcpy((gchar *) instance + fld->offset, text, fld->field.string.size);
 		set_modified(cmc, instance, TRUE);
 	}
 	return TRUE;
 }
 
-static gint evt_size_changed(GtkObject *obj, gpointer user)
+static gint evt_size_changed(GObject *obj, gpointer user)
 {
 	CmdCfg		*cmc = user;
 	CField		*fld;
@@ -509,13 +527,13 @@ static gint evt_size_changed(GtkObject *obj, gpointer user)
 	{
 		gchar		buf[32];
 		gsize		value = GTK_ADJUSTMENT(obj)->value;
-		GtkWidget	*label = gtk_object_get_data(obj, "label");
+		GtkWidget	*label = g_object_get_data(obj, "label");
 
 		value *= fld->field.size.step;
 		if(fld->field.size.step >= 512)
-			sze_put_size(buf, sizeof buf, value, SZE_KB);
+			sze_put_offset(buf, sizeof buf, value, SZE_KB, 0, ',');
 		else
-			sze_put_size(buf, sizeof buf, value, SZE_BYTES);
+			sze_put_offset(buf, sizeof buf, value, SZE_BYTES, 0, ',');
 		gtk_label_set_text(GTK_LABEL(label), buf);
 
 		*(gsize *) ((gchar *) instance + fld->offset) = value;
@@ -528,11 +546,25 @@ static gint evt_size_changed(GtkObject *obj, gpointer user)
 /* 2008-11-28 -	User changed the color. Write new back from widget. */
 static void evt_color_set(GtkWidget *wid, gpointer wuser, guint index, gpointer suser)
 {
+	CmdCfg		*cmc = suser;
 	CField		*fld;
 	gpointer	instance;
 
-	get_object_data(GTK_OBJECT(wid), &fld, &instance);
+	get_object_data(G_OBJECT(wid), &fld, &instance);
 	gtk_color_button_get_color(GTK_COLOR_BUTTON(wid), (GdkColor *) ((gchar *) instance + fld->offset));
+	set_modified(cmc, instance, TRUE);
+}
+
+static void evt_path_pick_clicked(GtkWidget *wid, gpointer user)
+{
+	CField		*fld;
+	gpointer	instance;
+	GtkEntry	*entry;
+
+	get_object_data(G_OBJECT(wid), &fld, &instance);
+	ldl_dialog_sync_new_wait((gchar *) instance + fld->offset, fld->field.string.size, fld->field.string.separator, fld->desc);
+	entry = GTK_ENTRY(g_object_get_data(G_OBJECT(wid), "entry"));
+	gtk_entry_set_text(entry, (gchar *) instance + fld->offset);
 }
 
 /* 2002-08-01 -	Build a neatly right-aligned label, and stuff it into <table>. */
@@ -568,7 +600,7 @@ static GtkWidget * field_build(CmdCfg *cmc, CField *fld, gpointer instance, GtkW
 			case CFT_INTEGER:
 				label_build(fld->desc, table, 0, row);
 				wid = gtk_spin_button_new(NULL, 1, 0);
-				set_object_data(GTK_OBJECT(wid), fld, instance);
+				set_object_data(G_OBJECT(wid), fld, instance);
 				adj = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(wid));
 				gtk_adjustment_clamp_page(adj, fld->field.integer.min, fld->field.integer.max);
 				gtk_adjustment_set_value(adj, *(gint *) ((gchar *) instance + fld->offset));
@@ -576,7 +608,7 @@ static GtkWidget * field_build(CmdCfg *cmc, CField *fld, gpointer instance, GtkW
 				break;
 			case CFT_BOOLEAN:
 				wid = gtk_check_button_new_with_label(fld->desc);
-				set_object_data(GTK_OBJECT(wid), fld, instance);
+				set_object_data(G_OBJECT(wid), fld, instance);
 				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wid), *(gboolean *) ((gchar *) instance + fld->offset));
 				g_signal_connect(G_OBJECT(wid), "clicked", G_CALLBACK(evt_boolean_clicked), cmc);
 				gtk_table_attach(GTK_TABLE(table), wid, 0, 2, row, row + 1,  GTK_EXPAND|GTK_FILL,0,5,0);
@@ -592,8 +624,8 @@ static GtkWidget * field_build(CmdCfg *cmc, CField *fld, gpointer instance, GtkW
 					group = gui_radio_group_new(fld->field.fenum.num, (const gchar **) fld->field.fenum.label, radio);
 					for(i = 0; i < fld->field.fenum.num; i++)
 					{
-						set_object_data(GTK_OBJECT(radio[i]), fld, instance);
-						gtk_object_set_data(GTK_OBJECT(radio[i]), "value", GINT_TO_POINTER(i));
+						set_object_data(G_OBJECT(radio[i]), fld, instance);
+						g_object_set_data(G_OBJECT(radio[i]), "value", GINT_TO_POINTER(i));
 						g_signal_connect(G_OBJECT(radio[i]), "toggled", G_CALLBACK(evt_enum_changed), cmc);
 						gtk_box_pack_start(GTK_BOX(vbox), radio[i], FALSE, FALSE, 0);
 						if(i == current)
@@ -611,22 +643,22 @@ static GtkWidget * field_build(CmdCfg *cmc, CField *fld, gpointer instance, GtkW
 							 fld->field.size.max / fld->field.size.step,
 							 1, 1, 0);
 
-				set_object_data(obj, fld, instance);
+				set_object_data(G_OBJECT(obj), fld, instance);
 				wid = gtk_hscale_new(GTK_ADJUSTMENT(obj));
-				gtk_range_set_update_policy(GTK_RANGE(wid), GTK_UPDATE_DELAYED);
 				gtk_scale_set_draw_value(GTK_SCALE(wid), FALSE);
 				gtk_box_pack_start(GTK_BOX(hbox), wid, TRUE, TRUE, 0);
 				label = gtk_label_new("");
 				gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 5);
-				gtk_object_set_data(obj, "label", label);
+				g_object_set_data(G_OBJECT(obj), "label", label);
 				g_signal_connect(G_OBJECT(obj), "value_changed", G_CALLBACK(evt_size_changed), cmc);
 				gtk_adjustment_value_changed(GTK_ADJUSTMENT(obj));
 				gtk_table_attach(GTK_TABLE(table), hbox, 1, 2, row, row + 1,  GTK_EXPAND|GTK_FILL,0,5,0);
 				break;
 			case CFT_STRING:
 				label_build(fld->desc, table, 0, row);
-				wid = gtk_entry_new_with_max_length(fld->field.string.size - 1);
-				set_object_data(GTK_OBJECT(wid), fld, instance);
+				wid = gtk_entry_new();
+				gtk_entry_set_max_length(GTK_ENTRY(wid), fld->field.string.size - 1);
+				set_object_data(G_OBJECT(wid), fld, instance);
 				gtk_entry_set_text(GTK_ENTRY(wid), (gchar *) instance + fld->offset);
 				g_signal_connect(G_OBJECT(wid), "changed", G_CALLBACK(evt_string_changed), cmc);
 				gtk_table_attach(GTK_TABLE(table), wid, 1, 2, row, row + 1,  GTK_EXPAND|GTK_FILL,0,5,0);
@@ -634,10 +666,30 @@ static GtkWidget * field_build(CmdCfg *cmc, CField *fld, gpointer instance, GtkW
 			case CFT_COLOR:
 				label_build(fld->desc, table, 0, row);
 				wid = gtk_color_button_new_with_color((const GdkColor *) ((gchar *) instance + fld->offset));
-				set_object_data(GTK_OBJECT(wid), fld, instance);
+				set_object_data(G_OBJECT(wid), fld, instance);
 				g_signal_connect(G_OBJECT(wid), "color_set", G_CALLBACK(evt_color_set), cmc);
 				gtk_table_attach(GTK_TABLE(table), wid, 1, 2, row, row + 1, GTK_EXPAND|GTK_FILL,0,5,0);
 				break;
+			case CFT_PATH:
+				{
+					GtkWidget	*pick;
+
+					label_build(fld->desc, table, 0, row);
+					hbox = gtk_hbox_new(FALSE, 0);
+					wid = gtk_entry_new();
+					gtk_entry_set_max_length(GTK_ENTRY(wid), fld->field.string.size - 1);
+					set_object_data(G_OBJECT(wid), fld, instance);
+					gtk_entry_set_text(GTK_ENTRY(wid), (gchar *) instance + fld->offset);
+					g_signal_connect(G_OBJECT(wid), "changed", G_CALLBACK(evt_string_changed), cmc);
+					gtk_box_pack_start(GTK_BOX(hbox), wid, TRUE, TRUE, 0);
+					pick = gui_details_button_new();
+					set_object_data(G_OBJECT(pick), fld, instance);
+					g_object_set_data(G_OBJECT(pick), "entry", wid);
+					g_signal_connect(G_OBJECT(pick), "clicked", G_CALLBACK(evt_path_pick_clicked), cmc);
+					gtk_box_pack_start(GTK_BOX(hbox), pick, FALSE, FALSE, 0);
+					gtk_table_attach(GTK_TABLE(table), hbox, 1, 2, row, row + 1, GTK_EXPAND|GTK_FILL,0,5,0);
+				}
+				break;
 		}
 		return table;
 	}
@@ -707,6 +759,7 @@ gpointer cmc_instance_new(CmdCfg *cmc)
 					fsize += sizeof (gsize);
 					break;
 				case CFT_STRING:
+				case CFT_PATH:
 					fsize += fld->field.string.size;
 					break;
 				case CFT_COLOR:
@@ -770,7 +823,8 @@ void cmc_instance_copy(CmdCfg *cmc, gpointer dst, gpointer src)
 					*(gsize *) ((gchar *) dst + fld->offset) = *(gsize *) ((gchar *) src + fld->offset);
 					break;
 				case CFT_STRING:
-					stu_strncpy((gchar *) dst + fld->offset, (gchar *) src + fld->offset, fld->field.string.size);
+				case CFT_PATH:
+					g_strlcpy((gchar *) dst + fld->offset, (gchar *) src + fld->offset, fld->field.string.size);
 					break;
 				case CFT_COLOR:
 					*(GdkColor *) ((gchar *) dst + fld->offset) = *(GdkColor *) ((gchar *) src + fld->offset);
