@@ -16,6 +16,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #include "dialog.h"
+#include "guiutil.h"
 #include "strutil.h"
 
 #include "cmdseq_dialog.h"
@@ -314,8 +315,7 @@ const gchar * csq_dialog_sync_new_wait(MainInfo *min, GHashTable *cmdseq)
 	gtk_box_pack_start(GTK_BOX(cdlg->vbox), label, FALSE, FALSE, 0);
 	scwin  = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_widget_set_size_request(scwin, 200, 384);
-	cdlg->entry = gtk_entry_new();
+	cdlg->entry = gui_dialog_entry_new();
 	if((tree = build_tree(min, cdlg)) != NULL)
 	{
 		gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scwin), tree);
@@ -328,6 +328,7 @@ const gchar * csq_dialog_sync_new_wait(MainInfo *min, GHashTable *cmdseq)
 		gtk_editable_select_region(GTK_EDITABLE(cdlg->entry), 0, -1);
 
 		cdlg->dlg = dlg_dialog_sync_new(cdlg->vbox, _("Select Command"), NULL);
+		gtk_window_set_default_size(GTK_WINDOW(dlg_dialog_get_dialog(cdlg->dlg)), 320, 544);
 		gtk_widget_grab_focus(cdlg->entry);
 		if(dlg_dialog_sync_wait(cdlg->dlg) == DLG_POSITIVE)
 			ret = cdlg->cmd->str;
