@@ -32,6 +32,7 @@
 #include "dirpane.h"
 #include "fileutil.h"
 #include "iconutil.h"
+#include "nag_dialog.h"
 #include "window.h"
 #include "xmlutil.h"
 
@@ -97,6 +98,54 @@ static CfgGui	the_cfggui = { NULL };
 
 /* ----------------------------------------------------------------------------------------- */
 
+/* 2011-07-24 -	Returns the base directory where the proper configuration file is to be found. */
+static const gchar * get_config_dirname(void)
+{
+	static gchar	buf[1024] = "";
+
+	if(buf[0] == '\0')
+	{
+		const gchar	*confdir;
+
+		if((confdir = g_get_user_config_dir()) != NULL)
+			g_snprintf(buf, sizeof buf, "%s" G_DIR_SEPARATOR_S PACKAGE, confdir);
+	}
+	return buf;
+}
+
+/* 2011-07-24 -	Returns pointer to the proper filename for our configuration file. */
+static const gchar * get_config_filename(const gchar *filename)
+{
+	static gchar	buf[1024] = "";
+
+	if(buf[0] == '\0')
+	{
+		const gchar	*confdir = get_config_dirname();
+
+		g_snprintf(buf, sizeof buf, "%s" G_DIR_SEPARATOR_S "%s", confdir, filename);
+	}
+	return buf;
+}
+
+/* 2011-07-24 -	Returns pointer to the old and outdated filename used by our configuration file. */
+static const gchar * get_config_filename_old(const gchar *filename)
+{
+	static gchar	buf[1024];
+
+	if(buf[0] == '\0')
+	{
+		const gchar	*home = g_getenv("HOME");
+
+		if(home == NULL)
+			home = g_get_home_dir();
+		if(home != NULL)
+			g_snprintf(buf, sizeof buf, "%s" G_DIR_SEPARATOR_S "%s", home, filename);
+	}
+	return buf;
+}
+
+/* ----------------------------------------------------------------------------------------- */
+
 /* 1998-06-26 -	Do the work of hiding the config GUI. */
 static void hide_config(CfgGui *cgu)
 {
@@ -167,18 +216,12 @@ static gint evt_ok_clicked(GtkWidget *wid, gpointer user)
 */
 void cfg_save_all(MainInfo *min)
 {
-	gchar		*root = "GentooConfig", *home, rcname[PATH_MAX];
+	const gchar	*root = "GentooConfig", *rcname;
 	FILE		*out;
 	guint		i;
 	const CfgModule	*page;
 
-	if((home = getenv("HOME")) != NULL)
-	{
-		strcpy(rcname, home);
-		strcat(rcname, "/" RCNAME);
-	}
-	else
-		return;
+	rcname = get_config_filename(RCNAME);
 
 	cfg_modified_clear(min);
 	if((out = xml_put_open(rcname)) != NULL)
@@ -440,22 +483,41 @@ static void load_node(const XmlNode *node, gpointer user)
 */
 guint32 cfg_load_config(MainInfo *min)
 {
-	XmlNode	*tree;
-	gchar	name[PATH_MAX] = "", *hpath;
-	guint32	i, flags = 0UL;
+	XmlNode		*tree;
+	gchar		name[PATH_MAX] = "";
+	const gchar	*rcdir, *rcname;
+	guint32		i, flags = 0UL, bad_dir = 0;
 
-	if((hpath = getenv("HOME")) != NULL)
-		g_snprintf(name, sizeof name, "%s" G_DIR_SEPARATOR_S "%s", hpath, RCNAME);
+	/* Since we know this function is called during boot, ensure the user's config directory exists. */
+	rcdir = get_config_dirname();
+	if(*rcdir == '\0')
+		g_error("Failed to retrieve user's configuration directory, can't save configuration data");
+	else if(!fut_exists(rcdir))
+		g_mkdir_with_parents(rcdir, 0700);
 
 	/* Does the user seem to have a local config? */
-	if(!fut_can_read_named(name))
-		g_snprintf(name, sizeof name, PATH_CFG G_DIR_SEPARATOR_S "%s", RCNAME + 1);	/* Nope, check for global one. */
+	rcname = get_config_filename(RCNAME);
+	if(!fut_can_read_named(rcname))
+	{
+		rcname = get_config_filename_old("." RCNAME);	/* Nope, check old location and name. */
+		bad_dir = 1;
+	}
+	if(!fut_can_read_named(rcname))
+	{
+		g_snprintf(name, sizeof name, PATH_CFG G_DIR_SEPARATOR_S "%s", RCNAME);		/* Nope, check for global one. */
+		rcname = name;
+		bad_dir = 1;
+	}
+
+	/* If loading from a "bad" (non-standard) directory, nag. */
+	if(bad_dir)
+		ndl_dialog_sync_new_wait(min, "rcpath", _("Configuration Path Notice"), _("Configuration was not loaded from the current default location.\nPress Save in the Configuration window to update."));
 
 	/* Initialize the cache of page descriptors. */
 	for(i = 0; i < CFG_PAGES; i++)
 		cfg_page[i] = describe_page[i](min);
 
-	if((tree = xml_tree_load(name)) != NULL)
+	if((tree = xml_tree_load(rcname)) != NULL)
 	{
 		const gchar	*fver;
 
@@ -466,16 +528,16 @@ guint32 cfg_load_config(MainInfo *min)
 	}
 	else
 	{
-		gchar	homename[PATH_MAX] = "", syscfg[PATH_MAX], whine[2 * PATH_MAX];
+		const gchar	*rcname, *oldrcname;
+		gchar		syscfg[PATH_MAX], whine[3 * PATH_MAX];
 
-		if((hpath = getenv("HOME")) != NULL)
-			g_snprintf(homename, sizeof homename, "%s/%s", hpath, RCNAME);
-
-		g_snprintf(syscfg, sizeof syscfg, PATH_CFG G_DIR_SEPARATOR_S "%s", RCNAME + 1);
-		g_snprintf(whine, sizeof whine, _("Couldn't find any configuration file; checked\n"
-				"both \"%s\" and \"%s\".\n"
+		rcname = get_config_filename(RCNAME);
+		oldrcname = get_config_filename_old("." RCNAME);
+		g_snprintf(syscfg, sizeof syscfg, PATH_CFG G_DIR_SEPARATOR_S "%s", RCNAME);
+		g_snprintf(whine, sizeof whine, _("Couldn't find any configuration file; checked:\n"
+				"\"%s\",\n\"%s\" and\n\"%s\".\n"
 				"Using built-in minimal configuration."),
-				homename, syscfg);
+				rcname, oldrcname, syscfg);
 		dlg_dialog_async_new_error(whine);
 		flags |= CLDF_NONE_FOUND;
 	}
