@@ -6,19 +6,24 @@
 #define	CONFIGURE_H
 
 /* These are flags useful in calls to cfg_set_flags(). */
-#define	CFLG_RESCAN_LEFT	(1<<0)
-#define	CFLG_RESCAN_RIGHT	(1<<1)
-#define	CFLG_RESCAN_BOTH	(CFLG_RESCAN_LEFT | CFLG_RESCAN_RIGHT)
-#define	CFLG_REDISP_LEFT	(1<<2)
-#define	CFLG_REDISP_RIGHT	(1<<3)
-#define	CFLG_FLUSH_ICONS	(1<<4)
-#define	CFLG_REBUILD_MIDDLE	(1<<5)
-#define	CFLG_REBUILD_BOTTOM	(1<<6)
-#define	CFLG_RESET_MOUNT	(1<<7)
-#define	CFLG_RESET_KEYBOARD	(1<<8)
+enum {
+	CFLG_RESCAN_LEFT	= (1 << 0),
+	CFLG_RESCAN_RIGHT	= (1 << 1),
+	CFLG_RESCAN_BOTH	= (CFLG_RESCAN_LEFT | CFLG_RESCAN_RIGHT),
+	CFLG_REDISP_LEFT	= (1 << 2),
+	CFLG_REDISP_RIGHT	= (1 << 3),
+	CFLG_FLUSH_ICONS	= (1 << 4),
+	CFLG_REBUILD_TOP	= (1 << 5),
+	CFLG_REBUILD_MIDDLE	= (1 << 6),
+	CFLG_REBUILD_BOTTOM	= (1 << 7),
+	CFLG_RESET_MOUNT	= (1 << 8),
+	CFLG_RESET_KEYBOARD	= (1 << 9),
+};
 
 /* These are flags returned by cfg_load_config(). */
-#define	CLDF_NONE_FOUND		(1<<0)		/* There was no config available. */
+enum {
+	CLDF_NONE_FOUND		= (1<<0)		/* There was no config available. */
+};
 
 extern gint	cfg_configure(MainInfo *min);
 
