@@ -394,9 +394,13 @@ const gchar * dph_history_get_first(const DirPane *dp)
 static const gchar * history_filename(MainInfo *min)
 {
 	static gchar	buffer[PATH_MAX];
+	const gchar	*confdir;
 
-	if(fut_path_component("~/.gentoo-history", buffer))
+	if((confdir = g_get_user_config_dir()) != NULL)
+	{
+		g_snprintf(buffer, sizeof buffer, "%s" G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S "dirhistory", confdir);
 		return buffer;
+	}
 	return NULL;
 }
 
