@@ -286,18 +286,8 @@ gboolean fut_size_gfile(MainInfo *min, const GFile *file, guint64 *bytes, FUCoun
 		return FALSE;
 	if((fi = g_file_query_info((GFile *) file, "standard::*", G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL, error)) == NULL)
 		return FALSE;
-	if(fc != NULL)		/* If there is a fc present, wipe it clean. */
-	{
-		fc->num_dirs  = 0U;
-		fc->num_files = 0U;
-		fc->num_links = 0U;
-		fc->num_specials = 0U;
-
-		fc->num_total = 0U;
-
-		fc->num_bytes  = 0ULL;
-		fc->num_blocks = 0ULL;
-	}
+	if(fc != NULL)		/* If there is an fc present, wipe it clean. */
+		memset(fc, 0, sizeof *fc);
 	ret = do_size_gfile_info(min, file, fi, bytes, fc, error);
 	/* Adjust, don't consider a directory to contain itself. */
 	if(g_file_info_get_file_type(fi) == G_FILE_TYPE_DIRECTORY && fc != NULL)
@@ -772,17 +762,6 @@ gboolean fut_can_write(const struct stat *stat, uid_t uid, gid_t gid)
 	return (stat->st_mode & S_IWOTH) ? TRUE : FALSE;
 }
 
-/* 1998-09-07 -	Do complex EXECUTE permission check. */
-gboolean fut_can_execute(const struct stat *stat, uid_t uid, gid_t gid)
-{
-	if(stat->st_uid == uid)
-		return (stat->st_mode & S_IXUSR) ? TRUE : FALSE;
-	if(stat->st_gid == gid)
-		return (stat->st_mode & S_IXGRP) ? TRUE : FALSE;
-
-	return (stat->st_mode & S_IXOTH) ? TRUE : FALSE;
-}
-
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1998-10-26 -	Check if the user doesn't want to see <name>. Returns TRUE if the file is
