@@ -233,9 +233,11 @@ void rebuild_middle(MainInfo *min)
 void rebuild_bottom(MainInfo *min)
 {
 	gtk_widget_destroy(min->gui->bottom);
-	min->gui->bottom = build_bottom(min);
-	gtk_box_pack_start(GTK_BOX(min->gui->vbox), min->gui->bottom, FALSE, FALSE, 0);
-	gtk_widget_show(min->gui->bottom);
+	if((min->gui->bottom = build_bottom(min)) != NULL)
+	{
+		gtk_box_pack_start(GTK_BOX(min->gui->vbox), min->gui->bottom, FALSE, FALSE, 0);
+		gtk_widget_show(min->gui->bottom);
+	}
 }
 
 /* 2008-04-20 -	Replaced old size_allocation-tracking code with new, using configure events instead. */
@@ -267,7 +269,8 @@ static GtkWidget * build_gui(MainInfo *min)
 		if(top != NULL)
 			gtk_box_pack_start(GTK_BOX(min->gui->vbox), top,    FALSE, FALSE, 0);
 		gtk_box_pack_start(GTK_BOX(min->gui->vbox), panes,  TRUE,  TRUE,  0);
-		gtk_box_pack_start(GTK_BOX(min->gui->vbox), bottom, FALSE, FALSE, 0);
+		if(bottom != NULL)
+			gtk_box_pack_start(GTK_BOX(min->gui->vbox), bottom, FALSE, FALSE, 0);
 		gtk_widget_show_all(min->gui->vbox);
 		min->gui->middle = panes;
 		min->gui->bottom = bottom;
