@@ -271,8 +271,8 @@ enum {
 	CBAF_RESCAN_DEST = (1<<1),
 	CBAF_CD_SOURCE = (1<<2),		/* These save some config work. */
 	CBAF_CD_DEST = (1<<3),
-	CBAF_REQSEL_SOURCE = (1<<4),		/* Command won't run if there's no source selection when envoked. */
-	CBAF_REQSEL_DEST = (1<<5)		/* Command won't run if there's no destination selection when envoked. */
+	CBAF_REQSEL_SOURCE = (1<<4),		/* Command won't run if there's no source selection when invoked. */
+	CBAF_REQSEL_DEST = (1<<5)		/* Command won't run if there's no destination selection when invoked. */
 };
 
 typedef struct {		/* Extra info for external commands. */
