@@ -76,13 +76,13 @@ const gchar * hdl_dialog_sync_new_wait(GHashTable *hash, const gchar *title)
 	gtk_tree_view_append_column(GTK_TREE_VIEW(hdl.view), vc);
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(hdl.view), FALSE);
 	g_signal_connect(G_OBJECT(hdl.view), "row_activated", G_CALLBACK(evt_row_activated), &hdl);
-	gtk_widget_set_size_request(hdl.view, 200, 384);
 
 	scwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_container_add(GTK_CONTAINER(scwin), hdl.view);
 
-	hdl.dlg  = dlg_dialog_sync_new(scwin, title, NULL);
+	hdl.dlg = dlg_dialog_sync_new(scwin, title, NULL);
+	gtk_window_set_default_size(GTK_WINDOW(dlg_dialog_get_dialog(hdl.dlg)), 320, 544);
 	if(dlg_dialog_sync_wait(hdl.dlg) == DLG_POSITIVE)
 	{
 		GtkTreeSelection	*sel;
