@@ -103,7 +103,6 @@ const gchar * idl_dialog_sync_new_wait(MainInfo *min, const gchar *path, const g
 		vc = gtk_tree_view_column_new_with_attributes("(title)", cr, "text", COLUMN_NAME, NULL);
 		gtk_tree_view_append_column(GTK_TREE_VIEW(view), vc);
 		gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(view), FALSE);
-		gtk_widget_set_size_request(view, 200, 384);
 		ts = gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
 
 		if(sel != NULL && ts != NULL)
@@ -118,6 +117,7 @@ const gchar * idl_dialog_sync_new_wait(MainInfo *min, const gchar *path, const g
 		gtk_container_add(GTK_CONTAINER(scwin), view);
 
 		dlg = dlg_dialog_sync_new(scwin, title, NULL);
+		gtk_window_set_default_size(GTK_WINDOW(dlg_dialog_get_dialog(dlg)), 320, 544);
 		g_signal_connect(G_OBJECT(view), "row_activated", G_CALLBACK(evt_row_activated), dlg);
 
 		if(dlg_dialog_sync_wait(dlg) != DLG_POSITIVE)
