@@ -11,6 +11,8 @@
 **		name really kind of rolls off your tongue, doesn't it?). Simplified things.
 ** 1999-11-21 -	Rewrote the ico_flush() function, to use g_hash_table_foreach_remove(),
 **		which made it a lot shorter and cleaner. Good.
+** 2010-02-22 -	Time flies. Removed old-style pixmap+mask representations, now always uses
+**		the more 2.0-y GdkPixbufs all over the place.
 */
 
 #include "gentoo.h"
@@ -36,18 +38,12 @@
 struct IconInfo {
 	GHashTable	*icon;			/* Provides name-to-pixmap lookup. */
 	const gchar	*path;			/* A local copy of the PTID_ICONS path. */
-	GdkPixmap	*empty_pixmap;		/* An empty icon. It's just blank! */
-	GdkBitmap	*empty_mask;		/* The very empty mask. */
 	GdkPixbuf	*empty;
-	GdkPixmap	*fail_pixmap;		/* This is returned if a named icon isn't found. */
-	GdkBitmap	*fail_mask;		/* Mask for unable-to-load case. */
 	GdkPixbuf	*fail;
 };
 
 typedef struct {
 	gchar		name[PATH_MAX];		/* This is real big. */
-	GdkPixmap	*pixmap;
-	GdkBitmap	*mask;
 	GdkPixbuf	*pixbuf;
 } IconGfx;
 
@@ -70,10 +66,7 @@ IconInfo * ico_initialize(MainInfo *min)
 
 	ico->icon = g_hash_table_new(g_str_hash, cmp_icon);
 
-	ico->empty_pixmap = gdk_pixmap_colormap_create_from_xpm_d(NULL, gtk_widget_get_default_colormap(), &ico->empty_mask, NULL, icon_empty_xpm);
 	ico->empty = gdk_pixbuf_new_from_xpm_data((const char **) icon_empty_xpm);
-
-	ico->fail_pixmap  = gdk_pixmap_colormap_create_from_xpm_d(NULL, gtk_widget_get_default_colormap(), &ico->fail_mask, NULL, icon_failed_xpm);
 	ico->fail = gdk_pixbuf_new_from_xpm_data((const char **) icon_failed_xpm);
 
 	ico->path = min->cfg.path.path[PTID_ICON]->str;
@@ -130,82 +123,16 @@ void ico_free_all(GList *list)
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* 1998-08-15 -	Internal icon loader. Uses the (new) file utility function 'fut_locate' to
-**		search the icon path. A configurable icon path is on the agenda...
-** 1999-08-28 -	Removed need for passing a GdkWindow, by using the _colormap_ pixmap creator. Good?
-*/
-static IconGfx * load(IconInfo *ico, const gchar *name)
-{
-	const gchar	*fname;
-	IconGfx		*ig;
-
-	ig = g_malloc(sizeof *ig);
-	stu_strncpy(ig->name, name, sizeof ig->name);
-	ig->pixbuf = NULL;
-	if(strcmp(name, ICON_NONE) == 0)		/* Is it the special, reserved, blank icon? */
-	{
-		ig->pixmap = ico->empty_pixmap;
-		ig->mask   = ico->empty_mask;
-		ig->pixbuf = ico->empty;
-		return ig;
-	}
-	if((fname = fut_locate(ico->path, name)) != NULL)
-	{
-		if((ig->pixmap = gdk_pixmap_colormap_create_from_xpm(NULL, gtk_widget_get_default_colormap(), &ig->mask, NULL, fname)) != NULL)
-		{
-			gdk_pixmap_ref(ig->pixmap);
-			gdk_bitmap_ref(ig->mask);
-			return ig;
-		}
-	}
-	g_free(ig);
-
-	return NULL;
-}
-
-/* 1998-08-15 -	Internal icon retrieval function. Does a lookup in the hash table, loads
-**		from disk if not found.
-*/
-static GdkPixmap * get_or_load(IconInfo *ico, const gchar *name, GdkBitmap **mask)
-{
-	IconGfx	*ig;
-
-	if(ico->icon == NULL)
-		ico->icon = g_hash_table_new(g_str_hash, cmp_icon);
-	if(ico->icon != NULL)
-	{
-		if((ig = g_hash_table_lookup(ico->icon, name)) != NULL)
-		{
-			*mask = ig->mask;
-			return ig->pixmap;
-		}
-		else if((ig = load(ico, name)) != NULL)
-		{
-			g_hash_table_insert(ico->icon, ig->name, ig);
-			*mask = ig->mask;
-			return ig->pixmap;
-		}
-		else
-		{
-			*mask = ico->fail_mask;
-			return ico->fail_pixmap;
-		}
-	}
-	return NULL;
-}
-
 static IconGfx * load_pixbuf(IconInfo *ico, const gchar *name)
 {
 	const gchar	*fname;
 	IconGfx		*ig;
 
 	ig = g_malloc(sizeof *ig);
-	stu_strncpy(ig->name, name, sizeof ig->name);
+	g_strlcpy(ig->name, name, sizeof ig->name);
 	if(strcmp(name, ICON_NONE) == 0)		/* Is it the special, reserved, blank icon? */
 	{
-		ig->pixmap = ico->empty_pixmap;
-		ig->mask   = ico->empty_mask;
-		ig->pixbuf = NULL;
+		ig->pixbuf = ico->empty;
 		return ig;
 	}
 	if((fname = fut_locate(ico->path, name)) != NULL)
@@ -224,30 +151,16 @@ static GdkPixbuf * get_or_load_pixbuf(IconInfo *ico, const gchar *name)
 		ico->icon = g_hash_table_new(g_str_hash, cmp_icon);
 	if((ig = g_hash_table_lookup(ico->icon, name)) != NULL)
 		return ig->pixbuf;
-	else if((ig = load_pixbuf(ico, name)) != NULL)
+	if((ig = load_pixbuf(ico, name)) != NULL)
+	{
+		g_hash_table_insert(ico->icon, ig->name, ig);
 		return ig->pixbuf;
+	}
 	return ico->fail;
 }
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* 1998-08-15 -	Retrieve a pixmap corresponding to the given <name>, which is typically
-**		an (unqualified) file name, such as "Makefile.xpm". Returns a pointer to
-**		a GDK pixmap, and fills in the <mask> pointer with a pointer to the mask
-**		needed when rendering this pixmap. Returns NULL on failure.
-** 1999-08-28 -	Removed silly GdkWindow argument. Nicer.
-** 2008-07-29 -	FIXME DEPRECATED This interface needs to go.
-*/
-GdkPixmap * ico_icon_get(MainInfo *min, const gchar *name, GdkBitmap **mask)
-{
-	if((name == NULL) || (*name == '\0') || (mask == NULL))
-		return NULL;
-
-	min->ico->path = min->cfg.path.path[PTID_ICON]->str;	/* Make sure we have a fresh path. */
-
-	return get_or_load(min->ico, name, mask);
-}
-
 /* 2008-07-29 -	New interface, this returns a GDK Pixbuf which is far more useful in these
  *		times of GTK+ 2 than the old GdkPixmap/GdkBitmap combo.
 */
@@ -267,11 +180,10 @@ GdkPixbuf * ico_icon_get_pixbuf(MainInfo *min, const gchar *name)
 */
 static gboolean kill_icon(gpointer key, gpointer value, gpointer user)
 {
-	IconGfx	*icon = value;
+	IconGfx	*gfx = value;
 
-	gdk_pixmap_unref(icon->pixmap);
-	gdk_bitmap_unref(icon->mask);
-	g_free(icon);
+	g_object_unref(gfx->pixbuf);
+	g_free(gfx);
 
 	return TRUE;			/* Tells glib to actually remove hash entry. */
 }
