@@ -12,12 +12,8 @@
 
 /* ----------------------------------------------------------------------------------------- */
 
-extern gchar *		stu_strncpy(gchar *dst, const gchar *src, gssize n);
-
 extern gchar *		stu_tickify(gchar *buf, guint64 n, gchar tick);
 
-extern const gchar *	stu_strcasechr(const gchar *str, gchar c);
-extern const gchar *	stu_strcaserchr(const gchar *str, gchar c);
 extern gboolean		stu_has_suffix(const gchar *string, const char *suffix);
 
 extern gint		stu_strcmp_vector(const gchar *string, const gchar **vector, gsize vector_size, gint def);
@@ -33,3 +29,9 @@ extern const gchar *	stu_word_length(const gchar *str, gsize *len, gchar *store)
 extern gchar **		stu_split_args(const char *argstring);
 
 extern const gchar *	stu_escape(const gchar *string);
+
+extern guint		stu_replace_simple(GString *output, const gchar *input, const gchar *find, const gchar *replace, gboolean global, gboolean nocase);
+
+extern const gchar *	stu_utf8_find(const gchar *string, gboolean (*function)(gunichar ch, gpointer user), gpointer user);
+
+extern gboolean		stu_interpolate_dictionary(gchar *output, gsize size, const gchar *format, const GHashTable *dictionary);
