@@ -34,14 +34,16 @@ typedef struct {
 ** used in the old_load_property() function, when converting to the more modern string-
 ** based property names used by this module.
 */
-#define	L_TYPE_UNSEL_BGCOL	(0)
-#define	L_TYPE_UNSEL_FGCOL	(1)
-#define	L_TYPE_UNSEL_ICON	(2)
-#define	L_TYPE_ACTN_DEFAULT	(6)
-#define	L_TYPE_ACTN_VIEW	(7)
-#define	L_TYPE_ACTN_EDIT	(8)
-#define	L_TYPE_ACTN_PRINT	(9)
-#define	L_TYPE_ACTN_PLAY	(10)
+enum {
+	L_TYPE_UNSEL_BGCOL	= 0,
+	L_TYPE_UNSEL_FGCOL	= 1,
+	L_TYPE_UNSEL_ICON	= 2,
+	L_TYPE_ACTN_DEFAULT	= 6,
+	L_TYPE_ACTN_VIEW	= 7,
+	L_TYPE_ACTN_EDIT	= 8,
+	L_TYPE_ACTN_PRINT	= 9,
+	L_TYPE_ACTN_PLAY	= 10
+};
 
 typedef struct {
 	gchar		name[STL_PROPERTY_NAME_SIZE];	/* Unique property identifier. */
@@ -177,7 +179,7 @@ static void property_update(gpointer key, gpointer value, gpointer user)
 	else	/* No property found, so create a fresh linking one. */
 	{
 		pr = g_malloc(sizeof *pr);
-		stu_strncpy(pr->name, ppr->name, sizeof pr->name);
+		g_strlcpy(pr->name, ppr->name, sizeof pr->name);
 		pr->override = FALSE;
 		pr->value = ppr->value;
 		g_hash_table_insert(stl->properties, pr->name, pr);
@@ -757,84 +759,10 @@ void stl_styleinfo_destroy(StyleInfo *si)
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* 1999-05-22 -	User just expanded a node in the tree. */
-static void evt_style_expand(GtkWidget *wid, gpointer user)
-{
-	Style		*stl = gtk_object_get_user_data(GTK_OBJECT(wid));
-	gboolean	*modified;
-
-	stl->expand = TRUE;
-	if((modified = user) != NULL)
-		*modified = TRUE;
-}
-
-/* 1999-05-22 -	User collapsed a style node. */
-static void evt_style_collapse(GtkWidget *wid, gpointer user)
-{
-	Style		*stl = gtk_object_get_user_data(GTK_OBJECT(wid));
-	gboolean	*modified;
-
-	stl->expand = FALSE;
-	if((modified = user) != NULL)
-		*modified = TRUE;
-}
-
-/* 1999-05-22 -	Recursively build a tree rooted at <node>, and add it to <parent>. */
-static void build_branch(GNode *node, GtkWidget *parent, Style *ignore, gboolean *modify_flag)
-{
-	GtkWidget	*item;
-
-	for(; (node != NULL); node = node->next)
-	{
-		if((ignore != NULL) && (node->data == ignore))
-			continue;
-		item = gtk_tree_item_new_with_label(((Style *) node->data)->name);
-		gtk_object_set_user_data(GTK_OBJECT(item), node->data);
-		gtk_tree_append(GTK_TREE(parent), item);
-		gtk_widget_show(item);
-		if(node->children)
-		{
-			GtkWidget	*tree;
-
-			tree = gtk_tree_new();
-			build_branch(node->children, tree, ignore, modify_flag);
-			gtk_tree_item_set_subtree(GTK_TREE_ITEM(item), tree);
-			g_signal_connect(G_OBJECT(item), "expand", G_CALLBACK(evt_style_expand), modify_flag);
-			g_signal_connect(G_OBJECT(item), "collapse", G_CALLBACK(evt_style_collapse), modify_flag);
-		}
-		if(((Style *) node->data)->expand)
-			gtk_tree_item_expand(GTK_TREE_ITEM(item));
-	}
-}
-
-/* 1999-05-22 -	Create and populate a GtkTree widget, holding the style tree. Recursive. To track selections
-**		in the tree, use the "selection_changed" signal, together with the GTK_TREE_SELECTION() macro.
-*/
-GtkTree * stl_styleinfo_build(StyleInfo *si, gboolean *modify_flag)
-{
-	GtkWidget	*tree;
-
-	tree = gtk_tree_new();
-	build_branch(si->styles, tree, NULL, modify_flag);
-
-	return GTK_TREE(tree);
-}
-
-/* 1999-05-24 -	Build a partial style tree, ignoring any branch rooted at <ignore>. */
-GtkTree * stl_styleinfo_build_partial(StyleInfo *si, Style *ignore)
-{
-	GtkWidget	*tree;
-
-	tree = gtk_tree_new();
-	build_branch(si->styles, tree, ignore, NULL);
-
-	return GTK_TREE(tree);
-}
-
 /* 2006-03-02 -	Append a branch of the style tree to the given store. This does not collapse/expand it
  *		properly, since that's not doable with GTK+2 at this level (it's a view property).
 */
-static void append_branch2(GtkTreeStore *store, const GNode *node, GtkTreeIter *parent, const Style *ignore, gboolean *modify_flag)
+static void append_branch(GtkTreeStore *store, const GNode *node, GtkTreeIter *parent, const Style *ignore, gboolean *modify_flag)
 {
 	GtkTreeIter	child;
 
@@ -847,17 +775,17 @@ static void append_branch2(GtkTreeStore *store, const GNode *node, GtkTreeIter *
 						  TREE_COLUMN_STYLE, node->data,
 						  -1);
 		if(node->children != NULL)
-			append_branch2(store, node->children, &child, ignore, modify_flag);
+			append_branch(store, node->children, &child, ignore, modify_flag);
 	}
 }
 
 /* 2006-03-02 -	Build a partial style store, ignoring any branch rooted at <ignore>. */
-GtkTreeStore * stl_styleinfo_build_partial2(const StyleInfo *si, const Style *ignore)
+GtkTreeStore * stl_styleinfo_build_partial(const StyleInfo *si, const Style *ignore)
 {
 	GtkTreeStore	*store;
 
 	store = gtk_tree_store_new(2, G_TYPE_STRING, G_TYPE_POINTER);
-	append_branch2(store, si->styles, NULL, ignore, NULL);
+	append_branch(store, si->styles, NULL, ignore, NULL);
 
 	return store;
 }
@@ -938,7 +866,7 @@ Style * stl_style_new(const gchar *name)
 	Style	*stl;
 
 	stl = g_malloc(sizeof *stl);
-	stu_strncpy(stl->name, name, sizeof stl->name);
+	g_strlcpy(stl->name, name, sizeof stl->name);
 	stl->styleinfo = NULL;
 	stl->properties = g_hash_table_new(g_str_hash, g_str_equal);
 	stl->expand = TRUE;
@@ -1013,7 +941,7 @@ Style * stl_style_copy(Style *stl)
 Style * stl_style_get(GtkWidget *wid)
 {
 	if(wid != NULL)
-		return gtk_object_get_user_data(GTK_OBJECT(wid));
+		return g_object_get_data(G_OBJECT(wid), "user");
 	return NULL;
 }
 
@@ -1036,14 +964,7 @@ gboolean stl_style_get_expand(Style *stl)
 void stl_style_set_name(Style *stl, const gchar *name)
 {
 	if((stl != NULL) && (name != NULL))
-		stu_strncpy(stl->name, name, sizeof stl->name);
-}
-
-/* 1999-05-24 -	Update label of treeitem <wid> to <name>. This is only useful in config. */
-void stl_style_set_name_widget(GtkWidget *wid, const gchar *name)
-{
-	if((wid != NULL) && GTK_IS_TREE_ITEM(wid) && (name != NULL))
-		gtk_label_set_text(GTK_LABEL(GTK_BIN(wid)->child), name);
+		g_strlcpy(stl->name, name, sizeof stl->name);
 }
 
 /* 1999-05-20 -	Just get a pointer (read-only, as usual) to the style's name. */
@@ -1171,7 +1092,7 @@ static StlProp * style_get_property(Style *stl, const gchar *name, StlPType type
 	else
 	{
 		pr = g_malloc(sizeof *pr);
-		stu_strncpy(pr->name, name, sizeof pr->name);
+		g_strlcpy(pr->name, name, sizeof pr->name);
 		g_hash_table_insert(stl->properties, pr->name, pr);
 	}
 	pr->override = TRUE;
@@ -1226,7 +1147,7 @@ void stl_style_property_set_icon(Style *stl, const gchar *property, const gchar
 	if((stl != NULL) && (value != NULL))
 	{
 		pr = style_get_property(stl, property, SPT_ICON);
-		stu_strncpy(pr->value->data.icon, value, sizeof pr->value->data.icon);
+		g_strlcpy(pr->value->data.icon, value, sizeof pr->value->data.icon);
 		styleinfo_update(stl->styleinfo);
 	}
 }
@@ -1247,7 +1168,7 @@ void stl_style_property_set_action(Style *stl, const gchar *property, const gcha
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1999-05-19 -	Get a read-only pointer to the color held in a color-property. */
-const GdkColor * stl_style_property_get_color(Style *stl, const gchar *property)
+const GdkColor * stl_style_property_get_color(const Style *stl, const gchar *property)
 {
 	StlProp	*pr;
 
@@ -1260,7 +1181,7 @@ const GdkColor * stl_style_property_get_color(Style *stl, const gchar *property)
 }
 
 /* 1999-05-19 -	Get a (read-only) icon name of an appropriately typed property. */
-const gchar * stl_style_property_get_icon(Style *stl, const gchar *property)
+const gchar * stl_style_property_get_icon(const Style *stl, const gchar *property)
 {
 	StlProp	*pr;
 
@@ -1427,7 +1348,7 @@ gboolean stl_style_property_rename(Style *stl, const gchar *property, const gcha
 	}
 	/* Remove from hash table, rename, and re-insert. */
 	g_hash_table_remove(stl->properties, pr->name);
-	stu_strncpy(pr->name, new_name, sizeof pr->name);
+	g_strlcpy(pr->name, new_name, sizeof pr->name);
 	g_hash_table_insert(stl->properties, pr->name, pr);
 	/* Name changed. Now traverse children, and remove non-overridden instances. */
 	if((me = g_node_find(stl->styleinfo->styles, G_PRE_ORDER, G_TRAVERSE_ALL, stl)) != NULL)
