@@ -37,9 +37,7 @@ StyleInfo *	stl_styleinfo_new(void);
 StyleInfo *	stl_styleinfo_default(void);
 StyleInfo *	stl_styleinfo_copy(StyleInfo *si);
 void		stl_styleinfo_destroy(StyleInfo *si);
-GtkTree *	stl_styleinfo_build(StyleInfo *si, gboolean *modify_flag);
-GtkTree *	stl_styleinfo_build_partial(StyleInfo *si, Style *ignore);
-GtkTreeStore *	stl_styleinfo_build_partial2(const StyleInfo *si, const Style *ignore);
+GtkTreeStore *	stl_styleinfo_build_partial(const StyleInfo *si, const Style *ignore);
 
 Style *		stl_styleinfo_get_style_iter(const StyleInfo *si, GtkTreeStore *store, GtkTreeIter *iter);
 gboolean	stl_styleinfo_tree_find_style(const StyleInfo *si, GtkTreeStore *store, const Style *style, GtkTreeIter *iter);
@@ -89,8 +87,8 @@ void		stl_style_property_set_color(Style *stl, const gchar *property, const GdkC
 void		stl_style_property_set_color_rgb(Style *stl, const gchar *property, guint16 red, guint16 green, guint16 blue);
 void		stl_style_property_set_icon(Style *stl, const gchar *property, const gchar *value);
 void		stl_style_property_set_action(Style *stl, const gchar *property, const gchar *value);
-const GdkColor*	stl_style_property_get_color(Style *stl, const gchar *property);
-const gchar *	stl_style_property_get_icon(Style *stl, const gchar *property);
+const GdkColor*	stl_style_property_get_color(const Style *stl, const gchar *property);
+const gchar *	stl_style_property_get_icon(const Style *stl, const gchar *property);
 const gchar *	stl_style_property_get_action(Style *stl, const gchar *property);
 gboolean	stl_style_property_get_override(Style *stl, const gchar *property);
 GList *		stl_style_property_get_actions(Style *stl);
