@@ -454,7 +454,7 @@ static void evt_goto_clicked(GtkWidget *wid, gpointer user)
 	goto_dialog.vbox  = gtk_vbox_new(FALSE, 0);
 	goto_dialog.label = gtk_label_new(_("Enter Line Number or Percentage:"));
 	gtk_box_pack_start(GTK_BOX(goto_dialog.vbox), goto_dialog.label, FALSE, FALSE, 0);
-	goto_dialog.entry = gtk_entry_new();
+	goto_dialog.entry = gui_dialog_entry_new();
 	gtk_box_pack_start(GTK_BOX(goto_dialog.vbox), goto_dialog.entry, FALSE, FALSE, 0);
 
 	gtk_widget_show_all(goto_dialog.vbox);
