@@ -16,18 +16,17 @@ extern GtkWidget *	txv_open(MainInfo *min, const gchar *label);
 
 extern void	txv_show(GtkWidget *textviewer);
 
-/* Use this to connect a "key_press_event" handler on the window. Call with
-** <func>==NULL to reset internal handler.
-*/
-extern guint	txv_connect_keypress(GtkWidget *wid, GtkSignalFunc func, gpointer user);
+extern gulong	txv_connect_delete(GtkWidget *wid, GCallback func, gpointer user);
+extern gulong	txv_connect_keypress(GtkWidget *wid, GCallback func, gpointer user);
 
 extern void	txv_set_label(GtkWidget *wid, const gchar *text);
-extern void	txv_set_label_from_filename(GtkWidget *wid, const gchar *filename);
+extern void	txv_set_label_from_file(GtkWidget *wid, GFile *file);
 
 extern void	txv_text_append(GtkWidget *wid, const gchar *text, gsize length);
 extern void	txv_text_append_with_color(GtkWidget *wid, const gchar *text, gsize length, const GdkColor *color);
-extern gint	txv_text_load(GtkWidget *wid, const gchar *name, gboolean use_mmap, gsize buf_size);
-extern gint	txv_text_load_hex(GtkWidget *wid, const gchar *name);
+
+extern gint	txv_text_load(GtkWidget *wid, GFile *file, gsize buf_size, const gchar *encoding, GError **err);
+extern gint	txv_text_load_hex(GtkWidget *wid, GFile *file, GError **err);
 
 extern void	txv_enable(GtkWidget *wid);
 
