@@ -30,6 +30,7 @@
 
 #include <stddef.h>
 
+#include "dirpane.h"
 #include "errors.h"
 #include "strutil.h"
 #include "styles.h"
@@ -41,10 +42,10 @@
 /* Collected variables that deal with 'file' into a struct, for clarity. */
 static struct
 {
-	gboolean		file_used;		/* Any types using 'file' active? */
-	GSList			*files;			/* Current list of files to inspect. */
-	gboolean		sigpipe_installed;	/* SIGPIPE handler installed? */
-	volatile sig_atomic_t	sigpipe_occured;	/* Did we just catch SIGPIPE? */
+	gboolean	file_used;		/* Any types using 'file' active? */
+	GSList		*files;			/* Current list of files to inspect. */
+	gboolean	sigpipe_installed;	/* SIGPIPE handler installed? */
+	volatile gint	sigpipe_occured;	/* Did we just catch SIGPIPE? */
 } file_info;
 
 /* ----------------------------------------------------------------------------------------- */
@@ -63,7 +64,7 @@ FType * typ_type_new(CfgInfo *cfg, const gchar *name, mode_t mode, gint perm, co
 
 	if((type = g_malloc(sizeof *type)) != NULL)
 	{
-		stu_strncpy(type->name, name, sizeof type->name);
+		g_strlcpy(type->name, name, sizeof type->name);
 		type->mode  = mode;
 		type->perm  = perm;
 		type->flags = 0UL;
@@ -77,17 +78,17 @@ FType * typ_type_new(CfgInfo *cfg, const gchar *name, mode_t mode, gint perm, co
 
 		if(suffix != NULL)
 		{
-			stu_strncpy(type->suffix, suffix, sizeof type->suffix);
+			g_strlcpy(type->suffix, suffix, sizeof type->suffix);
 			type->flags |= FTFL_REQSUFFIX;
 		}
 		if(name_re != NULL)
 		{
-			stu_strncpy(type->name_re_src, name_re, sizeof type->name_re_src);
+			g_strlcpy(type->name_re_src, name_re, sizeof type->name_re_src);
 			type->flags |= FTFL_NAMEMATCH;
 		}
 		if(file_re != NULL)
 		{
-			stu_strncpy(type->file_re_src, file_re, sizeof type->file_re_src);
+			g_strlcpy(type->file_re_src, file_re, sizeof type->file_re_src);
 			type->flags |= FTFL_FILEMATCH;
 		}
 		type->style = NULL;
@@ -156,13 +157,11 @@ FType * typ_type_get_unknown(const CfgInfo *cfg)
 /* 1998-09-07 -	Check if the file described by <line> matches the permissions requirements
 **		in <type>. Returns 1 if so, otherwise 0.
 ** 1999-03-14 -	Made the access to the DirRow (previously DirLine) a lot more abstract.
+** 2010-03-27 -	It's been a while, I guess. Porting to GIO and DirRow2.
 */
-static gint check_perm(const FType *type, DirRow *row)
+static gint check_perm(const FType *type, GtkTreeModel *model, const DirRow2 *row)
 {
-	gint	pr = 1, pw = 1, px = 1;
 	mode_t	mode = 0;
-	uid_t	uid;
-	gid_t	gid;
 
 	/* First build mode mask, for SetUID, SetGID and sticky. */
 	if(type->perm & FTPM_SETUID)
@@ -173,21 +172,25 @@ static gint check_perm(const FType *type, DirRow *row)
 		mode |= S_ISVTX;
 
 	/* Now we know the mode requirements - check if fulfilled. */
-	if((mode != 0) && ((DP_ROW_STAT(row).st_mode & mode) != mode))
+	if((mode != 0) && ((dp_row_get_mode(model, row) & mode) != mode))
 		return 0;
 
-	uid = geteuid();
-	gid = getegid();
-
-	/* Still here? Fine, then do (unorthodox, user-centric) read/write/execute permission checks. */
 	if(type->perm & FTPM_READ)
-		pr = fut_can_read(&DP_ROW_STAT(row), uid, gid);
+	{
+		if(!dp_row_get_can_read(model, row))
+			return 0;
+	}
 	if(type->perm & FTPM_WRITE)
-		pw = fut_can_write(&DP_ROW_STAT(row), uid, gid);
+	{
+		if(!dp_row_get_can_write(model, row))
+			return 0;
+	}
 	if(type->perm & FTPM_EXECUTE)
-		px = fut_can_execute(&DP_ROW_STAT(row), uid, gid);
-
-	return pr && pw && px;
+	{
+		if(!dp_row_get_can_execute(model, row))
+			return 0;
+	}
+	return 1;
 }
 
 /* ----------------------------------------------------------------------------------------- */
@@ -212,48 +215,44 @@ static gint check_re(const gchar *re_src, regex_t **re, gboolean glob, gboolean
 			g_free(glob_re);			/* Free the globbed version. */
 	}
 	if(*re != NULL)
-		return regexec(*re, string, 0, NULL, 0) != REG_NOMATCH;
-	return REG_NOMATCH;	/* FIXME: Weird! */
+		return regexec(*re, string, 0, NULL, 0) == 0;
+	return 0;
 }
 
-/* 1998-08-02 -	Attempt to apply the identification rules given in by the type <type> to the
-**		dirpane line in <user>. The string <fout> is output from 'file' on this very file,
-**		or NULL if 'file' hasn't yet been run. Returns TRUE if there is indeed a match. Note how
-**		regular expressions are compiled if they're not already, and that the compiled
-**		version is then kept for future use. This places some demands on the memory
-**		handling later (config etc) but I'll deal with that then...
-** 1998-08-26 -	Extended. Now actually does check against 'file' output.
-** 1998-08-30 -	Now supports glob->RE translations for name and file matches. Smooth.
-** 1998-09-15 -	Moved the actual RE checking out to a function of its own, since it was getting complex.
-** 1999-03-14 -	Replaced DirLine with new, opaque, DirRow.
-*/
-static gint check_type(FType *type, DirRow *row, const gchar *fout)
+static gboolean check_type(DirPane *dp, const DirRow2 *row, FType *type, const gchar *fout)
 {
-	guint		tries = 0, hits = 0;
+	gint		tries = 0, hits = 0;
 	const gchar	*name;
+	GFileType	tt;
+	GtkTreeModel	*model;
 
-	/* Everything matches the unknown type, and that's a fact. */
+	/* Catch-all: all files match the unknown type. */
 	if(TYP_IS_UNKNOWN(type))
-		return 1;
+		return TRUE;
 
-	/* For links, get actual name (without path) and use that. */
-	if(S_ISLNK(DP_ROW_LSTAT(row).st_mode))
-	{
-		if((name = strrchr(DP_ROW_LINKNAME(row), G_DIR_SEPARATOR)) == NULL)
-			name = DP_ROW_LINKNAME(row);
-		else
-			name++;
-	}
+	/* FIXME: Translate type's legacy type-information into simple GFileType value. */
+	if(S_ISREG(type->mode))
+		tt = G_FILE_TYPE_REGULAR;
+	else if(S_ISDIR(type->mode))
+		tt = G_FILE_TYPE_DIRECTORY;
+	else if(S_ISLNK(type->mode))
+		tt = G_FILE_TYPE_SYMBOLIC_LINK;
+	else if(S_ISFIFO(type->mode) || S_ISSOCK(type->mode))
+		tt = G_FILE_TYPE_SPECIAL;
 	else
-		name = DP_ROW_NAME(row);
+		tt = G_FILE_TYPE_UNKNOWN;
 
-	/* Apply the mode test first, since it's no doubt the fastest. */
-	if(((DP_ROW_STAT(row).st_mode) & S_IFMT) != type->mode)
-		return 0;
+	model = dp_get_tree_model(dp);
+
+	/* Apply the type test first, since it's the fastest. */
+	if(tt != dp_row_get_file_type(model, row, TRUE))
+		return FALSE;
+	name = dp_row_get_name(model, row);
+	/* Now do the rest, and count the number of matches. */
 	if(type->flags & FTFL_REQPERM)
 	{
 		tries++;
-		hits += check_perm(type, row);
+		hits += check_perm(type, model, row);
 	}
 	if(type->flags & FTFL_REQSUFFIX)
 	{
@@ -271,199 +270,7 @@ static gint check_type(FType *type, DirRow *row, const gchar *fout)
 		if(fout != NULL)
 			hits += check_re(type->file_re_src, &type->file_re, type->flags & FTFL_FILEGLOB, type->flags & FTFL_FILENOCASE, fout);
 	}
-	return tries == hits;
-}
-
-/* 1998-08-02 -	Identify the <line>, i.e. attempt to find an FType that matches it, and assign
-**		a pointer to that FType to the line's "type" field. If no user-defined type
-**		is found, we assign the root type ("Unknown").
-** 1998-08-26 -	Now returns TRUE if a "sophisticated" type was indeed found, FALSE if the "Unknown"
-**		type had to do. Also has become 'static', since you can't call this outside of
-**		the framework established by typ_identify_begin()/typ_idenfify_end(). Note use
-**		of NULL as third arg to check_type(), since we haven't started running 'file'
-**		yet.
-** 1999-03-14 -	Replaced DirLine with DirRow.
-*/
-static gint identify(MainInfo *min, DirRow *row)
-{
-	const GList	*here;
-
-	for(here = min->cfg.type; here != NULL; here = g_list_next(here))
-	{
-		if(check_type((FType *) here->data, row, NULL))
-		{
-			DP_ROW_TYPE(row) = here->data;
-			break;
-		}
-	}
-	return !TYP_IS_UNKNOWN((FType *) here->data);
-}
-
-/* ----------------------------------------------------------------------------------------- */
-
-/* 1998-08-26 -	A rewrite of the much of the (three weeks old) file typing architecture, in
-**		order to accomodate use of 'file' in a way even resembling something efficient.
-**		Rather than just calling typ_identify() on a dirline, you call first this
-**		function, which initializes some state. You then, repeatedly, call typ_identify()
-**		for all lines you wish to type. Then call typ_identify_end(). Done!
-*/
-void typ_identify_begin(MainInfo *min)
-{
-	GList	*here;
-
-	if(file_info.files != NULL)
-		fprintf(stderr, "**TYPES: Attempted to nest calls to typ_identify_begin()!\n");
-
-	for(here = min->cfg.type; here != NULL; here = g_list_next(here))
-	{
-		if(((FType *) here->data)->flags & FTFL_FILEMATCH)
-			break;
-	}
-	file_info.file_used = (here != NULL);
-}
-
-/* ----------------------------------------------------------------------------------------- */
-
-/* 1998-08-26 -	Identify the given line. If identification fails, i.e. if the "Unknown" type is
-**		assigned to the line, remember the line for later exposure to the external
-**		'file' command.
-*/
-void typ_identify(MainInfo *min, DirRow *row)
-{
-	if(!identify(min, row) && file_info.file_used)
-		file_info.files = g_slist_prepend(file_info.files, row);
-}
-
-/* ----------------------------------------------------------------------------------------- */
-
-/* 1998-08-26 -	Attempt to match all types in list against <line>, knowing that 'file' said
-**		<fout>. Only types that include a 'file'-matching RE are checked, of course.
-**		Returns the matching type if any, or NULL if there's no match.
-*/
-static FType * match_file(GList *list, DirRow *row, const gchar *fout)
-{
-	FType	*type;
-
-	for(; (list != NULL) && (type = (FType *) list->data); list = g_list_next(list))
-	{
-		if(check_type(type, row, fout))
-			return type;
-	}
-	return NULL;
-}
-
-/* 2009-03-11 -	Trivial SIGPIPE handler, that just sets a global flag. */
-static void sigpipe_handler(int sig)
-{
-	if(sig != SIGPIPE)
-		return;
-	file_info.sigpipe_occured = 1;
-}
-
-/* 2009-03-11 -	Installs a signal handler for SIGPIPE, so we can catch broken 'file' runs. */
-static gboolean install_handler(void)
-{
-	struct sigaction	act;
-
-	if(file_info.sigpipe_installed)
-		return TRUE;
-
-	act.sa_handler = sigpipe_handler;
-	sigemptyset(&act.sa_mask);
-	act.sa_flags	= 0;
-
-	return file_info.sigpipe_installed = (sigaction(SIGPIPE, &act, NULL) == 0);
-}
-
-/* 1998-08-26 -	End of batched identification. If any unknown's were found *and* we know that
-**		there are 1 or more types using the 'file' recognition support, we need to
-**		call 'file'. The idea here is that we only want to execute the 'file' command
-**		once, no matter how many files need identification. Also, we use redirection
-**		of stdin for 'file' to supply it with file names to check (via its "-f -" option),
-**		since writing out the names to disk seems inefficient.
-** 2009-03-08 -	Totally rewritten, now uses glib's fancy spawning to run the subprocess, and
-**		keeps it all going in pipes, without touching disk. This removes the need for
-**		a temporary filename, and should improve performance.
-*/
-void typ_identify_end(MainInfo *min, const gchar *path)
-{
-	gchar	*argv[] = { "file", "-n", "-f", "-", NULL };
-	GPid	file_pid;
-	gint	file_stdin, file_stdout;
-	GError	*error = NULL;
-
-	if(file_info.files == NULL)
-		return;
-
-	install_handler();
-
-	if(g_spawn_async_with_pipes(NULL, argv, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_STDERR_TO_DEV_NULL,
-				    NULL, NULL, &file_pid, &file_stdin, &file_stdout, NULL, &error))
-	{
-		FILE	*in;
-
-		if((in = fdopen(file_stdout, "rt")) != NULL)
-		{
-			GSList	*here;
-
-			for(here = file_info.files; here != NULL; here = g_slist_next(here))
-			{
-				gchar	buf[FILENAME_MAX + 256];
-				size_t	len, to_go;
-				ssize_t	wrote;
-
-				len = g_snprintf(buf, sizeof buf, "%s\n", DP_SEL_NAME(here));
-				if(len >= sizeof buf)	/* Handle overflow by just skipping that file. */
-					continue;
-				for(to_go = len; to_go > 0; to_go -= wrote)
-				{
-					file_info.sigpipe_occured = 0;
-					err_clear(min);
-					wrote = write(file_stdin, buf + (len - to_go), to_go);
-					if(errno == EPIPE)
-						file_info.sigpipe_occured = 1;
-					if(wrote < 0)
-						break;
-					else if(file_info.sigpipe_occured)
-						break;
-				}
-				if(file_info.sigpipe_occured)
-					break;
-				if(fgets(buf, sizeof buf, in) != NULL)
-				{
-					const char	*fout;
-					FType		*type;
-
-					if((fout = strchr(buf, ':')) == NULL)
-						continue;
-					for(fout++; isspace(*fout); fout++)
-						;
-					if((type = match_file(min->cfg.type, DP_SEL_ROW(here), fout)) != NULL)
-						DP_SEL_TYPE(here) = type;
-				}
-			}
-			fclose(in);
-		}
-		close(file_stdin);
-		close(file_stdout);
-		g_spawn_close_pid(file_pid);
-		err_clear(min);
-		if(file_info.sigpipe_occured)
-		{
-			/* FIXME: This is problematic; the nice printf() text is often lost due to free space printing. */
-			err_printf(min, _("Got SIGPIPE when writing to 'file' process (%s), it seems to have terminated prematurely."), argv[0]);
-			/* FIXME: As a last resort, this at leas "sticks" so an error gets shown when we get out. */
-			errno = EPIPE;
-		}
-	}
-	else
-	{
-		g_prefix_error(&error, _("Unable to run spawn 'file' command: "));
-		err_printf(min, "%s", error->message);
-		g_error_free(error);
-	}
-	g_slist_free(file_info.files);
-	file_info.files = NULL;
+	return (tries == hits);
 }
 
 /* ----------------------------------------------------------------------------------------- */
@@ -570,7 +377,7 @@ GList * typ_type_lookup_glob(const GList *list, const gchar *glob)
 */
 GList * typ_type_set_name(GList *list, FType *type, const gchar *name)
 {
-	stu_strncpy(type->name, name, sizeof type->name);
+	g_strlcpy(type->name, name, sizeof type->name);
 	return list;
 }
 
@@ -602,3 +409,183 @@ GList * typ_type_move(GList *list, FType *type, gint delta)
 
 	return g_list_insert(list, type, np);
 }
+
+/* ----------------------------------------------------------------------------------------- */
+
+void typ_identify_begin(DirPane *dp)
+{
+	GList	*here;
+
+	if(file_info.files != NULL)
+		g_warning("**TYPES: Attempted to nest calls to typ_identify_begin()!");
+
+	for(here = dp->main->cfg.type; here != NULL; here = g_list_next(here))
+	{
+		if(((FType *) here->data)->flags & FTFL_FILEMATCH)
+			break;
+	}
+	file_info.file_used = (here != NULL);
+}
+
+static FType * identify(DirPane *dp, const DirRow2 *row)
+{
+	const GList	*here;
+
+	for(here = dp->main->cfg.type; here != NULL; here = g_list_next(here))
+	{
+		if(check_type(dp, row, here->data, NULL))
+			return here->data;
+	}
+	return NULL;
+}
+
+void typ_identify(DirPane *dp, const DirRow2 *row)
+{
+	FType	*ft;
+
+	ft = identify(dp, row);
+	if(ft != NULL)
+		dp_row_set_ftype(dp_get_tree_model(dp), row, ft);
+	if(TYP_IS_UNKNOWN(ft) && file_info.file_used)
+	{
+		DirRow2	*sr;
+
+		sr = g_slice_alloc(sizeof *sr);
+		memcpy(sr, row, sizeof *sr);
+		file_info.files = g_slist_prepend(file_info.files, sr);
+	}
+}
+
+/* 2010-03-13 -	Attempt to match all types in list against <line>, knowing that 'file' said
+**		<fout>. Only types that include a 'file'-matching RE are checked, of course.
+**		Returns the matching type if any, or NULL if there's no match.
+*/
+static FType * match_file(DirPane *dp, GList *list, DirRow2 *row, const gchar *fout)
+{
+	FType	*type;
+
+	for(; (list != NULL) && (type = (FType *) list->data); list = g_list_next(list))
+	{
+		if(check_type(dp, row, list->data, fout))
+			return type;
+	}
+	return NULL;
+}
+
+/* 2009-03-11 -	Trivial SIGPIPE handler, that just sets a global flag. */
+static void sigpipe_handler(int sig)
+{
+	if(sig != SIGPIPE)
+		return;
+	g_atomic_int_set(&file_info.sigpipe_occured, 1);
+}
+
+/* 2009-03-11 -	Installs a signal handler for SIGPIPE, so we can catch broken 'file' runs. */
+static gboolean install_handler(void)
+{
+	struct sigaction	act;
+
+	if(file_info.sigpipe_installed)
+		return TRUE;
+
+	act.sa_handler = sigpipe_handler;
+	sigemptyset(&act.sa_mask);
+	act.sa_flags	= 0;
+
+	return file_info.sigpipe_installed = (sigaction(SIGPIPE, &act, NULL) == 0);
+}
+
+gboolean typ_identify_end(DirPane *dp)
+{
+	gchar		*argv[] = { "file", "-n", "-f", "-", NULL }, *path;
+	GPid		file_pid;
+	gint		file_stdin, file_stdout;
+	GError		*error = NULL;
+	GtkTreeModel	*tm = dp_get_tree_model(dp);
+	GSList		*here;
+	gboolean	ret = TRUE;
+
+	if(file_info.files == NULL || !dp->dir.is_local)
+		return TRUE;
+	if((path = g_file_get_path(dp->dir.root)) == NULL)
+		return TRUE;
+
+	install_handler();
+
+	if(g_spawn_async_with_pipes(path, argv, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_STDERR_TO_DEV_NULL,
+				    NULL, NULL, &file_pid, &file_stdin, &file_stdout, NULL, &error))
+	{
+		FILE	*in;
+
+		if((in = fdopen(file_stdout, "rt")) != NULL)
+		{
+			for(here = file_info.files; here != NULL; here = g_slist_next(here))
+			{
+				gchar	buf[URI_MAX + 256], *path;
+				size_t	len, to_go;
+				ssize_t	wrote;
+
+				/* Handle missing path by skipping, just like we do below. */
+				if((path = g_file_get_path(dp_get_file_from_row(dp, here->data))) == NULL)
+					continue;
+				len = g_snprintf(buf, sizeof buf, "%s\n", path);
+				g_free(path);
+				if(len >= sizeof buf)	/* Handle overflow by just skipping that file. */
+					continue;
+				g_atomic_int_set(&file_info.sigpipe_occured, 0);
+				for(to_go = len; to_go > 0; to_go -= wrote)
+				{
+					wrote = write(file_stdin, buf + (len - to_go), to_go);
+					if(wrote < 0)
+					{
+						if(errno == EPIPE)
+							g_atomic_int_set(&file_info.sigpipe_occured, 1);
+						break;
+					}
+				}
+				if(g_atomic_int_get(&file_info.sigpipe_occured))
+					break;
+				if(fgets(buf, sizeof buf, in) != NULL)
+				{
+					const char	*fout;
+					char		*lf;
+					FType		*type;
+
+					if((fout = strrchr(buf, ':')) == NULL)
+						continue;
+					for(fout++; isspace(*fout); fout++)
+						;
+					if((lf = strchr(fout + 1, '\n')) != NULL)
+						*lf = '\0';
+					if((type = match_file(dp, dp->main->cfg.type, here->data, fout)) != NULL)
+						dp_row_set_ftype(tm, here->data, type);
+				}
+			}
+			fclose(in);
+		}
+		close(file_stdin);
+		close(file_stdout);
+		g_spawn_close_pid(file_pid);
+		if(g_atomic_int_get(&file_info.sigpipe_occured))
+		{
+			/* FIXME: This is problematic; the nicely formatted text is often lost due to free space printing. */
+			err_printf(dp->main, _("Got SIGPIPE when writing to 'file' process (%s), it seems to have terminated prematurely."), argv[0]);
+			ret = FALSE;
+		}
+	}
+	else
+	{
+		g_prefix_error(&error, _("Unable to run spawn 'file' command: "));
+		err_printf(dp->main, "%s", error->message);
+		g_error_free(error);
+		ret = FALSE;
+	}
+	/* Walk list once more, freeing all data. */
+	for(here = file_info.files; here != NULL; here = g_slist_next(here))
+		g_slice_free1(sizeof (DirRow2), here->data);
+	g_slist_free(file_info.files);
+	file_info.files = NULL;
+	g_free(path);
+
+	return ret;
+}
