@@ -71,28 +71,32 @@ WinInfo * win_wininfo_new_default(MainInfo *min)
 	*/
 	win_borders_set(wi, 4, 24);
 
-	win_window_new(wi, WIN_MAIN, WIN_TYPE_SIMPLE_TOPLEVEL, FALSE, geteuid()
-			== 0 ? "gentoo [root]" : "gentoo", "main");
+	win_window_new(wi, WIN_MAIN, WIN_TYPE_SIMPLE_TOPLEVEL, FALSE, geteuid() == 0 ? "gentoo [root]" : "gentoo", "main");
 	win_window_pos_grab_set(wi, WIN_MAIN, TRUE);
 	win_window_size_set(wi, WIN_MAIN, 764, 932);
 	win_window_size_use_set(wi, WIN_MAIN, TRUE);
 	win_window_size_update_set(wi, WIN_MAIN, TRUE);
 	win_window_size_grab_set(wi, WIN_MAIN, TRUE);
 
-	win_window_new(wi, WIN_CONFIG, WIN_TYPE_COMPLEX_DIALOG, TRUE,
-			_("Configure gentoo"), "config");
+	win_window_new(wi, WIN_CONFIG, WIN_TYPE_COMPLEX_DIALOG, TRUE, _("Configure gentoo"), "config");
 	win_window_pos_use_set(wi, WIN_CONFIG, FALSE);
 	win_window_size_set(wi, WIN_CONFIG, -1, 464);
 	win_window_size_use_set(wi, WIN_CONFIG, TRUE);
 	win_window_size_update_set(wi, WIN_CONFIG, TRUE);
 
-	win_window_new(wi, WIN_TEXTVIEW, WIN_TYPE_SIMPLE_TOPLEVEL, FALSE,
-			_("Text Viewer"), "textview");
+	win_window_new(wi, WIN_TEXTVIEW, WIN_TYPE_SIMPLE_TOPLEVEL, FALSE, _("Text Viewer"), "textview");
 	win_window_pos_use_set(wi, WIN_TEXTVIEW, FALSE);
 	win_window_size_set(wi, WIN_TEXTVIEW, 640, 480);
 	win_window_size_use_set(wi, WIN_TEXTVIEW, TRUE);
 	win_window_size_update_set(wi, WIN_TEXTVIEW, TRUE);
 
+	win_window_new(wi, WIN_INFO, WIN_TYPE_SIMPLE_DIALOG, FALSE, "Info", "info");
+	win_window_pos_grab_set(wi, WIN_INFO, TRUE);
+	win_window_size_set(wi, WIN_INFO, 320, 480);
+	win_window_size_use_set(wi, WIN_INFO, TRUE);
+	win_window_size_update_set(wi, WIN_INFO, TRUE);
+	win_window_size_grab_set(wi, WIN_INFO, TRUE);
+
 	return wi;
 }
 
@@ -617,6 +621,8 @@ GtkWidget * win_window_open(const WinInfo *wi, guint32 id)
 			gtk_window_set_transient_for(GTK_WINDOW(wid), GTK_WINDOW(wi->min->gui->window));
 		if(wd->title != NULL)
 			win_window_set_title(wid, wd->title);
+		if(wd->label != NULL)
+			gtk_window_set_role(GTK_WINDOW(wid), wd->label);
 		return wid;
 	}
 	return NULL;
@@ -644,27 +650,8 @@ void win_window_relink(const WinInfo *wi, guint32 id, GtkWidget *window)
 */
 void win_window_set_title(GtkWidget *win, const gchar *title)
 {
-#if defined ENABLE_NLS
-	gchar obuf[256]; /* Buffer, subsequent setlocale() call kills it otherwise. */
-	const gchar *op;
-
-	/* Get current locale, before slamming "C" in there. */
-	if((op = setlocale(LC_ALL, NULL)) != NULL)
-	{
-		const gchar *sl;
-
-		g_snprintf(obuf, sizeof obuf, "%s", op);
-		sl = setlocale(LC_ALL, "C");
-	}
-#endif
-	/* If ENABLE_NLS is undefined, this is all we do. */
 	gtk_widget_realize(win);
 	gtk_window_set_title(GTK_WINDOW(win), title);
-
-#if defined ENABLE_NLS
-	if(op != NULL)
-		setlocale(LC_ALL, obuf);
-#endif
 }
 
 /* 1999-12-23 -	Use this rather than gtk_widget_show() when you want to the window to appear, since
