@@ -113,7 +113,7 @@ static	struct {
 /* This little global variable (shudder) holds the nesting level for tags in the file being
 ** written by xml_put_XXX() functions.
 */
-static gint	put_level = 0;
+static guint	put_level = 0;
 
 /* ----------------------------------------------------------------------------------------- */
 
